<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sieverules.css" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:object name="steptitle" /></h1>

<div id="preferences-details" class="boxcontent">
<roundcube:object name="sieverulessetup" class="propform" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>