<?php
/* Author: Aymeric Peuch */

$labels = array();
$labels['filters'] = 'Filtres';
$labels['managefilters'] = 'Gestion des filtres sur les mails entrants';
$labels['filtername'] = 'Nom du filtre';
$labels['disablerule'] = 'Désactiver le filtre';
$labels['disabled'] = 'Désactivé';
$labels['newfilter'] = 'Nouveau filtre';
$labels['moveup'] = 'Monter';
$labels['movedown'] = 'Descendre';
$labels['filterallof'] = 'valident toutes les conditions suivantes';
$labels['filteranyof'] = 'valident au moins une des conditions suivantes';
$labels['filterany'] = 'tous les messages';
$labels['filtercontains'] = 'contient';
$labels['filternotcontains'] = 'ne contient pas';
$labels['filteris'] = 'est';
$labels['filterisnot'] = 'n\'est pas';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'n\'existe pas';
$labels['filterregex'] = 'valide l\'expression régulière';
$labels['filternotregex'] = 'ne valide pas l\'expression régulière';
$labels['filterunder'] = 'est inférieur à';
$labels['filterover'] = 'est supérieur à';
$labels['filterbefore'] = 'antérieur(e) à';
$labels['filterafter'] = 'postérieur(e) à';
$labels['filteradvoptions'] = 'plus d\'options...';
$labels['spamtest'] = 'Probabilité de spam';
$labels['operator'] = 'Opérateur';
$labels['comparator'] = 'Comparateur';
$labels['isgreaterthan'] = 'plus grande que';
$labels['isgreaterthanequal'] = 'plus grande ou égale à';
$labels['islessthan'] = 'plus petite que';
$labels['islessthanequal'] = 'plus petite ou égale à';
$labels['equals'] = 'est égale à';
$labels['notequals'] = 'n\'est pas égale à';
$labels['countisgreaterthan'] = 'longueur plus grande que';
$labels['countisgreaterthanequal'] = 'longueur plus grande ou égale à';
$labels['countislessthan'] = 'longueur plus petite que';
$labels['countislessthanequal'] = 'longueur plus petite ou égale à';
$labels['countequals'] = 'longueur est égale à';
$labels['countnotequals'] = 'longueur n\'est pas égale à';
$labels['valueisgreaterthan'] = 'valeur plus grande que';
$labels['valueisgreaterthanequal'] = 'valeur plus grande ou égale à';
$labels['valueislessthan'] = 'valeur plus petite que';
$labels['valueislessthanequal'] = 'valeur plus petite ou égale à';
$labels['valueequals'] = 'valeur est égale à';
$labels['valuenotequals'] = 'valeur n\'est pas égale à';
$labels['userpart'] = 'partie utilisateur égale à';
$labels['notuserpart'] = 'partie utilisateur n\'est pas égale à';
$labels['detailpart'] = 'partie détaillée égale à';
$labels['notdetailpart'] = 'partie détaillée n\'est pas égale à';
$labels['domainpart'] = 'partie domaine égale à';
$labels['notdomainpart'] = 'partie domaine n\'est pas égale à';
$labels['teststring'] = 'Chaîne de test';
$labels['messagemoveto'] = 'Déplacer le message vers';
$labels['messageredirect'] = 'Rediriger le message à';
$labels['messageimapflags'] = 'Marquer le message comme';
$labels['messagereject'] = 'Rejeter le message';
$labels['messagevacation'] = 'Message d\'absence';
$labels['messagekeep'] = 'Garder le message';
$labels['messagediscard'] = 'Refuser le message';
$labels['messagenotify'] = 'Envoyer la notification';
$labels['messagestop'] = 'Arrêter les filtres en cours';
$labels['messagehelp'] = 'Qu\'est-ce que c\'est ?';
$labels['sieveorigsubj'] = 'Ajouter le sujet original à la réponse';
$labels['sievevachandle'] = 'Traiter';
$labels['method'] = 'Méthode';
$labels['options'] = 'Options';
$labels['messagesrules'] = 'Règles du filtre';
$labels['messagesactions'] = 'Actions du filtre';
$labels['sieveto'] = 'Alias';
$labels['sievefrom'] = 'De';
$labels['flag'] = 'Importance';
$labels['importancen'] = 'Aucune';
$labels['importance1'] = 'Haute';
$labels['importance2'] = 'Normale';
$labels['importance3'] = 'Basse';
$labels['flagread'] = 'Lu';
$labels['flagdeleted'] = 'Supprimé';
$labels['flaganswered'] = 'Répondu';
$labels['flagdraft'] = 'Brouillon';
$labels['flagflagged'] = 'Suivi';
$labels['addsieverule'] = 'Ajouter une autre règle en dessous de celle-ci';
$labels['addsieveact'] = 'Ajouter une autre action en dessous de celle-ci';
$labels['deletesieverule'] = 'Effacer cette règle';
$labels['deletesieveact'] = 'Effacer cette action';
$labels['envelopefrom'] = 'Enveloppe De';
$labels['envelopeto'] = 'Enveloppe Pour';
$labels['otherheader'] = 'Autre entête';
$labels['period'] = 'Période';
$labels['message'] = 'Message';
$labels['sieveruleheaders'] = 'Voir des exemples d\'autres entêtes';
$labels['examplefilters'] = 'Exemple de filtres';
$labels['importfilters'] = 'Importer des filtres';
$labels['usedefaultfilter'] = 'Utiliser les filtres par défaut';
$labels['importfilter'] = 'Importer des filtres';
$labels['moreactions'] = 'Plus d\'options';
$labels['adveditor'] = 'Editeur avancé';
$labels['stdeditor'] = 'Editeur par défaut';
$labels['messageredirectcopy'] = 'Envoyé une copie à';
$labels['messagecopyto'] = 'Copier le message vers';
$labels['body'] = 'Corps';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Brut';
$labels['text'] = 'Texte';
$labels['other'] = 'Autre';
$labels['bodycontentpart'] = 'Contenu';
$labels['notchecked'] = 'non coché';
$labels['spamlevelisgreaterthanequal'] = 'plus grande ou égale à';
$labels['spamlevelislessthanequal'] = 'plus petite ou égale à';
$labels['spamlevelequals'] = 'est égale à';
$labels['i;ascii-casemap'] = 'insensible à la casse';
$labels['i;octet'] = 'correspondance exacte';
$labels['i;ascii-numeric'] = 'correspondance numérique';
$labels['selectruleset'] = 'Sélectionner un groupe de règles';
$labels['activeruleset'] = '%s (actif)';
$labels['activateruleset'] = 'Activer ce groupe de règles';
$labels['newruleset'] = 'Créer un nouveau groupe de règles';
$labels['delruleset'] = 'Effacer ce groupe de règles';
$labels['renameruleset'] = 'Renomer ce groupe de règles';
$labels['copy'] = 'Copier';
$labels['copyexistingfilter'] = 'Copier les filtres éxistants';
$labels['copytoruleset'] = 'Copier le filtre dans un autre groupe de règles';
$labels['copyfromruleset'] = 'Copier des filtres depuis un autre groupe de règles';
$labels['time'] = 'Heure';
$labels['weekday'] = 'Jour de la semaine';

$messages = array();
$messages['nosieverules'] = 'Aucun filtre trouvé.';
$messages['filterdeleteconfirm'] = 'Etes-vous sûr de vouloir effacer ce filtre ?';
$messages['ruledeleteconfirm'] = 'Etes-vous sûr de vouloir effacer cette règle ?';
$messages['actiondeleteconfirm'] = 'Etes-vous sûr de vouloir effacer cette action ?';
$messages['filterunknownerror'] = 'Erreur serveur inconnue';
$messages['filterconnerror'] = 'Impossible de se connecter au serveur sieve';
$messages['filterdeleteerror'] = 'Impossible de supprimer le filtre. Une erreur serveur a eu lieu';
$messages['filterdeleted'] = 'Suppression du filtre effectuée.';
$messages['filtersaved'] = 'Sauvegarde du filtre effectuée.';
$messages['filtersaveerror'] = 'Impossible d\'enregistrer le filtre. Une erreur serveur a eu lieu';
$messages['vacperiodexp'] = 'La période est le nombre de jours pendant lesquels le message ne sera pas renvoyé à l\'utilisateur, peu importe le nombre de fois où il vous contacte. <br /> <br /> Par exemple: Si Joe vous contacte le lundi et la période est définie à 7, alors Joe va recevoir un message d\'absence du bureau le lundi, mais n\'en aura pas de nouveaux avant le lundi suivant, peu importe le nombre d\'emails qu\'il envoie au cours de la semaine.';
$messages['vachandleexp'] = 'Un traitement peut être utilisé pour lier différents messages d\'absence ensemble ; une fois qu\'un message a été envoyé, aucun autre message autre avec le même traitement sera renvoyé durant la période.';
$messages['vactoexp'] = 'Liste de destinataires supplémentaires qui sont inclus dans l\'auto réponse. Si le destinataire de l\'email n\'est pas votre adresse principale et qu\'elle n\'est pas dans la liste, aucun message ne sera envoyé.';
$messages['vactoexp_adv'] = 'Séparez plusieurs adresses avec une virgule (,). Par exemple: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Erreur: Plusieurs adresses doivent être séparées par une virgule (,)';
$messages['norulename'] = 'Veuillez entrer un nom pour le filtre';
$messages['ruleexists'] = 'Un filtre avec le même nom existe déjà. Veuillez en choisir un autre';
$messages['noheader'] = 'Veuillez entrer le nom de l\'entête à tester';
$messages['headerbadchars'] = 'Erreur : L\'entête contient des caractères interdits.';
$messages['noheadervalue'] = 'Veuillez entrer une valeur à tester pour l\'entête';
$messages['sizewrongformat'] = 'Erreur : La taile du message doit être un nombre';
$messages['noredirect'] = 'Veuillez entrer une adresse email pour la redirection du message';
$messages['redirectaddresserror'] = 'Erreur : L\'adresse email semble invalide';
$messages['noreject'] = 'Veuillez entrer un message à envoyer pour les emails rejetés';
$messages['vacnoperiod'] = 'Veuillez entrer un nombre de jours pour la période durant laquelle le message ne sera pas renvoyé à la même personne.';
$messages['vacperiodwrongformat'] = 'Erreur : La période doit être un nombre supérieir à 1';
$messages['vacnomsg'] = 'Veuillez entrer du texte pour votre message';
$messages['notifynomethod'] = 'Veuillez entrer la méthode par laquellela notification doit être envoyé';
$messages['notifynomsg'] = 'veuillez entrer du texte pour votre message';
$messages['sieveruleexp'] = 'Veuillez définir une ou plusieurs règles pour le filtre. Les filtres sont exécutés dans l\'ordre dans lequel ils apparaissent sur la gauche de l\'écran. Si un filtre est exécuté, plus aucun autre filtre ne sera testé.';
$messages['sieveruleexp_stop'] = 'Veuillez définir une ou plusieurs règles pour le filtre. Les filtres sont exécutés dans l\'ordre dans lequel ils apparaissent sur la gauche de l\'écran, et ce, jusqu\'à ce qu\'une action d\'arrêt des filtres soit exécutée.';
$messages['sieveactexp'] = 'Veuillez définir une ou plusieurs actions ci-dessous. Ces actions seront exécutés pour chaque message qui correspondra au règles ci-dessus.';
$messages['sieveheadershlp'] = 'Voici ci-dessous une liste d\'exemple d\'entête que vous pouvez utilisez dans votre règle. Sélectionnez-en une pour l\'ajouter à la règle ou entrez-en une manuellement dans le champs texte ci-dessous.';
$messages['movingfilter'] = 'Déplacement du filtre...';
$messages['noexistingfilters'] = 'Aucun filtre détecté!';
$messages['importdefault'] = '<b>Utiliser les filtres par défaut : </b>Il y a des filtres disponibles. Voulez-vous utiliser ces filtres ?';
$messages['importother'] = '<b>Importer des filtres : </b>Un autre set de filtres de %s a été trouvé. Voulez-vous importer ces filtres dans votre profil ?';
$messages['switchtoadveditor'] = 'Changer pour l\'éditeur avancé vous permet de modifier le fichier sieve directement. Tout changement ici peut le rendre illisible pour l\'édteur normal et peut être perdu quand les filtres sont enregistré avec l\'édteur normal. Voulez-vous continuer ?';
$messages['filterimported'] = 'Importation des filtres effectuée.';
$messages['filterimporterror'] = 'Impossible d\'importer les filtres. Une erreur serveur a eu lieu';
$messages['notifyinvalidmethod'] = 'La méthode ne semble pas être écrite dans un format valide, elle doit être une URI. Par exemple : \'mailto:alert@exemple.com\'';
$messages['nobodycontentpart'] = 'Veuillez entrer un contenu à tester';
$messages['badoperator'] = 'Désolé, l\'opérateur que vous avez sélectionner ne peut pas être utilisé pour cette règle';
$messages['filteractionerror'] = 'L\'action demandée n\'est pas supportée par le serveur';
$messages['filtermissingerror'] = 'Impossible de trouver la règle demandée';
$messages['contentpartexp'] = 'Le MIME-type our la partie spécifique du message qui doit être testé. Par exemple : `message/rfc822`, `text/html`, `audio/mp3` ou `image`.';
$messages['delrulesetconf'] = 'Êtes vous sûr de vouloir effacer ce groupe de règles ?';
$messages['rulesetexists'] = 'Un groupe de règles porte déjà ce nom. Veuillez en choisir un autre.';
$messages['copyexisting'] = '<b>Copie d\'un groupe de règles éxistant :</b> Voulez vous copier les filtres d\'un groupe de règles éxistant dans le groupe courant ?';
$messages['filtercopied'] = 'Filtre copié avec succès';
$messages['nosieverulesets'] = 'Aucun groupe de règles trouvé.';
$messages['baddateformat'] = 'Erreur: Veuillez entrer une date sous la forme AAAA-MM-JJ';
$messages['badtimeformat'] = 'Erreur: Veuillez entrer une heure sous la forme HH:MM:SS';

?>