<?php
/* Author: Samu Juvonen */

$labels = array();
$labels['filters'] = 'Suotimet';
$labels['managefilters'] = 'Hallitse viestisuotimia';
$labels['filtername'] = 'Suotimen nimi';
$labels['disablerule'] = 'Poista käytöstä';
$labels['disabled'] = 'Ei käytössä';
$labels['newfilter'] = 'Uusi suodin';
$labels['moveup'] = 'Siirrä ylös';
$labels['movedown'] = 'Siirrä alas';
$labels['filterallof'] = 'täsmää kaikkiin sääntöihin';
$labels['filteranyof'] = 'täsmää johonkin säännöistä';
$labels['filterany'] = 'kaikki viestit';
$labels['filtercontains'] = 'Sisältää';
$labels['filternotcontains'] = 'Ei sisällä';
$labels['filteris'] = 'Sama kuin';
$labels['filterisnot'] = 'Ei ole sama kuin';
$labels['filterexists'] = 'On olemassa';
$labels['filternotexists'] = 'Ei ole olemassa';
$labels['filterregex'] = 'Täsmää säännölliseen lausekkeeseen';
$labels['filternotregex'] = 'Ei täsmää säännölliseen lausekkeeseen';
$labels['filterunder'] = 'Vähemmän kuin';
$labels['filterover'] = 'Enemmän kuin';
$labels['filterbefore'] = 'Ennen';
$labels['filterafter'] = 'Jälkeen';
$labels['filteradvoptions'] = 'Lisää vaihtoehtoja...';
$labels['spamtest'] = 'Spammin todennäköisyys';
$labels['operator'] = 'Operaattori';
$labels['comparator'] = 'Vertailu';
$labels['isgreaterthan'] = 'Suurempi kuin';
$labels['isgreaterthanequal'] = 'Suurempi tai yhtä suuri kuin';
$labels['islessthan'] = 'Vähemmän kuin';
$labels['islessthanequal'] = 'Vähemmän tai yhtä suuri kuin';
$labels['equals'] = 'Yhtä suuri kuin';
$labels['notequals'] = 'Ei ole yhtä suuri';
$labels['countisgreaterthan'] = 'Lukumäärä suurempi';
$labels['countisgreaterthanequal'] = 'Lukumäärä suurempi tai yhtä suuri';
$labels['countislessthan'] = 'Lukumäärä pienempi';
$labels['countislessthanequal'] = 'Lukumäärä pienempi tai yhtä suuri';
$labels['countequals'] = 'Lukumäärä yhtä suuri';
$labels['countnotequals'] = 'Lukumäärä erisuuri';
$labels['valueisgreaterthan'] = 'Arvo suurempi';
$labels['valueisgreaterthanequal'] = 'Arvo suurempi tai yhtä suuri';
$labels['valueislessthan'] = 'Arvo pienempi';
$labels['valueislessthanequal'] = 'Arvo pienempi tai yhtä suuri';
$labels['valueequals'] = 'Arvo on yhtä suuri';
$labels['valuenotequals'] = 'Arvo on eri suuri';
$labels['userpart'] = 'Käyttäjäosa täsmää';
$labels['notuserpart'] = 'Käyttäjäosa ei täsmää';
$labels['detailpart'] = 'Lisätiedot täsmäävät';
$labels['notdetailpart'] = 'Lisätiedot eivät täsmää';
$labels['domainpart'] = 'Domain täsmää';
$labels['notdomainpart'] = 'Domain ei täsmää';
$labels['teststring'] = 'Verrattava arvo';
$labels['messagemoveto'] = 'Siirrä viesti kansioon';
$labels['messageredirect'] = 'Uudelleenohjaa osoitteeseen';
$labels['messageimapflags'] = 'Vaihda viestin tila';
$labels['messagereject'] = 'Hylkää viestillä';
$labels['messagevacation'] = 'Poissaoloviesti';
$labels['messagekeep'] = 'Säilytä viesti';
$labels['messagediscard'] = 'Hylkää viesti';
$labels['messagenotify'] = 'Lähetä ilmoitus';
$labels['messagestop'] = 'Keskeytä suotimien suoritus';
$labels['messagehelp'] = 'Mikä tämä on?';
$labels['sieveorigsubj'] = 'Lisää alkuperäinen otsikko vastauksen loppuun';
$labels['sievevachandle'] = 'Handle';
$labels['method'] = 'Method';
$labels['options'] = 'Asetukset';
$labels['messagesrules'] = 'Suotimen säännöt';
$labels['messagesactions'] = 'Suotimen toiminnot';
$labels['sieveto'] = 'Aliakset';
$labels['sievefrom'] = 'Lähettäjä';
$labels['flag'] = 'Tärkeys';
$labels['importancen'] = 'Ei mitään';
$labels['importance1'] = 'Korkea';
$labels['importance2'] = 'Tavallinen';
$labels['importance3'] = 'Alhainen';
$labels['flagread'] = 'Luettu';
$labels['flagdeleted'] = 'Poistettu';
$labels['flaganswered'] = 'Vastattu';
$labels['flagdraft'] = 'Luonnos';
$labels['flagflagged'] = 'Merkitty';
$labels['addsieverule'] = 'Lisää uusi sääntö alle';
$labels['addsieveact'] = 'Lisää uusi toiminto alle';
$labels['deletesieverule'] = 'Poista sääntö';
$labels['deletesieveact'] = 'Poista toiminto';
$labels['envelopefrom'] = 'Lähettäjä (envelope)';
$labels['envelopeto'] = 'Vastaanottaja (envelope)';
$labels['otherheader'] = 'Muu otsikkotieto';
$labels['period'] = 'Aikaväli';
$labels['message'] = 'Viesti';
$labels['sieveruleheaders'] = 'Katso esimerkkejä muista otsikkotiedoista';
$labels['examplefilters'] = 'Esimerkkejä';
$labels['importfilters'] = 'Tuo suotimet';
$labels['usedefaultfilter'] = 'Käytä oletussuotimia';
$labels['importfilter'] = 'Tuo suotimet';
$labels['moreactions'] = 'Lisää asetuksia...';
$labels['adveditor'] = 'Laajennettu editori';
$labels['stdeditor'] = 'Tavallinen editori';
$labels['messageredirectcopy'] = 'Lähetä kopio osoitteeseen';
$labels['messagecopyto'] = 'Kopioi viesti kansioon';
$labels['body'] = 'Viesti';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raaka';
$labels['text'] = 'Teksti';
$labels['other'] = 'Muu';
$labels['bodycontentpart'] = 'Sisältöosa';
$labels['spamnotchecked'] = 'Ei tarkistettu';
$labels['spamlevelisgreaterthanequal'] = 'Korkeampi tai yhtä korkea kuin';
$labels['spamlevelislessthanequal'] = 'Matalampi tai yhtä korkea kuin';
$labels['spamlevelequals'] = 'Yhtä korkea';
$labels['i;ascii-casemap'] = 'Kirjainkoosta riippumaton merkkijonovertailu';
$labels['i;octet'] = 'Täydellinen merkkijonon vastaavuus';
$labels['i;ascii-numeric'] = 'Numeerinen vastaavuus';
$labels['selectruleset'] = 'Valitse säännöstö';
$labels['activeruleset'] = '%s (aktiivinen)';
$labels['activateruleset'] = 'Ota säännöstö käyttöön';
$labels['newruleset'] = 'Luo uusi säännöstö';
$labels['delruleset'] = 'Poista säännöstö';
$labels['renameruleset'] = 'Nimeä säännöstö uudelleen';
$labels['copy'] = 'Kopioi';
$labels['copyexistingfilter'] = 'Kopioi nykyiset suotimet';
$labels['copytoruleset'] = 'Kopioi suodin uuteen säännöstöön';
$labels['copyfromruleset'] = 'Kopioi suotimia vanhasta säännöstöstä';
$labels['time'] = 'Aika';
$labels['weekday'] = 'Viikonpäivä';

$messages = array();
$messages['nosieverules'] = 'Suotimia ei löytynyt.';
$messages['filterdeleteconfirm'] = 'Haluatko varmasti poistaa tämän suotimen?';
$messages['ruledeleteconfirm'] = 'Haluatko varmasti poistaa tämän säännön?';
$messages['actiondeleteconfirm'] = 'Haluatko varmasti poistaa tämän toiminnon?';
$messages['filterunknownerror'] = 'Tuntematon palvelinvirhe';
$messages['filterconnerror'] = 'Unable to connect to sieve server';
$messages['filterdeleteerror'] = 'Palvelinvirhe. Suodinta ei poistettu.';
$messages['filterdeleted'] = 'Suodin poistettu onnistuneesti';
$messages['filtersaved'] = 'Suodin tallennettu onnistuneesti';
$messages['filtersaveerror'] = 'Palvelinvirhe. Suodinta ei tallennettu.';
$messages['vacperiodexp'] = 'Aikaväli on päivien määrä, jona aikana viestiä ei lähetetä samalle käyttäjälle välittämättä siitä, kuinka usein he ottavat sinuun yhteyttä.<br/><br/>Esimerkki: Jaakko lähettää sinulle sähköpostia maanantaina ja aikaväliksi on valittu 7 päivää. Jaakko saa poissaoloviestisi maanantaina, mutta jos hän lähettää sinulle samalla viikolla lisää viestejä, uutta ilmoitusta ei lähetetä ennen seuraavaa maanantaita.';
$messages['vachandleexp'] = 'Ryhmittelyä voidaan käyttää yhdistämään eri poissaoloviestit toisiinsa. Kun yksi viesti on lähetetty, muita saman ryhmittelyn viestejä ei lähetetä kyseisen aikavälin aikana.';
$messages['vactoexp'] = 'Lista muista vastaanottajien sähköpostiosoitteista, jotka liitetään automaattivastaukseen. Mikäli viestin vastaanottaja ei ole pääosoitteesi eikä löydy tältä listalta, mitään viestiä ei lähetetä.';
$messages['vactoexp_adv'] = 'Erottele aliakset pilkulla (,). Esimerkki: testi1@esimerkki.fi,testi2@esimerkki.fi,testi3@esimerkki.fi';
$messages['vactoexp_err'] = 'Virhe: aliakset tulee erotella pilkulla (,)';
$messages['norulename'] = 'Anna suotimelle nimi';
$messages['ruleexists'] = 'Tällä nimellä on jo suodin. Anna uusi nimi';
$messages['noheader'] = 'Anna testattavan otsikkotiedon nimi';
$messages['headerbadchars'] = 'Virhe: otsikkotiedossa on kiellettyjä merkkejä';
$messages['noheadervalue'] = 'Anna arvo, jolla otsikkotietoa testataan';
$messages['sizewrongformat'] = 'Virhe: viestin koon täytyy olla numeerinen';
$messages['noredirect'] = 'Anna osoite, johon viestit ohjataan';
$messages['redirectaddresserror'] = 'Virhe: osoite ei ole kelvollinen';
$messages['noreject'] = 'Anna viesti, joka liitetään hylättyyn sähköpostiin';
$messages['vacnoperiod'] = 'Ilmoita aikaväli (päivien määrä), jona samalle henkilölle ei lähetetä uutta viestiä.';
$messages['vacperiodwrongformat'] = 'Virhe: aikavälin täytyy olla suurempi tai yhtä suuri luku kuin 1';
$messages['vacnomsg'] = 'Kirjoita viestiisi jotain sisältöä';
$messages['notifynomethod'] = 'Määrittele metodi, jota käyttäen ilmoitus lähetetään.';
$messages['notifynomsg'] = 'Kirjoita viestiisi jotain sisältöä';
$messages['sieveruleexp'] = 'Määrittele yksi tai useampia sääntöjä, joihin jokaista viestiä testataan. Suotimet suoritetaan siinä järjestyksessä, jossa ne esiintyvät vasemmalla olevalla listalla. Kun jokin suotimista täsmää, loppuja suotimia ei suoriteta.';
$messages['sieveruleexp_stop'] = 'Määrittele yksi tai useampia sääntöjä, joihin jokaista viestiä testataan. Suotimet suoritetaan siinä järjestyksessä, jossa ne esiintyvät vasemmalla olevalla listalla, kunnes keskeytyssääntö tavataan.';
$messages['sieveactexp'] = 'Valitse jokin alla olevista vaihtoehdoista. Toiminnot suoritetaan kaikille viesteille, jotka täsmäävät yllä oleviin sääntöihin.';
$messages['sieveheadershlp'] = 'Alla on esimerkkejä otsikkotiedoista, joita voidaan testata suotimilla. Valitse jokin otsikkotieto listasta tai määrittele muu otsikkotieto yllä olevaan kenttään.';
$messages['movingfilter'] = 'Siirretään suodinta...';
$messages['noexistingfilters'] = 'Suotimia ei löytynyt!';
$messages['importdefault'] = '<b>Käytä oletussuotimia:</b> Suotimia on saatavilla. Haluatko käyttää näitä suotimia?';
$messages['importother'] = '<b>Tuo suotimia:</b> Suotimia löydettiin palvelusta %s. Haluatko lisätä nämä suotimet nykyisiin suotimiin?';
$messages['switchtoadveditor'] = 'Laajennetulla editorilla voit muokata seulatiedostoa suoraan. Tehdyt muutokset eivät välttämättä ole luettavissa tavallisessa editorissa ja saattavat hävitä, jos suotimia muokataan tavallisella editorilla. Haluatko jatkaa?';
$messages['filterimported'] = 'Suodin lisätty onnistuneesti';
$messages['filterimporterror'] = 'Palvelinvirhe. Suotimia ei lisätty';
$messages['notifyinvalidmethod'] = 'Metodi ei ole kelvollisessa muodossa. Sen täytyy olla osoite. Esimerkki: mailto:virhe@esimerkki.fi';
$messages['nobodycontentpart'] = 'Anna testattava sisältöosa';
$messages['badoperator'] = 'Valitsemaasi operaattoria ei voida käyttää tässä säännössä';
$messages['filteractionerror'] = 'Palvelin ei tue valitsemaasi toimintoa';
$messages['filtermissingerror'] = 'Valittua sääntöä ei löytynyt';
$messages['contentpartexp'] = 'MIME-tyyppi tai tietty viestin osa, jota testataan. Esimerkki: "message/rfc822", "text/html", "audio/mp3" tai "image"';
$messages['delrulesetconf'] = 'Haluatko varmasti poistaa tämän säännöstön?';
$messages['rulesetexists'] = 'Tällä nimellä on jo säännöstö. Anna uusi nimi';
$messages['copyexisting'] = '<b>Kopioi säännöstö:</b> Haluatko kopioida toisen säännöstön nykyisiin sääntöihisi?';
$messages['filtercopied'] = 'Suodin kopioitu onnistuneesti';
$messages['nosieverulesets'] = 'Säännöstöä ei löytynyt.';
$messages['baddateformat'] = 'Virhe: anna päivämäärä muodossa VVVV-KK-PP';
$messages['badtimeformat'] = 'Virhe: anna aika muodossa TT:MM:SS';
$messages['missingfoldername'] = 'Virhe: anna kansiolle nimi';

?>