<?php
/* Author: Ovidiu Bica */

$labels = array();
$labels['filters'] = 'Filtre';
$labels['managefilters'] = 'Administrează filtrele';
$labels['filtername'] = 'Nume filtru';
$labels['disablerule'] = 'Dezactivează regula';
$labels['disabled'] = 'Dezactivat';
$labels['newfilter'] = 'Filtru nou';
$labels['moveup'] = 'Mută sus';
$labels['movedown'] = 'Mută jos';
$labels['filterallof'] = 'îndeplineşte toate regulile de mai jos';
$labels['filteranyof'] = 'îndeplineşte oricare regula de mai jos';
$labels['filterany'] = 'toate mesajele';
$labels['filtercontains'] = 'conţine';
$labels['filternotcontains'] = 'nu conţine';
$labels['filteris'] = 'este egal cu';
$labels['filterisnot'] = 'nu este egal cu';
$labels['filterexists'] = 'există';
$labels['filternotexists'] = 'nu există';
$labels['filterregex'] = 'indeplineşte expresia';
$labels['filternotregex'] = 'nu indeplineşte expresia';
$labels['filterunder'] = 'este mai puţin de';
$labels['filterover'] = 'este mai mult de';
$labels['filteradvoptions'] = 'mai multe opţiuni';
$labels['spamtest'] = 'Probabilitate de spam';
$labels['operator'] = 'Operator';
$labels['comparator'] = 'Comparator';
$labels['isgreaterthan'] = 'este mai mare de';
$labels['isgreaterthanequal'] = 'este mai mare sau egal cu';
$labels['islessthan'] = 'este mai mic de';
$labels['islessthanequal'] = 'este mai mic sau egal cu';
$labels['equals'] = 'este egal cu';
$labels['notequals'] = 'nu este egal';
$labels['countisgreaterthan'] = 'numărul este mai mare de';
$labels['countisgreaterthanequal'] = 'numărul este mai mare sau egal cu';
$labels['countislessthan'] = 'numărul este mai mic de';
$labels['countislessthanequal'] = 'numărul este mai mic sau egal cu';
$labels['countequals'] = 'numărul este egal cu';
$labels['countnotequals'] = 'numărul nu este egal cu';
$labels['valueisgreaterthan'] = 'valoarea este mai mare de';
$labels['valueisgreaterthanequal'] = 'valoarea este mai mare sau egală cu';
$labels['valueislessthan'] = 'valoarea este mai mică de';
$labels['valueislessthanequal'] = 'valoarea este mai mică sau egală cu';
$labels['valueequals'] = 'valoarea este egala cu';
$labels['valuenotequals'] = 'valoarea nu este egală';
$labels['userpart'] = 'utilizatorul este';
$labels['notuserpart'] = 'utilizatorul nu este';
$labels['detailpart'] = 'detaliul este';
$labels['notdetailpart'] = 'detaliul nu este';
$labels['domainpart'] = 'domeniul este';
$labels['notdomainpart'] = 'domeniul nu este';
$labels['teststring'] = 'mesaj de test';
$labels['messagemoveto'] = 'Mută mesajul în';
$labels['messageredirect'] = 'Redirectionează mesajul la';
$labels['messageimapflags'] = 'Marchează mesajul ca';
$labels['messagereject'] = 'Refuză mesajul cu';
$labels['messagevacation'] = 'Mesaj - Plecat din birou';
$labels['messagekeep'] = 'Păastrează mesajul';
$labels['messagediscard'] = 'Refuză mesajul';
$labels['messagenotify'] = 'Trimite notificare';
$labels['messagestop'] = 'Opreşte procesarea filtrelor';
$labels['messagehelp'] = 'Ce este asta?';
$labels['sieveorigsubj'] = 'Atasează subiectul original la răspuns';
$labels['sievevachandle'] = 'Foloseşte';
$labels['method'] = 'Metodă';
$labels['options'] = 'Opţiuni';
$labels['messagesrules'] = 'Reguli filtrare';
$labels['messagesactions'] = 'Acţiuni filtrare';
$labels['sieveto'] = 'Sinonime';
$labels['sievefrom'] = 'De la';
$labels['flag'] = 'Importanţă';
$labels['importancen'] = 'Nici unul';
$labels['importance1'] = 'Mare';
$labels['importance2'] = 'Normal';
$labels['importance3'] = 'Scăzut';
$labels['flagread'] = 'Citit';
$labels['flagdeleted'] = 'Şters';
$labels['flaganswered'] = 'Răspuns';
$labels['flagdraft'] = 'Ciornă';
$labels['flagflagged'] = 'Marcat';
$labels['addsieverule'] = 'Adaugă o nouă regulă sub aceasta';
$labels['addsieveact'] = 'Adaugă o nouă acţiune sub aceasta';
$labels['deletesieverule'] = 'Şterge această regulă';
$labels['deletesieveact'] = 'Şterge această acţiune';
$labels['envelopefrom'] = 'Mesaj de la';
$labels['envelopeto'] = 'Mesaj către';
$labels['otherheader'] = 'Alt cuprins';
$labels['period'] = 'Perioadă';
$labels['message'] = 'Mesaj';
$labels['sieveruleheaders'] = 'Vezi exemple de alte cuprinsuri';
$labels['examplefilters'] = 'Exemple de filtre';
$labels['importfilters'] = 'Importa filtre';
$labels['usedefaultfilter'] = 'Foloseste filtre implicite';
$labels['importfilter'] = 'Importa filtru';
$labels['adveditor'] = 'Editor avansat';
$labels['messageredirectcopy'] = 'Trimite o copie către';
$labels['messagecopyto'] = 'Copiază mesajul către';
$labels['body'] = 'Conţinut';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Brut';
$labels['text'] = 'Text';
$labels['other'] = 'Altul';
$labels['bodycontentpart'] = 'Conţinut';
$labels['notchecked'] = 'neverificat';
$labels['spamlevelisgreaterthanequal'] = 'este mai mare sau egal cu';
$labels['spamlevelislessthanequal'] = 'este mai mic sau egal cu';
$labels['spamlevelequals'] = 'este egal cu';
$labels['i;ascii-casemap'] = 'potrivire caractere mici/mari';
$labels['i;octet'] = 'potrivire exactă';
$labels['i;ascii-numeric'] = 'potrivire numerică';
$labels['selectruleset'] = 'Selectează setul de reguli';
$labels['activeruleset'] = '%s (activ)';
$labels['activateruleset'] = 'Activează acest set de reguli';
$labels['newruleset'] = 'Crează un nou set de reguli';
$labels['delruleset'] = 'Sterge acest set de reguli';
$labels['renameruleset'] = 'Redenumeşte acest set de reguli';
$labels['copy'] = 'Copiază';
$labels['copyexistingfilter'] = 'Copiază filtre existente';
$labels['copytoruleset'] = 'Copiază filtrul la un alt set de reguli';
$labels['copyfromruleset'] = 'Copiază filtrele de la un set de reguli existent';

$messages = array();
$messages['nosieverules'] = 'Nu a fost găsit niciun filtru.';
$messages['filterdeleteconfirm'] = 'Eşti sigur că doreşti să ştergi acest filtru?';
$messages['ruledeleteconfirm'] = 'Eşti sigur că doreşti să ştergi această regulă?';
$messages['actiondeleteconfirm'] = 'Eşti sigur că doreşti să ştergi această acţiune?';
$messages['filterunknownerror'] = 'Eroare de server necunoscută.';
$messages['filterconnerror'] = 'Nu m-am putut conecta la serverul Sieve.';
$messages['filterdeleteerror'] = 'Nu am putut şterge filtrul. Eroare de server.';
$messages['filterdeleted'] = 'Filtru şters cu succes.';
$messages['filtersaved'] = 'Filtru salvat cu succes.';
$messages['filtersaveerror'] = 'Nu am putut salva filtrul. Eroare de server.';
$messages['vacperiodexp'] = 'Perioada este numărul de zile în care mesajul nu va fi retrimis persoanei indiferent de câte ori te va contacta.<br /><br />De exemplu: Dacă Ion iţi trimite un email luni şi perioada este setată la 7 zile, atunci Ion va primi un mesaj OUT of OFFICE luni însă nu va mai primi niciunul pana lunea următoare indiferent de câte mesaje îţi va trimite.';
$messages['vachandleexp'] = 'Poate fi folosită o regulă pentru a lega mesaje OUT of OFFICE împreună. Odată trimis un mesaj, nu va mai fi trimis niciun mesaj cu aceeasi regulă.';
$messages['vactoexp'] = 'Lista adreselor de email aditionale care vor fi incluse in raspunsul automat. ';
$messages['norulename'] = 'Te rog sa introduci un nume pentru acest filtru.';
$messages['ruleexists'] = 'Un filtru cu acest nume există deja. Te rog să introduci altul.';
$messages['noheader'] = 'Te rog să introduci numele headerului pentru verificare.';
$messages['headerbadchars'] = 'Eroare: Headerul conţine caractere ilegale.';
$messages['noheadervalue'] = 'Te rog să introduci o valoare pentru a testa headerul.';
$messages['sizewrongformat'] = 'Eroare: Mărimea mesajului trebuie să fie numerică .';
$messages['noredirect'] = 'Te rog să introduci o adresă de email pentru a redirecţiona mesajele.';
$messages['redirectaddresserror'] = 'Eroare: Adresa nu pare să fie validă.';
$messages['noreject'] = 'Te rog să introduci un mesaj pentru a fi trimis impreună cu mesajul de respingere.';
$messages['vacnoperiod'] = 'Te rog să introduci o perioadă de zile în care mesaju';
$messages['vacperiodwrongformat'] = 'Eroare: Perioada trebuie să fie un număr mai mare sau egal cu 1.';
$messages['vacnomsg'] = 'Te rog să introduci un text pentru mesaj.';
$messages['notifynomethod'] = 'Te rog să introduci o metodă prin care să se trimită notificarea.';
$messages['notifynomsg'] = 'Te rog să introduci un text pentru mesaj.';
$messages['sieveruleexp'] = 'Te rog să introduci una sau mai multe reguli prin care va fi testat fiecare mesaj. Filtrele sunt aplicate în ordinea în care apar în stânga ecranului. Dacă este găsită o potrivire, niciun alt filtru nu va mai fi testat.';
$messages['sieveruleexp_stop'] = 'Te rog să introduci una sau mai multe reguli prin care va fi testat fiecare mesaj. Filtrele sunt aplicate în ordinea în care apar în stânga ecranului până câand este găsită o acţiune de stopare.';
$messages['sieveactexp'] = 'Te rog sa selectezi una din opţiunile de mai jos. Aceste acţiuni vor fi efectuate pentru orice mesaj ce se potriveşte regulilor de mai jos.';
$messages['sieveheadershlp'] = 'Mai jos aveţi exemple de alte headere ce pot fi testate de către filtre. Selectează un header pentru a-l adăuga la regulă sau introdu una proprie în câmpul de mai sus.';
$messages['movingfilter'] = 'Se mută filtrul ...';
$messages['noexistingfilters'] = 'Nici un filtru existent ...';
$messages['importdefault'] = '<b>Foloseşte filtrele implicite:</b>Există un set de filtre implicite. Doreşti să foloseşti aceste filtre?';
$messages['importother'] = '<b>Importă filtre</b> Un alt set de filtre de la %s a fost găsit. Doreşti să imporţi aceste filtre in setul tău curent?';
$messages['switchtoadveditor'] = 'Trecerea la editorul avansat iti permite să editezi fişierul sieve direct. Orice modificare faci aici poate fi de nedescifrat in editorul normal si poate fi pierdută atunci când filtrele sunt salvate folosind editorul normal. Doreşti să continui?';
$messages['filterimported'] = 'Filtrul importat cu succes?';
$messages['filterimporterror'] = 'Imposibil de importat filtrul. Eroare de server.';
$messages['notifyinvalidmethod'] = 'Metoda nu pare a fi scrisă într-un format valid, trebuie să fie un URL. De ex. `mailto:ion@exemplu.com`';
$messages['nobodycontentpart'] = 'Te rog să introduci un conţinut de probă.';
$messages['badoperator'] = 'Îmi pare rău, operatorul selectat nu poate fi folosit în această regulă.';
$messages['filteractionerror'] = 'Acţiunea cerută nu este suportată de server.';
$messages['filtermissingerror'] = 'Imposibil de găsit regula cerută.';
$messages['contentpartexp'] = 'Tipul MIME-Type sau o parte specifica din mesajul ce trebuie testat. De ex. `message/rfc822`, `text/html`, `audio/mp3` sau `image`.';
$messages['delrulesetconf'] = 'Eşti sigur că doreşti să ştergi acest set de reguli?';
$messages['rulesetexists'] = 'Un set de reguli cu acest nume există deja. Introdu altul.';
$messages['copyexisting'] = '<b>Copiază setul de reguli existent:</b> Doreşti să copiezi filtrele dintr-un set de reguli existent in setul tău curent?';
$messages['filtercopied'] = 'Filtrul copiat cu succes.';
$messages['nosieverulesets'] = 'Niciun set de reguli găsit.';

?>