<?php
/* Author: Jernej Simončič */

$labels = array();
$labels['filters'] = 'Pravila';
$labels['managefilters'] = 'Upravljal pravila';
$labels['filtername'] = 'Ime';
$labels['disablerule'] = 'Onemogoči pravilo';
$labels['disabled'] = 'Onemogočeno';
$labels['newfilter'] = 'Novo pravilo';
$labels['moveup'] = 'Premakni višje';
$labels['movedown'] = 'Premakni nižje';
$labels['filterallof'] = 'sporočilo zadošča vsem pogojem';
$labels['filteranyof'] = 'sporočilo zadošča kateremukoli od pogojev';
$labels['filterany'] = 'vsa sporočila';
$labels['filtercontains'] = 'vsebuje';
$labels['filternotcontains'] = 'ne vsebuje';
$labels['filteris'] = 'je enak';
$labels['filterisnot'] = 'ni enak';
$labels['filterexists'] = 'obstaja';
$labels['filternotexists'] = 'ne obstaja';
$labels['filterregex'] = 'ustreza regularnemu izrazu';
$labels['filternotregex'] = 'ne ustreza regularnemu izrazu';
$labels['filterunder'] = 'je manj kot';
$labels['filterover'] = 'je več kot';
$labels['filterbefore'] = 'je pred';
$labels['filterafter'] = 'je po';
$labels['filteradvoptions'] = 'več možnosti...';
$labels['spamtest'] = 'spam verjetnost';
$labels['operator'] = 'Operater';
$labels['comparator'] = 'Primerjava';
$labels['isgreaterthan'] = 'je večje kot';
$labels['isgreaterthanequal'] = 'je večje ali enako';
$labels['islessthan'] = 'je manjše kot';
$labels['islessthanequal'] = 'je manjše ali enako';
$labels['equals'] = 'je enako';
$labels['notequals'] = 'ni enako';
$labels['countisgreaterthan'] = 'število je večje kot';
$labels['countisgreaterthanequal'] = 'število je večje ali enako';
$labels['countislessthan'] = 'število je manjše kot';
$labels['countislessthanequal'] = 'število je manjše ali enako';
$labels['countequals'] = 'število je enako';
$labels['countnotequals'] = 'število ni enako';
$labels['valueisgreaterthan'] = 'vrednost je večja kot';
$labels['valueisgreaterthanequal'] = 'vrednost je večja ali enaka';
$labels['valueislessthan'] = 'vrednost je manjša kot';
$labels['valueislessthanequal'] = 'vrednost je manjša ali enaka';
$labels['valueequals'] = 'vrednost je enaka';
$labels['valuenotequals'] = 'vrednost ni enaka';
$labels['userpart'] = 'uporabniški del naslova je enak';
$labels['notuserpart'] = 'uporabniški del naslova ni enak';
$labels['detailpart'] = 'podrobni del naslova je enak';
$labels['notdetailpart'] = 'podrobni del naslova ni enak';
$labels['domainpart'] = 'domena je enaka';
$labels['notdomainpart'] = 'domena ni enaka';
$labels['teststring'] = 'Vzorčno besedilo';
$labels['messagemoveto'] = 'Premakni sporočilo v';
$labels['messageredirect'] = 'Preusmeri sporočilo';
$labels['messageimapflags'] = 'Označi sporočilo kot';
$labels['messagereject'] = 'Zavrni s sporočilom';
$labels['messagevacation'] = 'Samodejni odgovor';
$labels['messagekeep'] = 'Ohrani sporočilo';
$labels['messagediscard'] = 'Zavrzi sporočilo';
$labels['messagenotify'] = 'Pošlji obvestilo';
$labels['messagestop'] = 'Prenehaj z izvajanjem pravil';
$labels['messagehelp'] = 'Kaj je to?';
$labels['sieveorigsubj'] = 'Pripni originalno zadevo k odgovoru';
$labels['sievevachandle'] = 'Vzdevek';
$labels['method'] = 'Metoda';
$labels['options'] = 'Možnosti';
$labels['messagesrules'] = 'Pogoji';
$labels['messagesactions'] = 'Dejanja';
$labels['sieveto'] = 'Drugi prejemniki';
$labels['sievefrom'] = 'Od';
$labels['flag'] = 'Pomembnost';
$labels['importancen'] = 'Brez';
$labels['importance1'] = 'Visoka';
$labels['importance2'] = 'Običajna';
$labels['importance3'] = 'Nizka';
$labels['flagread'] = 'Prebrano';
$labels['flagdeleted'] = 'Izbrisano';
$labels['flaganswered'] = 'Odgovorjeno';
$labels['flagdraft'] = 'Osnutek';
$labels['flagflagged'] = 'Zastavica';
$labels['addsieverule'] = 'Dodaj novo pravilo';
$labels['addsieveact'] = 'Dodaj novo dejanje';
$labels['deletesieverule'] = 'Izbriši to pravilo';
$labels['deletesieveact'] = 'Izbriši to dejanje';
$labels['envelopefrom'] = 'Pošiljatelj ovojnice';
$labels['envelopeto'] = 'Prejemnik ovojnice';
$labels['otherheader'] = 'Druga polja';
$labels['period'] = 'Ponovitev';
$labels['message'] = 'Sporočilo';
$labels['sieveruleheaders'] = 'Prikaži vzorce polj';
$labels['examplefilters'] = 'Vzorčni filtri';
$labels['importfilters'] = 'Uvozi filtre';
$labels['usedefaultfilter'] = 'Uporabi privzete filtre';
$labels['importfilter'] = 'Uvozi filter';
$labels['moreactions'] = 'Več možnosti...';
$labels['adveditor'] = 'Napredni urejevalnik';
$labels['stdeditor'] = 'Običajni urejevalnik';
$labels['messageredirectcopy'] = 'Pošlji kopijo';
$labels['messagecopyto'] = 'Kopiraj sporočilo v';
$labels['body'] = 'Telo';
$labels['auto'] = 'Samodejno';
$labels['raw'] = 'Surovo';
$labels['text'] = 'Besedilo';
$labels['other'] = 'Drugo';
$labels['bodycontentpart'] = 'Del vsebine';
$labels['notchecked'] = 'ni pregledano';
$labels['spamlevelisgreaterthanequal'] = 'je večja ali enaka';
$labels['spamlevelislessthanequal'] = 'je manjša ali enaka';
$labels['spamlevelequals'] = 'je enaka';
$labels['i;ascii-casemap'] = 'primerjaj brez razlikovanja velikih in malih črk';
$labels['i;octet'] = 'primerjaj z razlikovanjem velikih in malih črk';
$labels['i;ascii-numeric'] = 'primerjaj kot število';
$labels['selectruleset'] = 'Izberi zbirko pravil';
$labels['activeruleset'] = '%s (aktivna)';
$labels['activateruleset'] = 'Aktiviraj to zbirko';
$labels['newruleset'] = 'Ustvari novo zbirko';
$labels['delruleset'] = 'Izbriši to zbirko';
$labels['renameruleset'] = 'Preimenuj to zbirko';
$labels['copy'] = 'Kopiraj';
$labels['copyexistingfilter'] = 'Kopiraj obstoječa pravila';
$labels['copytoruleset'] = 'Kopiraj pravilo v drugo zbirko';
$labels['copyfromruleset'] = 'Kopiraj pravila iz obstoječe zbirke';
$labels['time'] = 'Čas';
$labels['weekday'] = 'Dan v tednu';

$messages = array();
$messages['nosieverules'] = 'Ni pravil.';
$messages['filterdeleteconfirm'] = 'Ali resnično želiš izbrisati to pravilo?';
$messages['ruledeleteconfirm'] = 'Ali resnično želiš izbrisati ta pogoj?';
$messages['actiondeleteconfirm'] = 'Ali resnično želiš izbrisati to dejanje?';
$messages['filterunknownerror'] = 'Neznana napaka strežnika';
$messages['filterconnerror'] = 'Ni se bilo mogoče povezati na strežnik sieve';
$messages['filterdeleteerror'] = 'Ni mogoče izbrisati pravila. Prišlo je do napake strežnika';
$messages['filterdeleted'] = 'Pravilo izbrisano';
$messages['filtersaved'] = 'Pravilo shranjeno';
$messages['filtersaveerror'] = 'Ni mogoče shraniti pravila. Prišlo je do napake strežnika';
$messages['vacperiodexp'] = 'Ponovitev je število dni, ki mora preteči, preden bo sporočilo znova poslano istemu pošiljatelju, ne glede na to, koliko sporočil je poslal v tem času.<br /><br />Npr.: če Janez pošlje sporočilo v ponedeljek, in je ponovitev nastavljena na 7, potem bo dobil odgovor v ponedeljek, še enega pa ne bo dobil pred naslednjim ponedeljkom, ne glede na to, koliko sporočil bo poslal vmes.';
$messages['vachandleexp'] = 'Z vzdevkom se lahko med seboj poveže več različnih samodejnih odgovorov - ko je bil samodejni odgovor z nekim vzdevkom poslan, ne bo v tej ponovitvi poslano noben drug odgovor z istim vzdevkom.';
$messages['vactoexp'] = 'Seznam dodatnih naslovov prejemnikov, ki bodo vključeni pri samodejnem odgovarjanju. Če naslova prejemnika sporočila ni na tem seznamu, samodejni odgovor na sporočilo ne bo poslan.';
$messages['vactoexp_adv'] = 'Naslove ločite z vejicami. Primer: naslov1@example.com,naslov2@example.org,naslov3@example.com';
$messages['vactoexp_err'] = 'Napaka: naslovi morajo biti ločeni z vejicami (,)';
$messages['norulename'] = 'Vnesite ime pravila';
$messages['ruleexists'] = 'Pravilo s tem imenom že obstaja. Vnesite drugo ime';
$messages['noheader'] = 'Vnesite ime polja';
$messages['headerbadchars'] = 'Napaka: polje vsebuje nedovoljene znake';
$messages['noheadervalue'] = 'Vnesite vrednost, s katero se preizkuša polje';
$messages['sizewrongformat'] = 'Napaka: velikost sporočila mora biti število';
$messages['noredirect'] = 'Vnestie e-poštni naslov, na katerega naj se preusmeri sporočilo';
$messages['redirectaddresserror'] = 'Napaka: naslov ni videti veljaven';
$messages['noreject'] = 'Vnesite sporočilo, ki naj se pošlje z zavrnitvijo';
$messages['vacnoperiod'] = 'Vnesite število dni, po preteku katerih se bo samodejni odgovor ponovil';
$messages['vacperiodwrongformat'] = 'Napaka: ponovitev mora biti večja ali enaka 1';
$messages['vacnomsg'] = 'Vnesite besedilo sporočila';
$messages['notifynomethod'] = 'Vnesite metodo, s katero naj bo poslano sporočilo';
$messages['notifynomsg'] = 'Vnesite besedilo sporočila';
$messages['sieveruleexp'] = 'Pripravite enega ali več pogojev, pod katerimi bo to pravilo uveljavljeno. Pravila se izvajajo v vrstnem redu, po katerem so razvrščena na seznamu na levi strani. Če sporočilo ustreza pogojem, se nadaljna pravila ne bodo izvedla.';
$messages['sieveruleexp_stop'] = 'Pripravite enega ali več pogojev, pod katerimi bo to pravilo uveljavljeno. Pravila se izvajajo v vrstnem redu, po katerem so razvrščena na seznamu na levi strani, in se izvajajo do dejanja ›Prenehaj‹.';
$messages['sieveactexp'] = 'Izberite eno od spodnjih možnosti. Ta dejanja se bodo izvedla za vsako sporočilo, ki ustreza zgornjim pravilom.';
$messages['sieveheadershlp'] = 'Spodaj je nekaj primerov drugih polj, ki jih lahko preizkušajo pravila. Izberite polje s seznama, ali pa vnesite poljubno polje.';
$messages['movingfilter'] = 'Premikam pravilo...';
$messages['noexistingfilters'] = 'Obstoječa pravila niso bila zaznana!';
$messages['importdefault'] = '<b>Uporabi privzeta pravila:</b> na voljo so privzeta pravila. Ali jih želite uvoziti?';
$messages['importother'] = '<b>Uvozi filtre:</b> Najdena je bila druga zbirka pravil %s. Ali želite uvoziti ta pravila v trenutno zbirko?';
$messages['switchtoadveditor'] = 'Preklop v napredni urejevalnik omogoča neposredno urejanje datoteke sieve. Sprememb, ki jih naredite v naprednem urejevalniku, običajni urejevalnik morda ne bo razumel, in se lahko izgubijo, če pravila shranite z običajnim urejevalnikom. Ali želite nadaljevati?';
$messages['filterimported'] = 'Pravilo uspešno uvoženo';
$messages['filterimporterror'] = 'Pravila ni bilo mogoče uvoziti. Prišlo je do napake strežnika';
$messages['notifyinvalidmethod'] = 'Metoda mora biti zapisana v URI formatu, npr.: ›mailto:alert@example.com‹.';
$messages['nobodycontentpart'] = 'Vnesite del vsebine za preizkus';
$messages['badoperator'] = 'Izbranega operaterja ne morete uporabiti s tem pravilom';
$messages['filteractionerror'] = 'Strežnik ne podpira željenega dejanja';
$messages['filtermissingerror'] = 'Željenega pravila ni bilo mogoče najti';
$messages['contentpartexp'] = 'MIME vrsta ali specifičen del sporočila, ki naj se testira. Npr.: ›message/rfc822‹, ›text/html‹, ›audio/mp3‹ ali ›image‹.';
$messages['delrulesetconf'] = 'Ali ste prepričani, da želite izbrisati izbrano zbirko?';
$messages['rulesetexists'] = 'Zbirka s tem imenom že obstaja. Vnesite drugo ime';
$messages['copyexisting'] = '<b>Kopiraj obstoječo zbirko:</b> Ali želite kopirati pravila iz obstoječe zbirke v trenutno?';
$messages['filtercopied'] = 'Pravilo uspešno prekopirano';
$messages['nosieverulesets'] = 'Ni zbirk.';
$messages['baddateformat'] = 'Napaka: vnesite datum v obliki LLLL-MM-DD';
$messages['badtimeformat'] = 'Napaka: vnesite čas v obliki UU:MM:SS';

?>