<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sieverules.css" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:object name="steptitle" /></h1>

<div id="preferences-details" class="boxcontent">
<roundcube:object name="sieveruleform" class="propform" helpIcon="/this/images/help.png" />
</div>

<div class="footerleft formbuttons">
<roundcube:button command="plugin.sieverules.save" type="input" class="button mainaction" label="save" />
<roundcube:button command="plugin.sieverules.copy_rule" type="input" class="button" label="sieverules.copy" condition="env:action=='plugin.sieverules.edit' && config:sieverules_multiplerules == true" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>