<?php
/* Author: Beheer */

$labels = array();
$labels['filters'] = 'Filters';
$labels['filtersname'] = 'Filters ($name)';
$labels['managefilters'] = 'Beheer inkomende mail filters';
$labels['filtername'] = 'Filternaam';
$labels['disablerule'] = 'Regel uitschakelen';
$labels['disabled'] = 'Uitgeschakeld';
$labels['newfilter'] = 'Nieuw filter';
$labels['moveup'] = 'Omhoog';
$labels['movedown'] = 'Omlaag';
$labels['filterallof'] = 'die voldoen aan alle volgende regels';
$labels['filteranyof'] = 'die voldoen aan een van de volgende regels';
$labels['filterany'] = 'alle berichten';
$labels['filtercontains'] = 'bevat';
$labels['filternotcontains'] = 'bevat niet';
$labels['filteris'] = 'is gelijk aan';
$labels['filterisnot'] = 'is niet gelijk aan';
$labels['filterexists'] = 'bestaat';
$labels['filternotexists'] = 'bestaat niet';
$labels['filterregex'] = 'voldoet aan reguliere expressie';
$labels['filternotregex'] = 'voldoet niet aan reguliere expressie';
$labels['filterunder'] = 'onder';
$labels['filterover'] = 'over';
$labels['filterbefore'] = 'is voor';
$labels['filterafter'] = 'is na';
$labels['filteradvoptions'] = 'meer opties...';
$labels['spamtest'] = 'Spam waarschijnlijkheid';
$labels['operator'] = 'Operator';
$labels['comparator'] = 'Vergelijker';
$labels['isgreaterthan'] = 'is groter dan';
$labels['isgreaterthanequal'] = 'is groter dan of gelijk aan';
$labels['islessthan'] = 'is minder dan';
$labels['islessthanequal'] = 'is minder dan of gelijk aan';
$labels['equals'] = 'is gelijk aan';
$labels['notequals'] = 'is niet gelijk aan';
$labels['countisgreaterthan'] = 'aantal is groter dan';
$labels['countisgreaterthanequal'] = 'aantal is groter dan of gelijk aan';
$labels['countislessthan'] = 'aantal is kleiner dan';
$labels['countislessthanequal'] = 'aantal is kleiner dan of gelijk aan';
$labels['countequals'] = 'aantal is gelijk aan';
$labels['countnotequals'] = 'aantal is niet gelijk aan';
$labels['valueisgreaterthan'] = 'waarde is groter dan';
$labels['valueisgreaterthanequal'] = 'waarde is groter dan of gelijk aan';
$labels['valueislessthan'] = 'waarde is minder dan';
$labels['valueislessthanequal'] = 'waarde is minder dan of gelijk aan';
$labels['valueequals'] = 'waarde is gelijk aan';
$labels['valuenotequals'] = 'waarde is niet gelijk aan';
$labels['userpart'] = 'gebruikersdeel is gelijk aan';
$labels['notuserpart'] = 'gebruikersdeel is niet gelijk aan';
$labels['detailpart'] = 'detaildeel is gelijk aan';
$labels['notdetailpart'] = 'detaildeel is niet gelijk aan';
$labels['domainpart'] = 'domeindeel is gelijk aan';
$labels['notdomainpart'] = 'domeindeel is niet gelijk aan';
$labels['teststring'] = 'Testwaarde';
$labels['messagemoveto'] = 'Verplaats bericht naar';
$labels['messageredirect'] = 'Verstuur bericht door naar';
$labels['messageimapflags'] = 'Markeer bericht als';
$labels['messagereject'] = 'Weiger met bericht';
$labels['messagevacation'] = 'Afwezigheidsbericht';
$labels['messagekeep'] = 'Bericht behouden';
$labels['messagediscard'] = 'Ontdoen van bericht';
$labels['messagenotify'] = 'Verstuur notificatie';
$labels['messagestop'] = 'Stop filterverwerking';
$labels['messagehelp'] = 'Wat is dit?';
$labels['sieveorigsubj'] = 'Voeg origineel onderwerp toe aan reactie';
$labels['sievevachandle'] = 'Reactienaam (\'handle\')';
$labels['method'] = 'Methode';
$labels['options'] = 'Opties';
$labels['messagesrules'] = 'Filterregels';
$labels['messagesactions'] = 'Filteracties';
$labels['sieveto'] = 'Aliassen';
$labels['sievefrom'] = 'Van';
$labels['flag'] = 'Belangrijkheid';
$labels['importancen'] = 'Geen';
$labels['importance1'] = 'Hoog';
$labels['importance2'] = 'Normaal';
$labels['importance3'] = 'Laag';
$labels['flagread'] = 'Gelezen';
$labels['flagdeleted'] = 'Verwijderd';
$labels['flaganswered'] = 'Beantwoord';
$labels['flagdraft'] = 'Concept';
$labels['flagflagged'] = 'Gemarkeerd';
$labels['addsieverule'] = 'Nieuwe regel onder deze';
$labels['addsieveact'] = 'Nieuwe actie onder deze';
$labels['deletesieverule'] = 'Verwijder deze regel';
$labels['deletesieveact'] = 'Verwijder deze actie';
$labels['envelopefrom'] = 'Envelop Van';
$labels['envelopeto'] = 'Envelop Aan';
$labels['otherheader'] = 'Andere header';
$labels['period'] = 'Periode';
$labels['message'] = 'Bericht';
$labels['sieveruleheaders'] = 'Bekijk voorbeelden van andere headers';
$labels['examplefilters'] = 'Voorbeelden filters';
$labels['importfilters'] = 'Importeer filters';
$labels['usedefaultfilter'] = 'Gebruik standaardfilters';
$labels['importfilter'] = 'Importeer filters';
$labels['moreactions'] = 'Meer opties...';
$labels['adveditor'] = 'Geavanceerde editor';
$labels['stdeditor'] = 'Standaard editor';
$labels['messageredirectcopy'] = 'Verstuur kopie naar';
$labels['messagecopyto'] = 'Kopie bericht naar';
$labels['body'] = 'Bericht';
$labels['auto'] = 'Automatisch';
$labels['raw'] = 'Bron';
$labels['text'] = 'Tekst';
$labels['other'] = 'Anders';
$labels['bodycontentpart'] = 'Inhoudsgedeelte';
$labels['notchecked'] = 'niet gecontroleerd';
$labels['spamlevelisgreaterthanequal'] = 'is groter dan of gelijk aan';
$labels['spamlevelislessthanequal'] = 'is kleiner dan of gelijk aan';
$labels['spamlevelequals'] = 'is gelijk aan';
$labels['i;ascii-casemap'] = 'hoofdlettergevoelige vergelijking';
$labels['i;octet'] = 'exacte vergelijking';
$labels['i;ascii-numeric'] = 'numerieke vergelijking';
$labels['selectruleset'] = 'Selecteer regelset';
$labels['activeruleset'] = '%s (actief)';
$labels['activateruleset'] = 'Activeer deze regelset';
$labels['isactive'] = 'Actieve regelset';
$labels['isinactive'] = 'Inactieve regelset';
$labels['newruleset'] = 'Maak een nieuwe regelset';
$labels['delruleset'] = 'Verwijder deze regelset';
$labels['renameruleset'] = 'Hernoem deze regelset';
$labels['copy'] = 'Kopie';
$labels['copyexistingfilter'] = 'Kopieer bestaande filters';
$labels['copytoruleset'] = 'Kopieer filter naar een andere regelset';
$labels['copyfromruleset'] = 'Kopieer filters van bestaande regelset';
$labels['time'] = 'Tijd';
$labels['weekday'] = 'Weekdag';
$labels['virustest'] = 'Virus waarschijnlijkheid';
$labels['novirus'] = 'geen virus gevonden';
$labels['virusremoved'] = 'virus gevonden en verwijderd';
$labels['viruscured'] = 'virus gevonden en genezen';
$labels['possiblevirus'] = 'bericht bevat mogelijk een virus';
$labels['definitevirus'] = 'bericht bevat hoogstwaarschijnlijk een virus';
$labels['addheader'] = 'Header toevoegen';
$labels['removeheader'] = 'Header verwijderen';
$labels['headername'] = 'Header naam';
$labels['headervalue'] = 'Header waarde';
$labels['headerappend'] = 'Toevoegen aan bestaande header.';
$labels['headerindex'] = 'Header index';
$labels['headerdelall'] = 'allen';
$labels['last'] = 'laatste';

$messages = array();
$messages['nosieverules'] = 'Geen filters gevonden.';
$messages['filterdeleteconfirm'] = 'Weet u zeker dat u dit filter wilt verwijderen?';
$messages['ruledeleteconfirm'] = 'Weet u zeker dat u deze regel wilt verwijderen?';
$messages['actiondeleteconfirm'] = 'Weet u zeker dat u deze actie wilt verwijderen?';
$messages['filterunknownerror'] = 'Onbekende serverfout';
$messages['filterconnerror'] = 'Kan geen verbinding maken met de managesieve server';
$messages['filterdeleteerror'] = 'Kan filter niet verwijderen. Er is een fout opgetreden';
$messages['filterdeleted'] = 'Filter succesvol verwijderd';
$messages['filtersaved'] = 'Filter succesvol opgeslagen';
$messages['filtersaveerror'] = 'Kan filter niet opslaan. Er is een fout opgetreden.';
$messages['vacperiodexp'] = 'De periode is het aantal dagen dat een bericht niet opnieuw wordt verzonden naar dezelfde ontvanger, ongeacht het aantal keer dat deze contact opneemt.<br /><br />Voorbeeld: Als Jan u op maandag emailt en de periode is op 7 ingesteld dan zal Jan op maandag een afwezigheidsbericht ontvangen, maar geen andere tot de daaropvolgende maandag, ongeacht het aantal emails welke hij gedurende de week verstuurt.';
$messages['vachandleexp'] = 'Een reactienaam of handle kan verschillende afwezigheidsberichten groeperen, zodat er binnen een periode slechts een enkel afwezigheidsbericht met dezelfde reactienaam wordt verstuurd.';
$messages['vactoexp'] = 'Lijst van extra adressen welke bij een afwezigsheidmelding gebruikt worden. Meldingen worden alleen verzonden als het bericht aan het standaard adres of een adres in deze lijst gericht is.';
$messages['vactoexp_adv'] = 'Scheid meerdere aliases met een komma (,). Bijvoorbeeld: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Fout: Meerdere aliases moeten met een komma (,) worden gescheiden';
$messages['norulename'] = 'Vul een naam in voor dit filter';
$messages['ruleexists'] = 'Deze naam is al in gebruik voor een ander filter, voer a.u.b. een andere in';
$messages['noheader'] = 'Vul een naam voor de kop in om te testen';
$messages['headerbadchars'] = 'Fout: de kop bevat ongeldige tekens';
$messages['noheadervalue'] = 'Vul een waarde in om met de kop te testen';
$messages['sizewrongformat'] = 'Fout: berichtgrootte is niet numeriek';
$messages['noredirect'] = 'Vul een e-mailadres in om berichten naar door te sturen';
$messages['redirectaddresserror'] = 'Fout: ongeldig e-mailadres';
$messages['noreject'] = 'Vul een bericht in om mee te zenden met geweigerde e-mail';
$messages['vacnoperiod'] = 'Vul het aantal dagen in voor de periode waarin het bericht niet opnieuw naar dezelfde persoon wordt verzonden';
$messages['vacperiodwrongformat'] = '\'Fout: De periode moet groter dan of gelijk aan 1 zijn';
$messages['vacnomsg'] = 'Vul tekst in voor uw bericht';
$messages['notifynomethod'] = 'Kies een verzendmethode voor de notificatie';
$messages['notifynomsg'] = 'Vul tekst in voor uw melding';
$messages['sieveruleexp'] = 'Maak een of meer regels waaraan een bericht moet voldoen. Filters worden uitgevoerd in de volgorde zoals deze links op het scherm zijn te zien. Als aan een regel wordt voldaan dan worden eventuele volgende regels genegeerd.';
$messages['sieveruleexp_stop'] = 'Maak een of meer regels waaraan een bericht moet voldoen. Filters worden uitgevoerd in de volgorde zoals deze links op het scherm zijn te zien totdat een \'Stop\' aktie optreedt';
$messages['sieveactexp'] = '\'Maak een keuze uit onderstaande opties. Deze acties worden uitgevoerd voor elk bericht dat aan bovenstaande regels voldoet.';
$messages['sieveheadershlp'] = 'Hieronder staan voorbeelden van andere koppen die kunnen worden getest door de filters. Kies een kop om toe te voegen aan de regel of vul een kop in in het invoerveld.';
$messages['movingfilter'] = 'Bezig met filter verplaatsen...';
$messages['noexistingfilters'] = 'Geen bestaande filters gevonden!';
$messages['importdefault'] = '\'<b>Gebruik standaardfilters:</b> Er is een set van standaardfilters beschikbaar. Wilt u deze filters gebruiken?';
$messages['importother'] = '<b>Import filters:</b> Er is een andere set filters van %s gevonden. Wilt u deze filters in uw huidige set importeren?';
$messages['switchtoadveditor'] = 'U kunt het \'Sieve\' bestand rechtstreeks wijzigen via de geavanceerde editor. Veranderingen zijn mogelijk onleesbaar in de standaardeditor en kunnen verloren gaan als filters via de standaardeditor worden opgeslagen. Wilt u doorgaan?';
$messages['filterimported'] = 'Filter succesvol geimporteerd';
$messages['filterimporterror'] = 'Kan filter niet importeren. Er is een fout opgetreden.';
$messages['notifyinvalidmethod'] = 'De methode is in een ongeldig formaat (URI) geschreven. Voorbeeld: `mailto:alert@example.com`.';
$messages['nobodycontentpart'] = 'Vul een inhoudsgedeelte in om te testen';
$messages['badoperator'] = 'De gekozen operator kan niet in deze regel worden gebruikt';
$messages['filteractionerror'] = 'De server ondersteund deze actie niet';
$messages['filtermissingerror'] = 'Regel niet gevonden';
$messages['contentpartexp'] = 'Het MIME-type of specifiek gedeelte van het bericht welke getest moet worden. Bijvoorbeeld: `message/rfc822`, `text/html`, `audio/mp3` or `image`.';
$messages['delrulesetconf'] = 'Weet u zeker dat u deze regelset wilt verwijderen?';
$messages['rulesetexists'] = 'Er is al een regelset met deze naam, voer a.u.b. een andere in';
$messages['copyexisting'] = '<b>Bestaande regelset kopie&euml;ren:</b> Wilt u filters van een bestaande regelset naar u huidige regelset kopie&euml;ren?';
$messages['filtercopied'] = 'Filter succesvol gekopieerd';
$messages['nosieverulesets'] = 'Geen regelsets gevonden.';
$messages['baddateformat'] = 'Fout: Vul de datum in het JJJJ-MM-DD in';
$messages['badtimeformat'] = 'Fout: Vul de tijd in het format UU:MM:SS in';
$messages['missingfoldername'] = 'Fout: Vul een mapnaam in';
$messages['eheadernoname'] = 'Fout: Vul een header naam in';
$messages['eheadernoval'] = 'Fout: Vul een header waarde in';

?>