<?php
/* Author: Tamas P */

$labels = array();
$labels['filters'] = 'Szűrők';
$labels['managefilters'] = 'Szűrők kezelése';
$labels['filtername'] = 'Szűrő neve';
$labels['disablerule'] = 'Szabály kikapcsolása';
$labels['disabled'] = 'Kikapcsolva';
$labels['newfilter'] = 'Új szűrő';
$labels['moveup'] = 'Fennebb';
$labels['movedown'] = 'Lennebb';
$labels['filterallof'] = 'illeszkedik az összes következő szabályra';
$labels['filteranyof'] = 'illeszkedik valamely szabályra';
$labels['filterany'] = 'összes üzenet';
$labels['filtercontains'] = 'tartalmazza';
$labels['filternotcontains'] = 'nem tartalmazza';
$labels['filteris'] = 'egyenlő';
$labels['filterisnot'] = 'nem egyenlő';
$labels['filterexists'] = 'létezik';
$labels['filternotexists'] = 'nem létezik';
$labels['filterregex'] = 'illeszkedik reguláris kifejezésre';
$labels['filternotregex'] = 'nem illeszkedik reguláris kifejezésre';
$labels['filterunder'] = 'kevesebb mint';
$labels['filterover'] = 'több mint';
$labels['filteradvoptions'] = 'több beállítás...';
$labels['spamtest'] = 'Spam valószínűség';
$labels['operator'] = 'számítás';
$labels['comparator'] = 'Összehasonlító';
$labels['isgreaterthan'] = 'nagyobb mint';
$labels['isgreaterthanequal'] = 'nagyobb vagy egyenlő';
$labels['islessthan'] = 'kissebb mint';
$labels['islessthanequal'] = 'kissebb vagy egyenlő';
$labels['equals'] = 'egyenlő';
$labels['notequals'] = 'nem egyenlő';
$labels['countisgreaterthan'] = 'számítás nagyobb mint';
$labels['countisgreaterthanequal'] = 'számítás nagyobb vagy egyenlő';
$labels['countislessthan'] = 'számítás kissebb mint';
$labels['countislessthanequal'] = 'számítás kissebb vagy egyenlő';
$labels['countequals'] = 'számítás egyenlő';
$labels['countnotequals'] = 'számítás nem egyenlő';
$labels['valueisgreaterthan'] = 'érték nagyobb mint';
$labels['valueisgreaterthanequal'] = 'érték nagyobb vagy egyenlő';
$labels['valueislessthan'] = 'érték kissebb mint';
$labels['valueislessthanequal'] = 'érték kissebb vagy egyenlő';
$labels['valueequals'] = 'érték egyenlő';
$labels['valuenotequals'] = 'érték nem egyenlő';
$labels['userpart'] = 'felhasználó része egyenlő';
$labels['notuserpart'] = 'felhasználó része nem egyenlő';
$labels['detailpart'] = 'részlet része egyenlő';
$labels['notdetailpart'] = 'részlet része nem egyenlő';
$labels['domainpart'] = 'domain része egyenlő';
$labels['notdomainpart'] = 'domain része nem egyenlő';
$labels['teststring'] = 'Teszt szöveg';
$labels['messagemoveto'] = 'Üzenet áthelyezése';
$labels['messageredirect'] = 'Üzenet átirányítása';
$labels['messageimapflags'] = 'Megjelőlés mint';
$labels['messagereject'] = 'Elutasítás, üzenettel';
$labels['messagevacation'] = 'Irodán kivűl üzenet';
$labels['messagekeep'] = 'Megtartás';
$labels['messagediscard'] = 'Üzenet eldobása';
$labels['messagenotify'] = 'Értesítés küldése';
$labels['messagestop'] = 'Szűrők feldolgozásának leállítása';
$labels['messagehelp'] = 'Mi ez?';
$labels['sieveorigsubj'] = 'Az eredeti tárgy hozzáfűzése a válaszhoz';
$labels['sievevachandle'] = 'Kezel';
$labels['method'] = 'Módszer';
$labels['options'] = 'Feltételek';
$labels['messagesrules'] = 'Szűrő szabályok';
$labels['messagesactions'] = 'Szűrő akció';
$labels['sieveto'] = 'Aliaszok';
$labels['sievefrom'] = 'Feladó';
$labels['flag'] = 'Jelőlés';
$labels['importancen'] = 'Egyik sem';
$labels['importance1'] = '1';
$labels['importance2'] = '2';
$labels['importance3'] = '3';
$labels['flagread'] = 'Olvasott';
$labels['flagdeleted'] = 'Törölt';
$labels['flaganswered'] = 'Megválaszolt';
$labels['flagdraft'] = 'Piszkozat';
$labels['flagflagged'] = 'Megjelőlve';
$labels['addsieverule'] = 'Új szabály hozzáadása, ez alá';
$labels['addsieveact'] = 'Új akció hozzáadása, ez alá';
$labels['deletesieverule'] = 'Szabály törlése';
$labels['deletesieveact'] = 'Akció törlése';
$labels['envelopefrom'] = 'Boríték, Küldő';
$labels['envelopeto'] = 'Boríték, Cimzett';
$labels['otherheader'] = 'Más fejléc';
$labels['period'] = 'Időszak';
$labels['message'] = 'Üzenet';
$labels['sieveruleheaders'] = 'Fejléc minták megtekintése';
$labels['examplefilters'] = 'Szűrő minták';
$labels['importfilters'] = 'Szűrők importálása';
$labels['usedefaultfilter'] = 'Alapértelmezett szűrők használata';
$labels['importfilter'] = 'Szűrők importálása';
$labels['moreactions'] = 'Tobábbi opciók...';
$labels['adveditor'] = 'Haladó szerkesztő';
$labels['stdeditor'] = 'Egyszerű szerkesztő';
$labels['messageredirectcopy'] = 'Másolat küldése';
$labels['auto'] = 'Auto';
$labels['text'] = 'Szöveg';
$labels['other'] = 'Egyéb';
$labels['spamlevelisgreaterthanequal'] = 'nagyobb vagy egyenlő';
$labels['spamlevelislessthanequal'] = 'kissebb vagy egyenlő';
$labels['spamlevelequals'] = 'egyenlő';
$labels['i;ascii-casemap'] = 'kis/nagybetű nem számít';
$labels['i;octet'] = 'pontos egyezés';
$labels['selectruleset'] = 'Szabálycsoport kiválasztása';
$labels['activateruleset'] = 'Szabálycsoport aktiválása';
$labels['newruleset'] = 'Új szabálycsoport létrehozása';
$labels['delruleset'] = 'Szabálycsoport törlése';
$labels['renameruleset'] = 'Szabálycsoport átnevezése';
$labels['copy'] = 'Másol';
$labels['copyexistingfilter'] = 'Létező szűrők másolása';
$labels['copytoruleset'] = 'Szűrő másolása másik szabálycsoportba';
$labels['copyfromruleset'] = 'Szűrő(k) másolása másik szabálycsoportból';
$labels['time'] = 'Idő';
$labels['weekday'] = 'Hétköznap';
$labels['createfilter'] = 'Szűrő létrehozása..';

$messages = array();
$messages['nosieverules'] = 'Nem található szűrő';
$messages['filterdeleteconfirm'] = 'Biztosan törölni akarod ezt a szűrőt?';
$messages['ruledeleteconfirm'] = 'Biztosan törölni akarod ezt a szabályt?';
$messages['actiondeleteconfirm'] = 'Biztosan törölni akarod ezt az akciót?';
$messages['filterunknownerror'] = 'Ismeretlen szerverhiba';
$messages['filterconnerror'] = 'Nem sikerült kapcsolódni a sieve szerverhez';
$messages['filterdeleteerror'] = 'Nem lehet törölni a szűrőt. Szerver hiba';
$messages['filterdeleted'] = 'A szűrő sikeresen törölve';
$messages['filtersaved'] = 'Szűrő elmentve';
$messages['filtersaveerror'] = 'Nem sikerült elmenteni a szűrőt. Szerver hiba';
$messages['vacperiodexp'] = 'Az dőszak, azon napok száma míg egy üzenet nem lesz újraküldve ugyanannak a címzettnek, függetlenül attól hányszolt lépett önnel kapcsolatba.<br /><br />Pédául: Ha János üzenetet küld Hétfőn és az időszak 7, válaszul kap egy Irodán kívül üzenetet ami nem lesz neki újraküldve a következő Hétfőig, bármennyi üzenetet is küld János ebben az időszakban.';
$messages['vachandleexp'] = 'A mutató arra használható, hogy összekapcsoljon külömböző Irodán kívül üzeneteket. Ha egy ilyen üzenet el lett küldve, másik ilyen mutatóju üzenet nem lesz elküldve megadott időszakban';
$messages['vactoexp'] = 'A többi címzett listája akiknek az automatikus válasz el lesz küldve. Ha egy címzett nem a fő cím én nincs ebben a listában, nem lesz neki üzenet küldve.';
$messages['vactoexp_adv'] = 'Több álnevet vesszővel (,) lehet elválasztani. Pl. teszt1@pelda.hu, teszt2@pelda.hu, teszt3@pelda.hu';
$messages['vactoexp_err'] = 'Hiba! Több álnév esetén vesszőt (,) kell használni';
$messages['norulename'] = 'Irjon be egy nevet a szűrőnek';
$messages['ruleexists'] = 'Ez a szűrőnév már létezik. Kérem irjon be másikat';
$messages['noheader'] = 'Kérem irja be a fejléc nevét a teszthez';
$messages['headerbadchars'] = 'Hiba: A fejléc illegális karaktert tartalmaz';
$messages['noheadervalue'] = 'Kérem irjon be egy értéket a fejléc teszteléséhez';
$messages['sizewrongformat'] = 'Hiba: az üzenet mérete szám kell legyen';
$messages['noredirect'] = 'Kérem irjon be egy e-mail címet az átirányításhoz';
$messages['redirectaddresserror'] = 'Hiba: A cím nem megfelelő';
$messages['noreject'] = 'Írja be az üzenetet amit válaszolni szeretne a visszadobott üzenetre';
$messages['vacnoperiod'] = 'Írja be a napok számát arra az időszakra mig az üzenet nem lesz újraküldve ugyanannak a címzettnek';
$messages['vacperiodwrongformat'] = 'Hiba: az időszak 1-nél nagyobb vagy egyenlő lehet';
$messages['vacnomsg'] = 'Írja be az üzenet szövegét';
$messages['notifynomethod'] = 'Írja be a módszert, melyel az értesitést eloküldjük';
$messages['notifynomsg'] = 'Írja be az üzenet szövegét';
$messages['sieveruleexp'] = 'Kérem határozzon meg egy vagy több szabályt mellyel az üzenetek szelve lesznek. A szűrők olyan sorrendben futnak le, ahogyan megjelennek a baloldalon. Ha egy szűrőnek megfelel az üzenet, több szűrő nem hajtodik végre.';
$messages['sieveactexp'] = 'Kérem válasszon a következő lehetőségekből. ezek minden üzenetnre végrehajtódnak, melyek megfelelnek a szabálynak.';
$messages['sieveheadershlp'] = 'Alább néhány példa más fejlécre melyek tesztelhetőek a szűrőkkel. Válassza ki a fejlécet, adja hozzá a szűrőhőz vagy írjon be egyénit az alábbi szövegmezőbe.';
$messages['movingfilter'] = 'Szűrő áthelyezése...';
$messages['noexistingfilters'] = 'Nem találhatók szűrők';
$messages['importdefault'] = '<b>Alapértelmezett szűrők használata:</b> Alapértelmezett szűrők léteznek. Szeretné használni ezeket a szűrőket?';
$messages['importother'] = '<b>Szűrők importálása:</b> Egy másik szűrőcsoport %s től létezik. Be szeretné tölteni ezt a szűrőcsoportot?';
$messages['switchtoadveditor'] = 'ÿtváltás halado szerkesztőre, mellyel Ön direktbe szerkesztheti a sieve fájlt. Az itt végzett változtatások nem lesznek olvashatóak a norlál szerkesztöben és elvesznek ha a szűrők mentésre kerülnek a normál szerkesztőben. Szeretné folytatni?';
$messages['filterimported'] = 'A szűrő sikeresen importálva';
$messages['filterimporterror'] = 'Nem sikerült a szűrő importálása. Szerver hiba';
$messages['filteractionerror'] = 'A kért műveletet nem támogatja a szerver';
$messages['filtermissingerror'] = 'Nem találom a keresett szabályt';
$messages['delrulesetconf'] = 'Biztosan törölni szeretné ezt a szabálycsoportot?';
$messages['rulesetexists'] = 'Már létezik ilyen nevű szabálycsoport. Írjon be másikat!';
$messages['filtercopied'] = 'Szűrő sikeresen átmásolva';
$messages['nosieverulesets'] = 'Nincs ilyen szabálycsoport.';
$messages['baddateformat'] = 'Hiba: a dátumot ÉÉÉÉ-HH-NN formátumban kell megadni.';
$messages['badtimeformat'] = 'Hiba: az időt ÓÓ:PP:MP fromátumban kell megadni';
$messages['missingfoldername'] = 'Hiba! Írjon be egy mappanevet.';

?>