<?php
/* Author: Guo-Wei Su */

$labels = array();
$labels['filters'] = '郵件規則';
$labels['managefilters'] = '管理郵件規則';
$labels['filtername'] = '規則名稱';
$labels['disablerule'] = '停用規則';
$labels['disabled'] = '停用';
$labels['newfilter'] = '建立新規則';
$labels['moveup'] = '上移';
$labels['movedown'] = '下移';
$labels['filterallof'] = '符合所有條件';
$labels['filteranyof'] = '符合任何一個條件';
$labels['filterany'] = '所有郵件';
$labels['filtercontains'] = '包含';
$labels['filternotcontains'] = '不包含';
$labels['filteris'] = '等於';
$labels['filterisnot'] = '不等於';
$labels['filterexists'] = '存在';
$labels['filternotexists'] = '不存在';
$labels['filterregex'] = '符合正則表示式';
$labels['filternotregex'] = '不符合正則表示式';
$labels['filterunder'] = '小於';
$labels['filterover'] = '大於';
$labels['filterbefore'] = '之前';
$labels['filterafter'] = '之後';
$labels['filteradvoptions'] = '更多選項...';
$labels['spamtest'] = 'Spam 可能性';
$labels['operator'] = '操作';
$labels['comparator'] = '比較';
$labels['isgreaterthan'] = '大於';
$labels['isgreaterthanequal'] = '大於或等於';
$labels['islessthan'] = '小於';
$labels['islessthanequal'] = '小於或等於';
$labels['equals'] = '等於';
$labels['notequals'] = '不等於';
$labels['countisgreaterthan'] = '數量大於';
$labels['countisgreaterthanequal'] = '數量大於或等於';
$labels['countislessthan'] = '數量少於';
$labels['countislessthanequal'] = '數量少於或等於';
$labels['countequals'] = '數量等於';
$labels['countnotequals'] = '數量不等於';
$labels['valueisgreaterthan'] = '值大於';
$labels['valueisgreaterthanequal'] = '值大於或等於';
$labels['valueislessthan'] = '值小於';
$labels['valueislessthanequal'] = '值小於或等於';
$labels['valueequals'] = '值等於';
$labels['valuenotequals'] = '值不等於';
$labels['userpart'] = 'user part equals';
$labels['notuserpart'] = 'user part does not equal';
$labels['detailpart'] = 'detail part equals';
$labels['notdetailpart'] = 'detail part does not equal';
$labels['domainpart'] = 'domain part equals';
$labels['notdomainpart'] = 'domain part does not equal';
$labels['teststring'] = '測試字串';
$labels['messagemoveto'] = '移動郵件至';
$labels['messageredirect'] = 'Redirect message to';
$labels['messageimapflags'] = '變更為';
$labels['messagereject'] = '拒絕郵件';
$labels['messagevacation'] = '不在辦公室訊息';
$labels['messagekeep'] = '保留郵件';
$labels['messagediscard'] = '丟棄郵件';
$labels['messagenotify'] = '寄送通知';
$labels['messagestop'] = '中斷郵件規則';
$labels['messagehelp'] = '這是什麼?';
$labels['sieveorigsubj'] = '附加來件主旨至回信主旨中';
$labels['sievevachandle'] = 'Handle';
$labels['method'] = '方式';
$labels['options'] = '選項';
$labels['messagesrules'] = '規則條件';
$labels['messagesactions'] = '規則動作';
$labels['sieveto'] = '別名';
$labels['sievefrom'] = '寄件者';
$labels['flag'] = '重要性';
$labels['importancen'] = '無';
$labels['importance1'] = '高';
$labels['importance2'] = '一般';
$labels['importance3'] = '低';
$labels['flagread'] = '讀取';
$labels['flagdeleted'] = '刪除';
$labels['flaganswered'] = '已答覆';
$labels['flagdraft'] = '草稿';
$labels['flagflagged'] = '標幟';
$labels['addsieverule'] = '新增條件，在這筆之後';
$labels['addsieveact'] = '新增動作，在這筆之後';
$labels['deletesieverule'] = '刪除這個條件';
$labels['deletesieveact'] = '刪除這個動作';
$labels['envelopefrom'] = 'Envelope From';
$labels['envelopeto'] = 'Envelope To';
$labels['otherheader'] = '其他郵件表頭';
$labels['period'] = '期間';
$labels['message'] = '訊息';
$labels['sieveruleheaders'] = '顯示表頭範例';
$labels['examplefilters'] = '規則範例';
$labels['importfilters'] = '匯入規則';
$labels['usedefaultfilter'] = '使用預設規則';
$labels['importfilter'] = '匯入規則';
$labels['moreactions'] = '更多選項...';
$labels['adveditor'] = '進階編輯器';
$labels['stdeditor'] = '一般編輯器';
$labels['messageredirectcopy'] = '寄送副本到';
$labels['messagecopyto'] = '複製郵件到';
$labels['body'] = 'Body';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Text';
$labels['other'] = 'Other';
$labels['bodycontentpart'] = 'Content Part';
$labels['notchecked'] = 'not checked';
$labels['spamlevelisgreaterthanequal'] = '大於或等於';
$labels['spamlevelislessthanequal'] = '小於或等於';
$labels['spamlevelequals'] = '等於';
$labels['i;ascii-casemap'] = 'case-insensitive string match';
$labels['i;octet'] = 'exact string match';
$labels['i;ascii-numeric'] = '數字符合';
$labels['selectruleset'] = 'Select ruleset';
$labels['activeruleset'] = '%s (active)';
$labels['activateruleset'] = 'Activate this ruleset';
$labels['newruleset'] = 'Create a new ruleset';
$labels['delruleset'] = 'Delete this ruleset';
$labels['renameruleset'] = 'Rename this ruleset';
$labels['copy'] = '複製';
$labels['copyexistingfilter'] = '複製規則';
$labels['copytoruleset'] = 'Copy filter to another ruleset';
$labels['copyfromruleset'] = 'Copy filters from existing ruleset';
$labels['time'] = '時間';
$labels['weekday'] = '平日';
$labels['virustest'] = 'Virus Probability';
$labels['novirus'] = '找不到病毒';
$labels['virusremoved'] = '發現病毒並移除';
$labels['viruscured'] = '發現病毒並清除';
$labels['possiblevirus'] = 'message possibly contains a virus';
$labels['definitevirus'] = 'message possibly defiantly a virus';

$messages = array();
$messages['nosieverules'] = '沒有任何規則';
$messages['filterdeleteconfirm'] = '您確定要刪除這筆郵件規則嗎?';
$messages['ruledeleteconfirm'] = '您確定要刪除這筆規則條件嗎?';
$messages['actiondeleteconfirm'] = '您確定要刪除這筆規則動作嗎?';
$messages['filterunknownerror'] = '未知的伺服器錯誤';
$messages['filterconnerror'] = '無法連線至sieve伺服器';
$messages['filterdeleteerror'] = '無法刪除郵件規則。(伺服器錯誤)';
$messages['filterdeleted'] = '成功刪除郵件規則';
$messages['filtersaved'] = '郵件規則儲存完必';
$messages['filtersaveerror'] = '無法儲存郵件規則。(伺服器錯誤)';
$messages['vacperiodexp'] = 'The period is the number of days during which the message will not be resent to the same user, no matter how many times they contact you.<br /><br />For example: If Joe emails you on Monday and the period is set to 7 then Joe will receive an out of office message on Monday but will not get another one until the following Monday, no matter how many emails he sends an email during the week.';
$messages['vachandleexp'] = 'A handle can be used to link different out of office messages together, once one message has been sent no other message with the same handle will be resent in that period.';
$messages['vactoexp'] = 'List of additional recipient addresses which are included in the auto replying. If a mail\'s recipient is not your main address and it\'s not on this list, no message will be sent.';
$messages['vactoexp_adv'] = 'Separate multiple aliases with a comma (,). For Example: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Error: Multiple aliases should be separated with a comma (,)';
$messages['norulename'] = '請輸入規則名稱';
$messages['ruleexists'] = '重複的規則名稱。請重新輸入';
$messages['noheader'] = 'Please enter the name of the header to test';
$messages['headerbadchars'] = 'Error: Header contains forbidden characters';
$messages['noheadervalue'] = 'Please enter a value to test the header against';
$messages['sizewrongformat'] = '錯誤: 郵件大小必須是數字';
$messages['noredirect'] = '請輸入一個電子郵件位址以便轉寄訊息';
$messages['redirectaddresserror'] = 'Error: Address appears invalid';
$messages['noreject'] = 'Please enter a message to send with rejected email';
$messages['vacnoperiod'] = 'Please enter a number of days for the period in which the message will not be resent to the same person';
$messages['vacperiodwrongformat'] = 'Error: The period must be a number greater than or equal to 1';
$messages['vacnomsg'] = 'Please enter some text for your message';
$messages['notifynomethod'] = 'Please enter a method by which the notification should be sent';
$messages['notifynomsg'] = 'Please enter some text for your message';
$messages['sieveruleexp'] = '請定義一個或多個規則條件。每封信都會依照左側列表，採由上而下的順序比對規則條件，如果符合其中一個規則，後續的郵件規則將不被執行。';
$messages['sieveruleexp_stop'] = 'Please define one or more rules against which each message will be tested. Filters are run in the order in which they appear on the left of this screen until a \'Stop\' action is met.';
$messages['sieveactexp'] = '請從選單中選擇項目，這些動作將會套用在符合上述規則條件的郵件。';
$messages['sieveheadershlp'] = 'Below are some examples of other headers that can be tested by the filters. Select a header to add it to the rule or enter a custom one in the box above.';
$messages['movingfilter'] = '移動郵件規則...';
$messages['noexistingfilters'] = 'No existing filters detected!';
$messages['importdefault'] = '<b>Use default filters:</b> There is a set of default filters available. Would you like to use these filters?';
$messages['importother'] = '<b>Import filters:</b> Another set of filters from %s has been found. Would you like to import these filters into your current set?';
$messages['switchtoadveditor'] = 'Switching to the advanced editor allows you to edit the sieve file directly. Any changes here may be unreadable in the normal editor and may be lost when filters are saved using the normal editor. Do you wish to continue?';
$messages['filterimported'] = 'Filter imported successfully';
$messages['filterimporterror'] = '無法匯入郵件規則。(伺服器錯誤)';
$messages['notifyinvalidmethod'] = 'The method does not appear to be written in a valid format, it must be a URI. For example: `mailto:alert@example.com`.';
$messages['nobodycontentpart'] = 'Please enter a content part to test';
$messages['badoperator'] = 'Sorry the operator you selected cannot be used in this rule';
$messages['filteractionerror'] = 'The action you requested is not supported by the server';
$messages['filtermissingerror'] = 'Unable to find the rule requested';
$messages['contentpartexp'] = 'The MIME-type or specific part of the message which should be tested. For example: `message/rfc822`, `text/html`, `audio/mp3` or `image`.';
$messages['delrulesetconf'] = 'Are you sure you want to delete this ruleset?';
$messages['rulesetexists'] = 'A ruleset with this name already exists. Please enter another';
$messages['copyexisting'] = '<b>Copy exiting ruleset:</b> Would you like to copy filters from an existing ruleset into your current set?';
$messages['filtercopied'] = 'Filter copied successfully';
$messages['nosieverulesets'] = 'No rulesets found.';
$messages['baddateformat'] = 'Error: Please enter the date in the format YYYY-MM-DD';
$messages['badtimeformat'] = 'Error: Please enter the time in the format HH:MM:SS';
$messages['missingfoldername'] = '錯誤: 請輸入資料夾名稱';

?>