<?php
/* Author: Bartosz Mierzwiak */

$labels = array();
$labels['filters'] = 'Filtry';
$labels['filtersname'] = 'Filtry ($name)';
$labels['managefilters'] = 'Zarządzaj filtrami';
$labels['filtername'] = 'Nazwa reguły:';
$labels['disablerule'] = 'Wyłącz regułę';
$labels['disabled'] = 'Wyłączona';
$labels['newfilter'] = 'Nowy filtr';
$labels['moveup'] = 'Przenieś wyżej';
$labels['movedown'] = 'Przenieś niżej';
$labels['filterallof'] = 'spełniające wszystkie poniższe kryteria';
$labels['filteranyof'] = 'spełniające dowolne z poniższych kryteriów';
$labels['filterany'] = 'wszystkie wiadomości';
$labels['filtercontains'] = 'zawiera';
$labels['filternotcontains'] = 'nie zawiera';
$labels['filteris'] = 'jest równa';
$labels['filterisnot'] = 'nie jest równa';
$labels['filterexists'] = 'istnieje';
$labels['filternotexists'] = 'nie istnieje';
$labels['filterregex'] = 'pasuje do wyrażenia regularnego';
$labels['filternotregex'] = 'nie pasuje do wyrażenia regularnego ';
$labels['filterunder'] = 'jest mniejsza niż';
$labels['filterover'] = 'jest większa niż';
$labels['filterbefore'] = 'jest wcześniejsza';
$labels['filterafter'] = 'jest późniejsza';
$labels['filteradvoptions'] = 'więcej opcji...';
$labels['spamtest'] = 'Przypuszczalnie Spam';
$labels['operator'] = 'Operator';
$labels['comparator'] = 'Komparator';
$labels['isgreaterthan'] = 'jest większe od';
$labels['isgreaterthanequal'] = 'jest większa lub równa';
$labels['islessthan'] = 'jest mniejsza niż';
$labels['islessthanequal'] = 'jest mniejsza lub równa';
$labels['equals'] = 'jest równy';
$labels['notequals'] = 'nie równa się';
$labels['countisgreaterthan'] = 'liczba jest większa niż';
$labels['countisgreaterthanequal'] = 'liczba jest większa lub równa';
$labels['countislessthan'] = 'liczba jest równa';
$labels['countislessthanequal'] = 'liczba jest mniejsza niż';
$labels['countequals'] = 'liczba jest równa';
$labels['countnotequals'] = 'liczba jest inna niż';
$labels['valueisgreaterthan'] = 'wartość jest wyższa niż';
$labels['valueisgreaterthanequal'] = 'wartość jest większa lub równa';
$labels['valueislessthan'] = 'wartość jest mniejsza niż';
$labels['valueislessthanequal'] = 'wartość jest mniejsza lub równa';
$labels['valueequals'] = 'wartość jest równa';
$labels['valuenotequals'] = 'wartość jest inna niż';
$labels['userpart'] = 'część użytkowników jest równa';
$labels['notuserpart'] = 'część użytkowników jest inna niż';
$labels['detailpart'] = 'część szczegółów jest równa';
$labels['notdetailpart'] = 'część szczegółów jest inna niż';
$labels['domainpart'] = 'część domeny zawiera';
$labels['notdomainpart'] = 'część domeny nie zawiera';
$labels['teststring'] = 'Łańcuch testowy';
$labels['messagemoveto'] = 'Przenieś wiadomość do';
$labels['messageredirect'] = 'Przekierowanie wiadomości';
$labels['messageimapflags'] = 'Oznacz wiadomość jako';
$labels['messagereject'] = 'Odrzuć wiadomość';
$labels['messagevacation'] = 'Automatyczna odpowiedź';
$labels['messagekeep'] = 'Zachowaj wiadomość';
$labels['messagediscard'] = 'Odrzuć wiadomość';
$labels['messagenotify'] = 'Wyślij zgłoszenie';
$labels['messagestop'] = 'Nie sprawdzaj kolejnych filtrów';
$labels['messagehelp'] = 'Co to jest?';
$labels['sieveorigsubj'] = 'Dołącz oryginalny przedmiot odpowiedzi';
$labels['sievevachandle'] = 'Obsłuż';
$labels['method'] = 'Metoda';
$labels['options'] = 'Opcje';
$labels['messagesrules'] = 'Reguły filtra';
$labels['messagesactions'] = 'Filtr działania';
$labels['sieveto'] = 'alians';
$labels['sievefrom'] = 'Z';
$labels['flag'] = 'Ważność';
$labels['importancen'] = 'Najwyższa';
$labels['importance1'] = 'Wysoka';
$labels['importance2'] = 'Normalna';
$labels['importance3'] = 'Niska';
$labels['flagread'] = 'Odebrane';
$labels['flagdeleted'] = 'Usunięto';
$labels['flaganswered'] = 'Odpowiedział';
$labels['flagdraft'] = 'Projekt';
$labels['flagflagged'] = 'Oflagowane';
$labels['addsieverule'] = 'Dodaj nowy przepis, poniżej tej jednej';
$labels['addsieveact'] = 'Dodaj kolejne działania, pod tym jednym';
$labels['deletesieverule'] = 'Usuń tę regułę';
$labels['deletesieveact'] = 'Usuń to działanie';
$labels['envelopefrom'] = 'Adres Nadawcy';
$labels['envelopeto'] = 'Adres Odbiorcy';
$labels['otherheader'] = 'Inny nagłówek';
$labels['period'] = 'Liczba dni';
$labels['message'] = 'Wiadomość';
$labels['sieveruleheaders'] = 'Pokaż przykłady innych nagłówków';
$labels['examplefilters'] = 'Przykłady filtrów';
$labels['importfilters'] = 'Importuj filtry';
$labels['usedefaultfilter'] = 'Użyj domyślnych filtrów';
$labels['importfilter'] = 'Importuj filtr';
$labels['moreactions'] = 'Więcej opcji...';
$labels['adveditor'] = 'Zaawansowana edycja';
$labels['stdeditor'] = 'Edytor standardowy';
$labels['messageredirectcopy'] = 'Wyślij kopię wiadomości do:';
$labels['messagecopyto'] = 'Kopiuj wiadomość do:';
$labels['body'] = 'Cała wiadomość';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Text';
$labels['other'] = 'Inny';
$labels['bodycontentpart'] = 'Zawartość części';
$labels['notchecked'] = 'nie sprawdza';
$labels['spamlevelisgreaterthanequal'] = 'jest większa lub równa';
$labels['spamlevelislessthanequal'] = 'jest mniejsza lub równa';
$labels['spamlevelequals'] = 'jest równa';
$labels['i;ascii-casemap'] = 'przypadek-ignorowania łańcucha dopasowania';
$labels['i;octet'] = 'dopasowanie łańcucha';
$labels['i;ascii-numeric'] = 'numeryczne dopasowanie';
$labels['selectruleset'] = 'Zaznacz zestaw reguł';
$labels['activeruleset'] = '%s (aktywna)';
$labels['activateruleset'] = 'Aktywuj zestaw reguł';
$labels['isactive'] = 'Aktywny zestaw reguł';
$labels['isinactive'] = 'Niekatywny zestaw reguł';
$labels['newruleset'] = 'Utwórz nowy zestaw reguł';
$labels['delruleset'] = 'Usuń ten zestaw reguł';
$labels['renameruleset'] = 'Zmień nazwę tego zestawu reguł';
$labels['copy'] = 'Kopiuj';
$labels['copyexistingfilter'] = 'Kopiuj istniejące filtry';
$labels['copytoruleset'] = 'Kopiuj filtr do innego zestawu reguł';
$labels['copyfromruleset'] = 'Kopiuj filtry z istniejącego zestawu reguł';
$labels['time'] = 'Czas';
$labels['weekday'] = 'Dzień tygodnia';
$labels['virustest'] = 'Prawdopodobieństwo wirusa';
$labels['novirus'] = 'nie znaleziono wirusa';
$labels['virusremoved'] = 'wirus znaleziony i usunięty';
$labels['viruscured'] = 'wirus znaleziony i zneutralizowany';
$labels['possiblevirus'] = 'wiadomość może zawierać wirusa';
$labels['definitevirus'] = 'wiadomość może zawierać groźnego wirusa';
$labels['addheader'] = 'Dodaj nagłówek';
$labels['removeheader'] = 'Usuń nagłówek';
$labels['headername'] = 'Nazwa nagłówka';
$labels['headervalue'] = 'Wartość nagłówka';
$labels['headerappend'] = 'Dodaj do istniejącego nagłówka wiadomości';
$labels['headerindex'] = 'Indeks nagłówka';
$labels['headerdelall'] = 'wszystkie zdarzenia';
$labels['last'] = 'ostatni';
$labels['createfilter'] = 'Utwórz filtr...';

$messages = array();
$messages['nosieverules'] = 'Nie znaleziono filtrów.';
$messages['filterdeleteconfirm'] = 'Czy na pewno chcesz usunąć ten filtr?';
$messages['ruledeleteconfirm'] = 'Czy na pewno chcesz usunąć tę regułę?';
$messages['actiondeleteconfirm'] = 'Czy na pewno chcesz usunąć tę zasadę działania? ';
$messages['filterunknownerror'] = 'Nieznany błąd serwera.';
$messages['filterconnerror'] = 'Nie można się połączyć z serwerem filtrów';
$messages['filterdeleteerror'] = 'Nie można usunąć filtru. Błąd serwera!';
$messages['filterdeleted'] = 'Filtr został usunięty';
$messages['filtersaved'] = 'Filtr zapisany';
$messages['filtersaveerror'] = 'Nie można zapisać filtra - Błąd serwera!';
$messages['vacperiodexp'] = 'Okres to liczba dni, podczas których wiadomość nie zostanie wysłana ponownie do tego samego użytkownika, bez względu na to ile razy próbował się z tobą skontaktować.  Na przykład: Jeśli Jasio wyśle wiadomości e-mail w poniedziałek, a okres ten zostanie ustawiony na 7 dni, Małgosia otrzyma automatyczną odpowiedź w poniedziałek, ale nie będzie dostawała kolejnych do następnego poniedziałku, bez względu na liczbę wiadomości e-mail wysłanych w ciągu tygodnia.';
$messages['vachandleexp'] = 'Uchwyt może być stosowany do łączenia różnych komunikatów razem, gdy jedna wiadomość została wysłana, żadne inne wiadomości nie bedą wysyłane w tym okresie.';
$messages['vactoexp'] = 'Lista dodatkowych adresów odbiorców, które są zawarte w automatycznej odpowiedzi.';
$messages['vactoexp_adv'] = 'Rozdziel adresy aliasów przecinkiem (,). Na przykład: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Błąd: Adresy aliasów muszą być rodzielone przecinkiem (,)';
$messages['norulename'] = 'Proszę podać nazwę tego filtru';
$messages['ruleexists'] = 'Filtr o takiej nazwie już istnieje. Proszę podać inną nazwę!';
$messages['noheader'] = 'Proszę wprowadzić nazwę nagłówka do badania';
$messages['headerbadchars'] = 'Błąd: Nagłówek zawiera zakazane znaki!';
$messages['noheadervalue'] = 'Proszę wprowadzić wartość do badań nagłówka.';
$messages['sizewrongformat'] = 'Błąd: Rozmiar wiadomości musi  być określony numeryczne';
$messages['noredirect'] = 'Proszę podać adres e-mail aby przekierować wiadomości';
$messages['redirectaddresserror'] = 'Błąd: Adres wydaje się nieprawidłowy';
$messages['noreject'] = 'Proszę wprowadzić treść wiadomości, aby wysłać e-mail z komunikatem odrzucenia';
$messages['vacnoperiod'] = 'Proszę podać liczbę dni w okresie, w którym wiadomość nie zostanie wysłana ponownie do tej samej osoby';
$messages['vacperiodwrongformat'] = 'Błąd: Okres ten musi być liczbą większą lub równą 1 ';
$messages['vacnomsg'] = 'Proszę wprowadzić treść do Twojej wiadomości generowanej automatycznie';
$messages['notifynomethod'] = 'Proszę wprowadzić metodę, dzięki której zgłoszenie powinno być wysłane';
$messages['notifynomsg'] = 'Proszę wprowadzić treść do Twojej wiadomości';
$messages['sieveruleexp'] = 'Proszę określić jedną lub więcej reguł z których każda wiadomość będzie testowane. Filtry są uruchamiane w kolejności, w jakiej znajdują się na lewo od ekranu, jeśli nie zostaną znalezione żadne dodatkowe, filtry zostaną przetestowane.';
$messages['sieveruleexp_stop'] = 'Proszę podać jedną lub więcej reguł jakimi testowana będzie wiadomość. Filtry będą używane w kolejności w jakiej widnieją po lewej stronie tego ekranu, do momentu dotarcia do akcji \'Stop\'.';
$messages['sieveactexp'] = 'Proszę wybrać jedną z poniższych opcji. Działania te będą wykonywane dla wszystkich wiadomości pasujących do reguł(y).';
$messages['sieveheadershlp'] = 'Poniżej kilka przykładów innych nagłówków, które mogą być badane przez filtry. Wybierz nagłówek, aby dodać go do przepisu lub wprowadź własny w polu powyżej.';
$messages['movingfilter'] = 'Przemieszczanie filtra...';
$messages['noexistingfilters'] = 'Nie znaleziono istniejących filtrów!';
$messages['importdefault'] = 'Użyj domyślnego zestawu filtrów: Nie ma domyślnie dostępnego zestawu filtrów. Chcesz używać tych filtrów? ';
$messages['importother'] = 'Importuj filtry: Kolejny zestaw filtrów %s zostało znalezione. Czy chcesz zaimportować te filtry do bieżącego zestawu?';
$messages['switchtoadveditor'] = 'Przełącz na zaawansowany edytor pozwala na edycję plików bezpośrednio sito. Wszelkie zmiany w tym względzie może być nieczytelne w normalnym edytorze i mogą zostać utracone, gdy filtry są zapisywane przy użyciu normalnego edytora. Czy chcesz kontynuować? ';
$messages['filterimported'] = 'Filtr zaimportowany';
$messages['filterimporterror'] = 'Nie można zaimportować filtra. Błąd serwera!';
$messages['notifyinvalidmethod'] = 'Ta metoda ma nieprawidłowy format, podaj URI. Na przykład: "mailto: alert@example.com".';
$messages['nobodycontentpart'] = 'Proszę wprowadzić zawartość strony do testowania';
$messages['badoperator'] = 'Przepraszamy, wybrany operator nie może być stosowany w tej regule.';
$messages['filteractionerror'] = 'Żądane działanie nie jest obsługiwane przez serwer!';
$messages['filtermissingerror'] = 'Nie można znaleźć treści reguły';
$messages['contentpartexp'] = 'Typ MIME lub określonej części wiadomości, które powinny być badane. Na przykład: "message/rfc822`, `text/html`, `audio/mp3` lub `image`.';
$messages['delrulesetconf'] = 'Czy na pewno chcesz usunąć ten zestaw reguł?';
$messages['rulesetexists'] = 'Reguła o takiej nazwie już istnieje. Proszę podać inną nazwę';
$messages['copyexisting'] = 'Kopiowanie istniejącego zestawu reguł: Czy chcesz skopiować filtry z istniejącego zestawu reguł do bieżącego zestawu?';
$messages['filtercopied'] = 'Filtr przekopiowany';
$messages['nosieverulesets'] = 'Nie znaleziono zestawu filtrów.';
$messages['baddateformat'] = 'Błąd: Podaj datę w formacie YYYY-MM-DD';
$messages['badtimeformat'] = 'Błąd: Podaj czas w formacie HH:MM:SS';
$messages['missingfoldername'] = 'Błąd: Podaj nazwę folderu';
$messages['eheadernoname'] = 'Błąd: Podaj nazwę nagłówka';
$messages['eheadernoval'] = 'Błąd: Podaj wartość nagłówka';

?>