<?php
/* Author: Pedro Padron */

$labels = array();
$labels['filters'] = 'Filtros';
$labels['managefilters'] = 'Gerenciar filtros';
$labels['filtername'] = 'Nome do filtro';
$labels['disablerule'] = 'Desativar regra';
$labels['disabled'] = 'Desativado';
$labels['newfilter'] = 'Novo filtro';
$labels['moveup'] = 'Mover para cima';
$labels['movedown'] = 'Mover para baixo';
$labels['filterallof'] = 'corresponde a todas as seguintes regras';
$labels['filteranyof'] = 'corresponde a uma das seguintes regras';
$labels['filterany'] = 'todas as mensagens';
$labels['filtercontains'] = 'contém';
$labels['filternotcontains'] = 'não contém';
$labels['filteris'] = 'é igual a';
$labels['filterisnot'] = 'é diferente de';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'não existe';
$labels['filterregex'] = 'corresponde à expressão';
$labels['filternotregex'] = 'não corresponde à expressão';
$labels['filterunder'] = 'é inferior a';
$labels['filterover'] = 'é superior a';
$labels['filterbefore'] = 'é antes';
$labels['filterafter'] = 'é depois';
$labels['filteradvoptions'] = 'mais opções...';
$labels['spamtest'] = 'Probabilidade de Spam';
$labels['operator'] = 'Operador';
$labels['comparator'] = 'Comparador';
$labels['isgreaterthan'] = 'é maior que';
$labels['isgreaterthanequal'] = 'é maior ou igual a';
$labels['islessthan'] = 'é menor que';
$labels['islessthanequal'] = 'é menor ou igual a';
$labels['equals'] = 'é igual a';
$labels['notequals'] = 'é diferente de';
$labels['countisgreaterthan'] = 'contagem é maior que';
$labels['countisgreaterthanequal'] = 'contagem é maior ou igual a';
$labels['countislessthan'] = 'contagem é menor que';
$labels['countislessthanequal'] = 'contagem é menor ou igual a';
$labels['countequals'] = 'contagem é igual a';
$labels['countnotequals'] = 'contagem é diferente de';
$labels['valueisgreaterthan'] = 'valor é maior que';
$labels['valueisgreaterthanequal'] = 'valor é maior ou igual a';
$labels['valueislessthan'] = 'valor é menor que';
$labels['valueislessthanequal'] = 'valor é menor ou igual a';
$labels['valueequals'] = 'valor é igual a';
$labels['valuenotequals'] = 'valor diferente de';
$labels['userpart'] = 'parte do utilizador igual a';
$labels['notuserpart'] = 'parte do utilizador diferente de';
$labels['detailpart'] = 'parte do detalhe igual a';
$labels['notdetailpart'] = 'parte do detalhe diferente de';
$labels['domainpart'] = 'parte do domínio igual a';
$labels['notdomainpart'] = 'parte do domínio diferente de';
$labels['teststring'] = 'Texto de teste';
$labels['messagemoveto'] = 'Mover mensagem para';
$labels['messageredirect'] = 'Redirecionar mensagem para';
$labels['messageimapflags'] = 'Marcar mensagem como';
$labels['messagereject'] = 'Rejeitar com a mensagem';
$labels['messagevacation'] = 'Mensagem de Fora do Escritório';
$labels['messagekeep'] = 'Manter mensagem';
$labels['messagediscard'] = 'Rejeitar mensagem';
$labels['messagenotify'] = 'Enviar notificação';
$labels['messagestop'] = 'Parar o processamento de filtros';
$labels['messagehelp'] = 'O que é isto?';
$labels['sieveorigsubj'] = 'Acrescentar assunto original à resposta';
$labels['sievevachandle'] = 'Identificador';
$labels['method'] = 'Método';
$labels['options'] = 'Opções';
$labels['messagesrules'] = 'Regras para Filtros';
$labels['messagesactions'] = 'Ações para Filtros';
$labels['sieveto'] = 'Alias';
$labels['sievefrom'] = 'De';
$labels['flag'] = 'Importância';
$labels['importancen'] = 'Nenhum';
$labels['importance1'] = 'Alta';
$labels['importance2'] = 'Normal';
$labels['importance3'] = 'Baixa';
$labels['flagread'] = 'Lida';
$labels['flagdeleted'] = 'Eliminada';
$labels['flaganswered'] = 'Respondida';
$labels['flagdraft'] = 'Rascunho';
$labels['flagflagged'] = 'Marcada';
$labels['addsieverule'] = 'Adicionar outra regra, depois desta';
$labels['addsieveact'] = 'Adicionar outra ação, depois desta';
$labels['deletesieverule'] = 'Eliminar esta regra';
$labels['deletesieveact'] = 'Eliminar esta ação';
$labels['envelopefrom'] = 'Envelope De';
$labels['envelopeto'] = 'Envelope Para';
$labels['otherheader'] = 'Outro cabeçalho';
$labels['period'] = 'Periodo';
$labels['message'] = 'Mensagem';
$labels['sieveruleheaders'] = 'Ver exemplos de outros cabecalhos';
$labels['examplefilters'] = 'Exemplo de Filtros';
$labels['importfilters'] = 'Importar Filtros';
$labels['usedefaultfilter'] = 'Usar filtros predefinidos';
$labels['importfilter'] = 'Importar filtros';
$labels['moreactions'] = 'Mais opções...';
$labels['adveditor'] = 'Editor avançado';
$labels['stdeditor'] = 'Editor padrão';
$labels['messageredirectcopy'] = 'Enviar cópia para';
$labels['messagecopyto'] = 'Copiar mensagem para';
$labels['body'] = 'Corpo';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Texto';
$labels['other'] = 'Outro';
$labels['bodycontentpart'] = 'Parte Conteúdo';
$labels['notchecked'] = 'não verificado';
$labels['spamlevelisgreaterthanequal'] = 'é maior ou igual a';
$labels['spamlevelislessthanequal'] = 'é menor ou igual a';
$labels['spamlevelequals'] = 'é igual a';
$labels['i;ascii-casemap'] = 'correspondência de texto indeferente a maiúsculas e minúsculas';
$labels['i;octet'] = 'correspondência exata do texto';
$labels['i;ascii-numeric'] = 'correspondência numérica';
$labels['selectruleset'] = 'Selecionar conjunto de regras';
$labels['activeruleset'] = '%s (ativo)';
$labels['activateruleset'] = 'Ativar este conjunto de regras';
$labels['newruleset'] = 'Criar um no grupo de regras';
$labels['delruleset'] = 'Eliminar este conjunto de regras';
$labels['renameruleset'] = 'Renomear este conjunto de regras';
$labels['copy'] = 'Copiar';
$labels['copyexistingfilter'] = 'Copiar filtros existentes';
$labels['copytoruleset'] = 'Copiar o filtro para outro conjunto de regras';
$labels['copyfromruleset'] = 'Copiar filtros de um conjunto regras existente';
$labels['time'] = 'Tempo';
$labels['weekday'] = 'dia da semana';
$labels['createfilter'] = 'Criar filtro...';

$messages = array();
$messages['nosieverules'] = 'Nenhum filtro encontrado.';
$messages['filterdeleteconfirm'] = 'Tem a certeza que pretende eliminar este filtro?';
$messages['ruledeleteconfirm'] = 'Tem a certeza que pretende eliminar esta regra?';
$messages['actiondeleteconfirm'] = 'Tem a certeza que pretende eliminar esta ação?';
$messages['filterunknownerror'] = 'Erro de servidor desconhecido';
$messages['filterconnerror'] = 'Não foi possível conectar ao servidor Sieve';
$messages['filterdeleteerror'] = 'Não foi possível eliminar o filtro. Erro no servidor';
$messages['filterdeleted'] = 'Filtro eliminado com sucesso';
$messages['filtersaved'] = 'Filtro salvo com sucesso';
$messages['filtersaveerror'] = 'Não foi possível salvar o filtro. Erro no servidor';
$messages['vacperiodexp'] = 'O período é o número de dias durante o qual a mensagem não será reenviada para o mesmo remetente, não importando quantas vezes ele entre contato.<br/><br/>Por exemplo: Se João lhe enviar e-mails na segunda-feira e o período estiver definido para 7 dias, João irá receber uma mensagem de Fora do Escritório na segunda-feira, mas não irá receber mais nenhuma até à segunda-feira seguinte, não importando quantos e-mails ele lhe envie durante a semana.';
$messages['vachandleexp'] = 'Um identificador pode ser usado para ligar as diferentes mensagens de Fora do Escritório em conjunto, uma vez que uma mensagem foi enviada nenhuma outra com o mesmo identificador será enviada.';
$messages['vactoexp'] = 'Lista de endereços de destinatários adicionais que estão incluídos na resposta automática. Se um destinatário de e-mail não for seu endereço principal e não estiver nesta lista, nenhuma mensagem será enviada.';
$messages['norulename'] = 'Por favor, indique um nome para este filtro';
$messages['ruleexists'] = 'Já existe um filtro com este nome. Por favor, indique outro';
$messages['noheader'] = 'Por favor, indique o nome do cabeçalho para testar';
$messages['headerbadchars'] = 'Erro: O cabeçalho contém caracteres proibidos';
$messages['noheadervalue'] = 'Por favor indique um valor para testar o cabeçalho contra';
$messages['sizewrongformat'] = 'Erro: O tamanho da mensagem deve ser numérico';
$messages['noredirect'] = 'Indique um endereço de e-mail para redirecionar as mensagens';
$messages['redirectaddresserror'] = 'Erro: O endereço de e-mail parece ser inválido';
$messages['noreject'] = 'Indique uma mensagem para enviar juntamente com o e-mail rejeitado';
$messages['vacnoperiod'] = 'Por favor insira um número de dias para o período em que a mensagem não será reenviado para a mesma pessoa';
$messages['vacperiodwrongformat'] = 'Erro: O período deve ser um número maior ou igual a 1';
$messages['vacnomsg'] = 'Insira o texto para a sua mensagem';
$messages['notifynomethod'] = 'Por favor, indique um método pelo qual a notificação deve ser enviada';
$messages['notifynomsg'] = 'Insira o texto para a sua mensagem';
$messages['sieveruleexp'] = 'Por favor, defina uma ou mais regras sobre as quais cada mensagem será testada. Os filtros são executados na ordem em que aparecem à esquerda da tela, se for encontrada uma correspondência mais nenhum filtro será testado.';
$messages['sieveruleexp_stop'] = 'Por favor, defina uma ou mais regras sobre as quais cada mensagem será testada. Os filtros são executados na ordem em que aparecem à esquerda da tela até uma ação de \'Stop\' ser encontrada.';
$messages['sieveactexp'] = 'Por favor, selecione uma das opções abaixo. Essas ações serão realizadas para qualquer mensagem correspondente à(s) regra(s) acima.';
$messages['sieveheadershlp'] = 'Abaixo estão alguns exemplos de outros cabeçalhos que podem ser testados pelos filtros. Selecione um cabeçalho para adicioná-lo à regra, ou introduza um personalizado na caixa acima.';
$messages['movingfilter'] = 'Movendo filtro...';
$messages['noexistingfilters'] = 'Não foi detectado nenhum filtro existente!';
$messages['importdefault'] = '<b>Usar filtros predefinidos:</b> Há um conjunto de filtros predefinidos disponíveis. Gostaria de usar esses filtros?';
$messages['importother'] = '<b>Importação de filtros:</b>Foi encontrado outro conjunto de filtros de %s. Gostaria de importar esses filtros para o seu conjunto actual?';
$messages['switchtoadveditor'] = 'Mudando para o editor avançado é possível editar o arquivo Sieve diretamente. Quaisquer alterações aqui efetuadas podem ser ilegíveis no editor normal e podem ser perdidas quando os filtros são guardados usando o editor normal. Deseja continuar?';
$messages['filterimported'] = 'Filtro importado com sucesso';
$messages['filterimporterror'] = 'Não foi possível importar o filtro. Ocorreu um erro no servidor.';
$messages['notifyinvalidmethod'] = 'O método parece não estar escrito num formato válido, ele deve ser uma URL. Por exemplo: "mailto: alert@example.com».';
$messages['nobodycontentpart'] = 'Por favor, indique uma parte de conteúdo para testar';
$messages['badoperator'] = 'O operador seleccionado não pode ser usado nesta regra';
$messages['filteractionerror'] = 'A ação solicitada não é suportada pelo servidor';
$messages['filtermissingerror'] = 'Não foi possível encontrar a regra solicitada';
$messages['contentpartexp'] = 'O tipo de MIME ou parte específica da mensagem que deve ser testado. Por exemplo: `text/html`, `audio/mp3` or `image`.';
$messages['delrulesetconf'] = 'Tem certeza que quer eliminar este conjunto de regras?';
$messages['rulesetexists'] = 'Um conjunto de regras com este nome já existe. Por favor, indique outro nome';
$messages['copyexisting'] = '<b>Copiar conjunto de regras existente:</b>Gostaria de copiar os filtros de um conjunto de de regras existente para o seu conjunto actual?';
$messages['filtercopied'] = 'Filtro copiado com sucesso';
$messages['nosieverulesets'] = 'Nenhum conjunto de regras encontrado.';
$messages['baddateformat'] = 'Erro: Indique a data no formato AAAA-MM-DD';
$messages['badtimeformat'] = 'Erro: Indique a hora no formato HH:MM:SS';

?>