<?php
/* Author: Peter Zotov */

$labels = array();
$labels['filters'] = 'Фильтры';
$labels['filtersname'] = 'Фильтры ($name)';
$labels['managefilters'] = 'управление фильтрами';
$labels['filtername'] = 'Имя фильтра';
$labels['disablerule'] = 'отключить правило';
$labels['disabled'] = 'отключено';
$labels['newfilter'] = 'Новый фильтр';
$labels['moveup'] = 'вверх';
$labels['movedown'] = 'вниз';
$labels['filterallof'] = 'соответствует всем правилам';
$labels['filteranyof'] = 'соответствует хотя бы одному из правил';
$labels['filterany'] = 'все сообщения';
$labels['filtercontains'] = 'содержит';
$labels['filternotcontains'] = 'не содержит';
$labels['filteris'] = 'совпадает с';
$labels['filterisnot'] = 'не совпадает с';
$labels['filterexists'] = 'существует';
$labels['filternotexists'] = 'не существует';
$labels['filterregex'] = 'соответствует регулярному выражению';
$labels['filternotregex'] = 'не соответствует регулярному выражению';
$labels['filterunder'] = 'меньше чем';
$labels['filterover'] = 'больше чем';
$labels['filterbefore'] = 'до';
$labels['filterafter'] = 'после';
$labels['filteradvoptions'] = 'другие...';
$labels['spamtest'] = 'Вероятность спама';
$labels['operator'] = 'Условие';
$labels['comparator'] = 'Сравнение';
$labels['isgreaterthan'] = 'больше чем';
$labels['isgreaterthanequal'] = 'больше чем или равен';
$labels['islessthan'] = 'меньше чем';
$labels['islessthanequal'] = 'меньше чем или равен';
$labels['equals'] = 'равен';
$labels['notequals'] = 'не равен';
$labels['countisgreaterthan'] = 'количество больше чем';
$labels['countisgreaterthanequal'] = 'количество больше чем или равно';
$labels['countislessthan'] = 'количество меньше чем';
$labels['countislessthanequal'] = 'количество меньше чем или равно';
$labels['countequals'] = 'количество равно';
$labels['countnotequals'] = 'количество не равно';
$labels['valueisgreaterthan'] = 'значение больше чем';
$labels['valueisgreaterthanequal'] = 'значение больше чем или равно';
$labels['valueislessthan'] = 'значение меньше чем';
$labels['valueislessthanequal'] = 'значение меньше чем или равно';
$labels['valueequals'] = 'значение равно';
$labels['valuenotequals'] = 'значение не равно';
$labels['userpart'] = 'имя пользователя (перед \'@\' или \'+\') равно';
$labels['notuserpart'] = 'имя пользователя не равно';
$labels['detailpart'] = 'часть имени после \'+\' равна';
$labels['notdetailpart'] = 'часть имени после \'+\' не равна';
$labels['domainpart'] = 'имя домена (после \'@\') равно';
$labels['notdomainpart'] = 'имя домена не равно';
$labels['teststring'] = 'Сравнить со строкой';
$labels['messagemoveto'] = 'переместить сообщения в';
$labels['messageredirect'] = 'перенаправить сообщения на адрес';
$labels['messageimapflags'] = 'пометить сообщения как';
$labels['messagereject'] = 'отклонить с сообщением';
$labels['messagevacation'] = 'сообщение \'Нет на месте\'';
$labels['messagekeep'] = 'сохранить сообщение';
$labels['messagediscard'] = 'отклонить сообщение';
$labels['messagenotify'] = 'отправить уведомление';
$labels['messagestop'] = 'прекратить обработку фильтров';
$labels['messagehelp'] = 'Что это?';
$labels['sieveorigsubj'] = 'Добавить тему исходного сообщения к ответу';
$labels['sievevachandle'] = 'Метка';
$labels['method'] = 'Способ';
$labels['options'] = 'Параметры';
$labels['messagesrules'] = 'Правила фильтра';
$labels['messagesactions'] = 'Действия фильтра';
$labels['sieveto'] = 'Адреса';
$labels['sievefrom'] = 'От';
$labels['flag'] = 'Важность';
$labels['importancen'] = 'не указана';
$labels['importance1'] = 'высокая';
$labels['importance2'] = 'обычная';
$labels['importance3'] = 'низкая';
$labels['flagread'] = 'прочитано';
$labels['flagdeleted'] = 'удалено';
$labels['flaganswered'] = 'ответ написан';
$labels['flagdraft'] = 'черновик';
$labels['flagflagged'] = 'помечено';
$labels['addsieverule'] = 'добавить правило';
$labels['addsieveact'] = 'добавить дополнительное действие';
$labels['deletesieverule'] = 'удалить правило';
$labels['deletesieveact'] = 'удалить действие';
$labels['otherheader'] = 'Другой заголовок';
$labels['period'] = 'Периодичность';
$labels['message'] = 'Сообщение';
$labels['sieveruleheaders'] = 'посмотреть примеры других заголовков';
$labels['examplefilters'] = 'Примеры фильтров';
$labels['importfilters'] = 'Импорт фильтров';
$labels['usedefaultfilter'] = 'Использовать фильтры по умолчанию';
$labels['importfilter'] = 'Импортировать фильтры';
$labels['moreactions'] = 'Другие варианты...';
$labels['adveditor'] = 'Расширенный редактор';
$labels['stdeditor'] = 'Стандартный редактор';
$labels['messageredirectcopy'] = 'отослать копию на адрес';
$labels['messagecopyto'] = 'сохранить копию в папку';
$labels['body'] = 'Тело сообщения';
$labels['auto'] = 'автоматически';
$labels['raw'] = 'в исходнике';
$labels['text'] = 'в тексте';
$labels['other'] = 'часть сообщения';
$labels['bodycontentpart'] = 'MIME-тип части сообщения';
$labels['notchecked'] = 'не проверено';
$labels['spamlevelisgreaterthanequal'] = 'больше чем или равна';
$labels['spamlevelislessthanequal'] = 'меньше чем или равна';
$labels['spamlevelequals'] = 'равна';
$labels['i;ascii-casemap'] = 'сравнение строк без учета регистра';
$labels['i;octet'] = 'точное сравнение строк';
$labels['i;ascii-numeric'] = 'числовое сравнение';
$labels['selectruleset'] = 'Выбрать набор правил';
$labels['activeruleset'] = '%s (активный)';
$labels['activateruleset'] = 'Активировать набор правил';
$labels['newruleset'] = 'Создать набор правил';
$labels['delruleset'] = 'Удалить набор правил';
$labels['renameruleset'] = 'Переименовать набор правил';
$labels['copy'] = 'Скопировать';
$labels['copyexistingfilter'] = 'Скопировать существующие фильтры';
$labels['copytoruleset'] = 'Скопировать фильтры в другой набор';
$labels['copyfromruleset'] = 'Скопировать фильтры из существующего набора';
$labels['time'] = 'Время';
$labels['weekday'] = 'День недели';

$messages = array();
$messages['nosieverules'] = 'Фильтры не найдены.';
$messages['filterdeleteconfirm'] = 'Вы уверены, что хотите удалить этот фильтр?';
$messages['ruledeleteconfirm'] = 'Вы уверены, что хотите удалить это правило?';
$messages['actiondeleteconfirm'] = 'Вы уверены, что хотите удалить это действие?';
$messages['filterunknownerror'] = 'Неизвестная ошибка сервера.';
$messages['filterconnerror'] = 'Невозможно соединиться с сервером sieve.';
$messages['filterdeleteerror'] = 'Невозможно удалить фильтр. Возникла ошибка сервера.';
$messages['filterdeleted'] = 'Фильтр успешно удален.';
$messages['filtersaved'] = 'Фильтр успешно сохранен.';
$messages['filtersaveerror'] = 'Невозможно сохранить фильтр. Возникла ошибка сервера.';
$messages['vacperiodexp'] = 'Количество дней, в течение которого корреспонденты не будут получать повторные сообщения об вашем отсутствии, вне зависимости от того, сколько раз они вам написали за это время.<br /><br />Например: Если Вася написал вам письмо в понедельник и вы установили периодичность в 7 (дней), то Вася получит сообщение о Вашем отсутствии в понедельник, и больше не будет получать таких сообщений до следующего понедельника, даже если он писал вам много раз.';
$messages['vachandleexp'] = 'Метка связывает  несколько сообщений об отсутствии вместе: после того, как одно из них было отправлено, другие сообщения с той же меткой не будут отправляться в течение этого периода..';
$messages['vactoexp'] = 'Список дополнительных адресов получателей, для которых будет работать "автоответчик". Ответы не будут отправляться, если адреса получателя принятого сообщения нет в этом списке.';
$messages['vactoexp_adv'] = 'Несколько адресов разделяются запятой (,). Например, test1@example.com,test2@example.com,test3@example.com.';
$messages['vactoexp_err'] = 'Ошибка: Несколько ардесов должны быть разделены запятыми.';
$messages['norulename'] = 'Пожалуйста, введите имя для этого фильтра.';
$messages['ruleexists'] = 'Фильтр с таким именем уже существует. Введите другое имя фильтра.';
$messages['noheader'] = 'Пожалуйста, введите имя заголовка для проверки.';
$messages['headerbadchars'] = 'Ошибка: указанная строка содержит запрещенные символы.';
$messages['noheadervalue'] = 'Пожалуйста, введите значение для проверки заголовка.';
$messages['sizewrongformat'] = 'Ошибка: размер сообщения должен быть числовым.';
$messages['noredirect'] = 'Пожалуйста, введите адрес электронной почты для перенаправки сообщения.';
$messages['redirectaddresserror'] = 'Ошибка: введен неверный адрес.';
$messages['noreject'] = 'Пожалуйста, введите текст сообщения.';
$messages['vacnoperiod'] = 'Пожалуйста, укажите периодичность отсылки уведомлений';
$messages['vacperiodwrongformat'] = 'Ошибка: Периодичность должна быть положительным целым числом';
$messages['vacnomsg'] = 'Пожалуйста, введите текст сообщения.';
$messages['notifynomethod'] = 'Пожалуйста, введите способ отправки уведомления.';
$messages['notifynomsg'] = 'Пожалуйста, введите текст сообщения.';
$messages['sieveruleexp'] = 'Пожалуйста, введите одно или несколько правил, согласно которым будут проверяться сообщения. Фильтры работают в том порядке, в котором они появляются слева. Если соответствие найдено, остальные фильтры тестироваться не будут.';
$messages['sieveactexp'] = 'Пожалуйста, выберите одно или несколько действий. Эти действия будут выполняться для каждого сообщения, соответствующего вышеуказанным правилам.';
$messages['sieveheadershlp'] = 'Ниже находятся несколько примеров заголовков, которые могут быть проверены фильтрами. Выберите заголовок, чтобы добавить его, либо введите другой в поле ввода.';
$messages['movingfilter'] = 'Перемещение фильтра...';
$messages['noexistingfilters'] = 'Фильтров не найдено!';
$messages['importdefault'] = '<b>Фильтры по умолчанию:</b> Доступен набор фильтров по умолчанию. Использовать?';
$messages['importother'] = '<b>Импорт фильтров:</b> Найден набор фильтров от приложения %s. Импортировать?';
$messages['switchtoadveditor'] = 'Переключение в режим расширенного редактора позволяет редактировать исходный текст сценария \'sieve\'. Изменения, сделанные в этом режиме, могут не восприниматься графическим интерфейсом, и могут быть потеряны в случае сохранения фильтров в графическом интерфейсе. Продолжить?';
$messages['filterimported'] = 'Фильтр успешно импортирован';
$messages['filterimporterror'] = 'Ошибка сервера во время импорта фильтра. Импорт не выполнен';
$messages['notifyinvalidmethod'] = 'Формат метода неверен. Нужно указать URI, например: «mailto:alert@example.com».';
$messages['nobodycontentpart'] = 'Укажите часть тела сообщения';
$messages['badoperator'] = 'Такой оператор не может использоваться в данном правиле';
$messages['filteractionerror'] = 'Запрошенное действие не поддерживается сервером';
$messages['filtermissingerror'] = 'Указанное правило не существует';
$messages['contentpartexp'] = 'MIME-тип или часть сообщения для проверки. Например, «message/rfc822», «text/html», «audio/mp3» или «image».';
$messages['delrulesetconf'] = 'Действительно удалить этот набор правил?';
$messages['rulesetexists'] = 'Набор правил с таким названием уже существует. Выберите другое название.';
$messages['copyexisting'] = '<b>Копирование существующего набора правил:</b> Скопировать фильтры из существующего набора правил в текущий набор?';
$messages['filtercopied'] = 'Фильтры успешно скопированы';
$messages['nosieverulesets'] = 'Наборы правил не найдены.';
$messages['baddateformat'] = 'Ошибка: Дата должна вводиться в формате ГГГГ-ММ-ДД';
$messages['badtimeformat'] = 'Ошибка: Время должно вводиться в формате ЧЧ:ММ:СС';

?>