<?php
/* Author: Alessio Cecchi */

$labels = array();
$labels['filters'] = 'Filtri';
$labels['managefilters'] = 'Gestisci filtri';
$labels['filtername'] = 'Nome del filtro';
$labels['disablerule'] = 'Disabilita regola';
$labels['disabled'] = 'Disabilitata';
$labels['newfilter'] = 'Nuovo filtro';
$labels['moveup'] = 'Muovi su';
$labels['movedown'] = 'Muovi giù';
$labels['filterallof'] = 'soddisfa tutte le seguenti regole';
$labels['filteranyof'] = 'soddisfa una qualunque delle seguenti regole';
$labels['filterany'] = 'tutti i messaggi';
$labels['filtercontains'] = 'contiene';
$labels['filternotcontains'] = 'non contiene';
$labels['filteris'] = 'è uguale a';
$labels['filterisnot'] = 'non è uguale a';
$labels['filterexists'] = 'esiste';
$labels['filternotexists'] = 'non esiste';
$labels['filterregex'] = 'soddisfa espressione regolare';
$labels['filternotregex'] = 'non soddisfa espressione regolare';
$labels['filterunder'] = 'è minore di';
$labels['filterover'] = 'è maggiore di';
$labels['filterbefore'] = 'prima';
$labels['filterafter'] = 'dopo';
$labels['filteradvoptions'] = 'altre opzioni...';
$labels['spamtest'] = 'Probabilità Spam';
$labels['operator'] = 'Operatore';
$labels['comparator'] = 'Comparatore';
$labels['isgreaterthan'] = 'è maggiore di';
$labels['isgreaterthanequal'] = 'è maggiore o uguale a';
$labels['islessthan'] = 'è minore di';
$labels['islessthanequal'] = 'è minore o uguale a';
$labels['equals'] = 'è uguale a';
$labels['notequals'] = 'è diverso da';
$labels['countisgreaterthan'] = 'numero di occorrenze maggiore di';
$labels['countisgreaterthanequal'] = 'numero di occorrenze maggiore o uguale a';
$labels['countislessthan'] = 'numero di occorrenze minore di';
$labels['countislessthanequal'] = 'numero di occorrenze minore o uguale a';
$labels['countequals'] = 'numero di occorrenze uguale a';
$labels['countnotequals'] = 'numero di occorrenze diverso da';
$labels['valueisgreaterthan'] = 'valore maggiore di';
$labels['valueisgreaterthanequal'] = 'valore maggiore o uguale a';
$labels['valueislessthan'] = 'valore minore di';
$labels['valueislessthanequal'] = 'valore minore o uguale a';
$labels['valueequals'] = 'valore uguale a';
$labels['valuenotequals'] = 'valore diverso da';
$labels['userpart'] = 'parte utente dell\'indirizzo uguale a';
$labels['notuserpart'] = 'parte utente dell\'indirizzo diversa da';
$labels['detailpart'] = 'parte del dettaglio dell\'indirizzo uguale a';
$labels['notdetailpart'] = 'parte del dettaglio dell\'indirizzo diverso da';
$labels['domainpart'] = 'dominio uguale a';
$labels['notdomainpart'] = 'dominio diverso da';
$labels['teststring'] = 'Stringa di test';
$labels['messagemoveto'] = 'Sposta il messaggio in';
$labels['messageredirect'] = 'Reindirizza il messaggio in';
$labels['messageimapflags'] = 'Contrassegna il messaggio come';
$labels['messagereject'] = 'Respingi con il seguente messaggio';
$labels['messagevacation'] = 'Messaggio di assenza';
$labels['messagekeep'] = 'Conserva il messaggio';
$labels['messagediscard'] = 'Scarta il messaggio';
$labels['messagenotify'] = 'Invia notifica';
$labels['messagestop'] = 'Smetti di processare i filtri';
$labels['messagehelp'] = 'Cos\'è questo?';
$labels['sieveorigsubj'] = 'Appendi l\'oggetto originale alla risposta';
$labels['sievevachandle'] = 'Gestisci';
$labels['method'] = 'Metodo';
$labels['options'] = 'Opzioni';
$labels['messagesrules'] = 'Regole del filtro';
$labels['messagesactions'] = 'Azioni del filtro';
$labels['sieveto'] = 'Alias';
$labels['sievefrom'] = 'Da';
$labels['flag'] = 'Importanza';
$labels['importancen'] = 'Nessuna';
$labels['importance1'] = 'Alta';
$labels['importance2'] = 'Normale';
$labels['importance3'] = 'Bassa';
$labels['flagread'] = 'Letto';
$labels['flagdeleted'] = 'Cancellato';
$labels['flaganswered'] = 'Risposto';
$labels['flagdraft'] = 'Bozza';
$labels['flagflagged'] = 'Etichettati';
$labels['addsieverule'] = 'Aggiungi un\'altra regola sotto';
$labels['addsieveact'] = 'Aggiungi un\'altra azione sotto';
$labels['deletesieverule'] = 'Cancella questa regola';
$labels['deletesieveact'] = 'Cancella questa azione';
$labels['envelopefrom'] = 'Envelope Da';
$labels['envelopeto'] = 'Envelope A';
$labels['otherheader'] = 'Altra intestazione';
$labels['period'] = 'Periodo';
$labels['message'] = 'Messaggio';
$labels['sieveruleheaders'] = 'Vedi esempi di altre intestazioni';
$labels['examplefilters'] = 'Filtri di esempio';
$labels['importfilters'] = 'Importa Filtri';
$labels['usedefaultfilter'] = 'Usa i filtri predefiniti';
$labels['importfilter'] = 'Importa filtri';
$labels['moreactions'] = 'Altre opzioni...';
$labels['adveditor'] = 'Editor avanzato';
$labels['stdeditor'] = 'Editor semplice';
$labels['messageredirectcopy'] = 'Invia una copia a';
$labels['messagecopyto'] = 'Copia il messaggio in';
$labels['body'] = 'Corpo';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Testo';
$labels['other'] = 'Altro';
$labels['bodycontentpart'] = 'Contenuto del corpo';
$labels['notchecked'] = 'non etichettato';
$labels['spamlevelisgreaterthanequal'] = 'è maggiore o uguale a';
$labels['spamlevelislessthanequal'] = 'è minore o uguale a';
$labels['spamlevelequals'] = 'è uguale a';
$labels['i;ascii-casemap'] = 'corrispondenza non sensibile alle maiuscole';
$labels['i;octet'] = 'corrispondenza esatta';
$labels['i;ascii-numeric'] = 'corrispondenza numerica';
$labels['selectruleset'] = 'Seleziona set di regole';
$labels['activeruleset'] = '%s (attivo)';
$labels['activateruleset'] = 'Attiva questo set di regole';
$labels['newruleset'] = 'Crea un nuovo set di regole';
$labels['delruleset'] = 'Cancella questo set di regole';
$labels['renameruleset'] = 'Rinomina questo set di regole';
$labels['copy'] = 'Copia';
$labels['copyexistingfilter'] = 'Copia i filtri esistenti';
$labels['copytoruleset'] = 'Copia il filtro in un altro set di regole';
$labels['copyfromruleset'] = 'Copia i filtri da un set di regole esistente';
$labels['time'] = 'Ora';
$labels['weekday'] = 'Giorno della settimana';
$labels['virustest'] = 'Probabilità Virus';
$labels['novirus'] = 'nessun virus trovato';
$labels['virusremoved'] = 'virus trovato e rimosso';
$labels['viruscured'] = 'virus trovato e curato';
$labels['possiblevirus'] = 'il messaggio potrebbe contenere un virus';
$labels['definitevirus'] = 'il messaggio potrebbe essere certamente un virus';
$labels['addheader'] = 'Aggiungi un header';
$labels['removeheader'] = 'Rimuovi un header';
$labels['headername'] = 'Nome header';
$labels['headervalue'] = 'Contenuto header';
$labels['headerappend'] = 'Accoda ad un header esistente';
$labels['headerindex'] = 'Indice header';
$labels['headerdelall'] = 'Tutte le occorrenze';
$labels['last'] = 'ultimo';
$labels['createfilter'] = 'Crea filtro...';
$labels['createfilterbased'] = 'Crea un filtro basato su questo messaggio';

$messages = array();
$messages['nosieverules'] = 'Nessun filtro trovato.';
$messages['filterdeleteconfirm'] = 'Sei sicuro/a di di voler cancellare questo filtro?';
$messages['ruledeleteconfirm'] = 'Sei sicuro/a di voler cancellare questa regola?';
$messages['actiondeleteconfirm'] = 'Sei sicuro/a di voler cancellare questa azione?';
$messages['filterunknownerror'] = 'Errore sconosciuto del server';
$messages['filterconnerror'] = 'Impossibile connettersi al server sieve';
$messages['filterdeleteerror'] = 'Impossibile cancellare il filtro. Errore del server';
$messages['filterdeleted'] = 'Filtro cancellato con successo';
$messages['filtersaved'] = 'Filtro salvato con successo';
$messages['filtersaveerror'] = 'Impossibile salvare il filtro. Errore del server';
$messages['vacperiodexp'] = 'Il periodo è il numero di giorni durante i quali il messaggio non sarà più spedito allo stesso utente, a prescindere da quante volte ti abbiano contattato.<br /><br />Per esempio: Se Marco ti scrive una email lunedì e il periodo è impostato a 7, Marco riceverà un messaggio di assenza lunedì ma non ne riceverà altri fino al lunedì successivo, indipendentemente dal n. di email che invia durante la settimana.';
$messages['vachandleexp'] = 'Un handle può essere usato per collegare diversi messaggi di assenza insieme, una volta che un messaggio è stato inviato nessun altro con lo stesso handle sarà rispedito in quel periodo.';
$messages['vactoexp'] = 'Lista degli indirizzi dei destinatari aggiuntivi che sono inclusi nella risposta automatica. Se un destinatario non è il tuo indirizzo principale e non è in questa lista, nessun messaggio sarà inviato.';
$messages['vactoexp_adv'] = 'Separare i diversi indirizzi con una virgola. Per esempio: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Errore: i diversi indirizzi devono essere separati da virgole';
$messages['norulename'] = 'Inserire un nome per il filtro';
$messages['ruleexists'] = 'Un filtro con questo nome esiste già. Per favore scegline un altro.';
$messages['noheader'] = 'Inserire il nome dell\'intestazione da testare';
$messages['headerbadchars'] = 'Errore: L\'intestazione contiene caratteri proibiti';
$messages['noheadervalue'] = 'Inserire un valore con cui testare l\'intestazione';
$messages['sizewrongformat'] = 'Errore: Le dimensioni del messaggio devono essere espresse in formato numerico';
$messages['noredirect'] = 'Inserire un indirizzo email a cui reindirizzare i messaggi';
$messages['redirectaddresserror'] = 'Errore: L\'indirizzo non è valido';
$messages['noreject'] = 'Inserire un messaggio da inviare con le email respinte';
$messages['vacnoperiod'] = 'Inserire il numero di giorni per il periodo in cui il messaggio non sarà reinviato alla stessa persona';
$messages['vacperiodwrongformat'] = 'Errore: Il periodo deve essere un numero maggiore o uguale a 1';
$messages['vacnomsg'] = 'Inserire un testo per il messaggio';
$messages['notifynomethod'] = 'Inserire un metodo con cui la notifica dovrà essere inviata';
$messages['notifynomsg'] = 'Inserire un testo per il messaggio';
$messages['sieveruleexp'] = 'Definire una o più regole con cui ogni messaggio sarà testato. I filtri sono lanciati nell\'ordine in cui essi appaiono nella sinistra della schermata. Se una regola viene soddisfatta nessun altro filtro viene valutato.';
$messages['sieveruleexp_stop'] = 'Definire una o più regole con le quali testare i messaggi. I filtri sono lanciati nell\'ordine in cui appaiono nella sinistra della schermata fintanto che non viene eseguita un\'azione di \'Stop\'.';
$messages['sieveactexp'] = 'Selezionare una delle opzioni. Queste azioni saranno eseguite per ogni messaggio che soddiferà le regole qui sopra.';
$messages['sieveheadershlp'] = 'Questi sono alcuni esempi di intestazioni che possono essere testate dal filtro. Scegliere un\'intestazione per aggiungerla alla regola, o scriverne una personalizzata nella casella qui sopra.';
$messages['movingfilter'] = 'Sto spostando il filtro...';
$messages['noexistingfilters'] = 'Nessun filtro esistente rilevato!';
$messages['importdefault'] = '<b>Usa i filtri predefiniti:</b> C\'è un set predefinito di filtri disponibile. Vuoi usare questi filtri?';
$messages['importother'] = '<b>Importa filtri:</b> è stato trovato un altro set di filtri da %s. Vuoi importare questi filtri nel tuo set corrente?';
$messages['switchtoadveditor'] = 'Passare all\'editor avanzato ti consente di editare il \'file sieve\' direttamente. Ogni cambiamento qui potrà risultare illeggibile nell\'editor normale e può essere perso quando i filtri sono salvati usando l\'editor normale. Vuoi continuare?';
$messages['filterimported'] = 'Filtro importato con successo';
$messages['filterimporterror'] = 'Impossibile importare il filtro. Errore del server.';
$messages['notifyinvalidmethod'] = 'Il metodo non sembra essere scritto in un formato valido, deve essere un URI, per esempio: `mailto:alert@example.com`.';
$messages['nobodycontentpart'] = 'Inserire una parte di contenuto da testare';
$messages['badoperator'] = 'Spiacente, l\'operatore che hai selezionato non può essere usato in questa regola';
$messages['filteractionerror'] = 'L\'azione che hai richiesto non è supportata dal server';
$messages['filtermissingerror'] = 'Impossibile trovare la regola richiesta';
$messages['contentpartexp'] = 'Il MIME-type o la parte specifica del messaggio che dovrebbe essere testato. Per esempio: `message/rfc822`, `text/html`, `audio/mp3` o `image`.';
$messages['delrulesetconf'] = 'Sei sicuro di voler cancellare questo set di regole?';
$messages['rulesetexists'] = 'Un set di regole con questo nome esiste già. Inseriscine un altro.';
$messages['copyexisting'] = '<b>Copia del set di regole:</b> Vuoi copiare i filtri dal set di regole esistente nel set corrente?';
$messages['filtercopied'] = 'Filtro copiato con successo';
$messages['nosieverulesets'] = 'Nessun set di regole trovato.';
$messages['baddateformat'] = 'Errore: Inserire la data nel formato YYYY-MM-DD';
$messages['badtimeformat'] = 'Errore: Inserire l\'ora nel formato HH:MM:SS';
$messages['missingfoldername'] = 'Errore: Per favore inserisci il nome di una cartella';
$messages['eheadernoname'] = 'Errore: Per favore inserisci il nome di un header';
$messages['eheadernoval'] = 'Errore: Per favore inserisci il contenuto di un header';

?>