<?php
/* Author: Philip Weir */

$labels = array();
$labels['filters'] = 'Filters';
$labels['filtersname'] = 'Filters ($name)';
$labels['managefilters'] = 'Manage message filters';
$labels['filtername'] = 'Filter name';
$labels['disablerule'] = 'Disable rule';
$labels['disabled'] = 'Disabled';
$labels['newfilter'] = 'New filter';
$labels['editfilter'] = 'Edit filter';
$labels['moveup'] = 'Move up';
$labels['movedown'] = 'Move down';
$labels['filterallof'] = 'matching all of the following rules';
$labels['filteranyof'] = 'matching any of the following rules';
$labels['filterany'] = 'all messages';
$labels['filtercontains'] = 'contains';
$labels['filternotcontains'] = 'does not contain';
$labels['filteris'] = 'is equal to';
$labels['filterisnot'] = 'is not equal to';
$labels['filterexists'] = 'exists';
$labels['filternotexists'] = 'does not exist';
$labels['filtermatches'] = 'wildcard match';
$labels['filternotmatches'] = 'is not a wildcard match';
$labels['filterregex'] = 'matches regular expression';
$labels['filternotregex'] = 'does not match regular expression';
$labels['filterunder'] = 'is less than';
$labels['filterover'] = 'is more than';
$labels['filterbefore'] = 'is before';
$labels['filterafter'] = 'is after';
$labels['filterbeforeequal'] = 'is on or before';
$labels['filterafterequal'] = 'is on or after';
$labels['filteradvoptions'] = 'more options...';
$labels['spamtest'] = 'Spam Probability';
$labels['operator'] = 'Operator';
$labels['comparator'] = 'Comparator';
$labels['isgreaterthan'] = 'is greater than';
$labels['isgreaterthanequal'] = 'is greater than or equal to';
$labels['islessthan'] = 'is less than';
$labels['islessthanequal'] = 'is less than or equal to';
$labels['equals'] = 'is equal to';
$labels['notequals'] = 'does not equal';
$labels['countisgreaterthan'] = 'count is greater than';
$labels['countisgreaterthanequal'] = 'count is greater than or equal to';
$labels['countislessthan'] = 'count is less than';
$labels['countislessthanequal'] = 'count is less than or equal to';
$labels['countequals'] = 'count is equal to';
$labels['countnotequals'] = 'count does not equal';
$labels['valueisgreaterthan'] = 'value is greater than';
$labels['valueisgreaterthanequal'] = 'value is greater than or equal to';
$labels['valueislessthan'] = 'value is less than';
$labels['valueislessthanequal'] = 'value is less than or equal to';
$labels['valueequals'] = 'value is equal to';
$labels['valuenotequals'] = 'value does not equal';
$labels['userpart'] = 'user part equals';
$labels['notuserpart'] = 'user part does not equal';
$labels['detailpart'] = 'detail part equals';
$labels['notdetailpart'] = 'detail part does not equal';
$labels['domainpart'] = 'domain part equals';
$labels['notdomainpart'] = 'domain part does not equal';
$labels['teststring'] = 'Test string';
$labels['messagemoveto'] = 'Move message to';
$labels['messageredirect'] = 'Redirect message to';
$labels['messageimapflags'] = 'Mark message as';
$labels['messagereject'] = 'Reject with message';
$labels['messagevacation'] = 'Out of Office Message';
$labels['messagekeep'] = 'Keep message';
$labels['messagediscard'] = 'Discard message';
$labels['messagenotify'] = 'Send notification';
$labels['messagestop'] = 'Stop processing filters';
$labels['messagehelp'] = 'What is this?';
$labels['sieveorigsubj'] = 'Append original subject to response';
$labels['sievevachandle'] = 'Handle';
$labels['method'] = 'Method';
$labels['options'] = 'Options';
$labels['messagesrules'] = 'Filter Rules';
$labels['messagesactions'] = 'Filter Actions';
$labels['sieveto'] = 'Aliases';
$labels['sievefrom'] = 'From';
$labels['flag'] = 'Importance';
$labels['importancen'] = 'None';
$labels['importance1'] = 'High';
$labels['importance2'] = 'Normal';
$labels['importance3'] = 'Low';
$labels['flagread'] = 'Read';
$labels['flagdeleted'] = 'Deleted';
$labels['flaganswered'] = 'Answered';
$labels['flagdraft'] = 'Draft';
$labels['flagflagged'] = 'Flagged';
$labels['addsieverule'] = 'Add another rule, below this one';
$labels['addsieveact'] = 'Add another action, below this one';
$labels['deletesieverule'] = 'Delete this rule';
$labels['deletesieveact'] = 'Delete this action';
$labels['envelopefrom'] = 'Envelope From';
$labels['envelopeto'] = 'Envelope To';
$labels['otherheader'] = 'Other header';
$labels['period'] = 'Period';
$labels['days'] = 'days';
$labels['seconds'] = 'seconds';
$labels['message'] = 'Message';
$labels['sieveruleheaders'] = 'View examples of other headers';
$labels['examplefilters'] = 'Example Filters';
$labels['importfilters'] = 'Import Filters';
$labels['usedefaultfilter'] = 'Use default filters';
$labels['importfilter'] = 'Import filters';
$labels['moreactions'] = 'More options...';
$labels['adveditor'] = 'Advanced editor';
$labels['stdeditor'] = 'Standard editor';
$labels['messageredirectcopy'] = 'Send a copy to';
$labels['messagecopyto'] = 'Copy message to';
$labels['body'] = 'Body';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Text';
$labels['other'] = 'Other';
$labels['bodycontentpart'] = 'Content Part';
$labels['notchecked'] = 'not checked';
$labels['spamlevelisgreaterthanequal'] = 'is greater than or equal to';
$labels['spamlevelislessthanequal'] = 'is less than or equal to';
$labels['spamlevelequals'] = 'is equal to';
$labels['i;ascii-casemap'] = 'case-insensitive string match';
$labels['i;octet'] = 'exact string match';
$labels['i;ascii-numeric'] = 'numeric match';
$labels['selectruleset'] = 'Select ruleset';
$labels['activeruleset'] = '%s (active)';
$labels['activateruleset'] = 'Activate this ruleset';
$labels['isactive'] = 'Active ruleset';
$labels['isinactive'] = 'Inactive ruleset';
$labels['newruleset'] = 'Create a new ruleset';
$labels['delruleset'] = 'Delete this ruleset';
$labels['renameruleset'] = 'Rename this ruleset';
$labels['copy'] = 'Copy';
$labels['copyexistingfilter'] = 'Copy existing filters';
$labels['copytoruleset'] = 'Copy filter to another ruleset';
$labels['copyfromruleset'] = 'Copy filters from existing ruleset';
$labels['time'] = 'Time';
$labels['weekday'] = 'Weekday';
$labels['virustest'] = 'Virus Probability';
$labels['novirus'] = 'no virus found';
$labels['virusremoved'] = 'virus found and removed';
$labels['viruscured'] = 'virus found and cured';
$labels['possiblevirus'] = 'message possibly contains a virus';
$labels['definitevirus'] = 'message definitely contains a virus';
$labels['addheader'] = 'Add header';
$labels['removeheader'] = 'Remove header';
$labels['headername'] = 'Header name';
$labels['headervalue'] = 'Header value';
$labels['headerappend'] = 'Append to existing message header.';
$labels['headerindex'] = 'Header index';
$labels['headerdelall'] = 'all occurrences';
$labels['last'] = 'last';
$labels['arialabelfiltersform'] = 'Filters edit form';
$labels['createfilter'] = 'Create filter';
$labels['createfilterbased'] = 'Create a filter based on this message';
$labels['automaticreply'] = 'Automatic reply';
$labels['manageautoreply'] = 'Manage automatic reply';
$labels['enableautoreply'] = 'Enable automatic reply';
$labels['sendonlyperiod'] = 'Send message only during this period:';
$labels['datefrom'] = 'From';
$labels['dateto'] = 'To';

$messages = array();
$messages['nosieverules'] = 'No filters found.';
$messages['filterdeleteconfirm'] = 'Are you sure you want to delete this filter?';
$messages['ruledeleteconfirm'] = 'Are you sure you want to delete this rule?';
$messages['actiondeleteconfirm'] = 'Are you sure you want to delete this action?';
$messages['filterunknownerror'] = 'Unknown server error';
$messages['filterconnerror'] = 'Unable to connect to sieve server';
$messages['filterdeleteerror'] = 'Unable to delete filter. Server error occurred';
$messages['filterdeleted'] = 'Filter deleted successfully';
$messages['filtersaved'] = 'Filter saved successfully';
$messages['filtersaveerror'] = 'Unable to save filter. Server error occurred';
$messages['vacperiodexp'] = 'The period is the number of days during which the message will not be resent to the same user, no matter how many times they contact you.<br /><br />For example: If Joe emails you on Monday and the period is set to 7 then Joe will receive an out of office message on Monday but will not get another one until the following Monday, no matter how many emails he sends you during the week.';
$messages['vachandleexp'] = 'A handle can be used to link different out of office messages together, once one message has been sent no other message with the same handle will be resent in that period.';
$messages['vactoexp'] = 'List of additional recipient addresses which are included in the auto replying. If a mail\'s recipient is not your main address and it\'s not on this list, no message will be sent.';
$messages['vactoexp_adv'] = 'Separate multiple aliases with a comma (,). For Example: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Error: Multiple aliases should be separated with a comma (,)';
$messages['norulename'] = 'Please enter a name for this filter';
$messages['ruleexists'] = 'A filter with this name already exists. Please enter another';
$messages['noheader'] = 'Please enter the name of the header to test';
$messages['headerbadchars'] = 'Error: Header contains forbidden characters';
$messages['noheadervalue'] = 'Please enter a value to test the header against';
$messages['sizewrongformat'] = 'Error: Message size must be numeric';
$messages['noredirect'] = 'Please enter an email address to redirect messages to';
$messages['redirectaddresserror'] = 'Error: Address appears invalid';
$messages['noreject'] = 'Please enter a message to send with rejected email';
$messages['vacnoperiod'] = 'Please enter a number of days for the period in which the message will not be resent to the same person';
$messages['vacperiodwrongformat'] = 'Error: The period must be a number greater than or equal to 1';
$messages['vacnomsg'] = 'Please enter some text for your message';
$messages['vacmsgone'] = 'Error: Only one Out of Office Message per filter permitted';
$messages['notifynomethod'] = 'Please enter a method by which the notification should be sent';
$messages['notifynomsg'] = 'Please enter some text for your message';
$messages['sieveruleexp'] = 'Please define one or more rules against which each message will be tested. Filters are run in the order in which they appear on the left of this screen, if a match is found no further filters will be tested.';
$messages['sieveruleexp_stop'] = 'Please define one or more rules against which each message will be tested. Filters are run in the order in which they appear on the left of this screen until a \'Stop\' action is met.';
$messages['sieveactexp'] = 'Please select from the options below. These actions will be performed for any message matching the above rule(s).';
$messages['sieveheadershlp'] = 'Below are some examples of other headers that can be tested by the filters. Select a header to add it to the rule or enter a custom one in the box above.';
$messages['movingfilter'] = 'Moving filter...';
$messages['noexistingfilters'] = 'No existing filters detected!';
$messages['importdefault'] = '<b>Use default filters:</b> There is a set of default filters available. Would you like to use these filters?';
$messages['importother'] = '<b>Import filters:</b> Another set of filters from %s has been found. Would you like to import these filters into your current set?';
$messages['switchtoadveditor'] = 'Switching to the advanced editor allows you to edit the sieve file directly. Any changes here may be unreadable in the normal editor and may be lost when filters are saved using the normal editor. Do you wish to continue?';
$messages['filterimported'] = 'Filter imported successfully';
$messages['filterimporterror'] = 'Unable to import filter. Server error occurred';
$messages['notifyinvalidmethod'] = 'The method does not appear to be written in a valid format, it must be a URI. For example: `mailto:alert@example.com`.';
$messages['nobodycontentpart'] = 'Please enter a content part to test';
$messages['badoperator'] = 'Sorry the operator you selected cannot be used in this rule';
$messages['filteractionerror'] = 'The action you requested is not supported by the server';
$messages['filtermissingerror'] = 'Unable to find the rule requested';
$messages['contentpartexp'] = 'The MIME-type or specific part of the message which should be tested. For example: `message/rfc822`, `text/html`, `audio/mp3` or `image`.';
$messages['delrulesetconf'] = 'Are you sure you want to delete this ruleset?';
$messages['rulesetexists'] = 'A ruleset with this name already exists. Please enter another';
$messages['norulesetname'] = 'Please enter a name for this ruleset';
$messages['copyexisting'] = '<b>Copy exiting ruleset:</b> Would you like to copy filters from an existing ruleset into your current set?';
$messages['filtercopied'] = 'Filter copied successfully';
$messages['nosieverulesets'] = 'No rulesets found.';
$messages['baddateformat'] = 'Error: Please enter the date in the format YYYY-MM-DD';
$messages['badtimeformat'] = 'Error: Please enter the time in the format HH:MM:SS';
$messages['missingfoldername'] = 'Error: Please enter a folder name';
$messages['eheadernoname'] = 'Error: Please enter a header name';
$messages['eheadernoval'] = 'Error: Please enter a header value';
$messages['addtoexisting'] = 'Select an existing filter from the list on the left hand side to add the new criteria to it or select from the options below.';
$messages['autoreplysaved'] = 'Automatic reply saved';
$messages['pleaseinitialise'] = 'Please go to the \'Filters\' tab to initialise your filters before setting up an automatic reply';

?>