<roundcube:object name="doctype" value="html5" />
<html>
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sieverules.css" />
</head>
<roundcube:if condition="env:extwin" /><body class="noscroll extwin"><roundcube:else /><body class="noscroll"><roundcube:endif />

<roundcube:include file="/includes/header.html" />

<div id="mainscreen" class="offset">

<h1 class="voice"><roundcube:label name="settings" /> : <roundcube:label name="sieverules.filters" /></h1>

<roundcube:include file="/includes/settingstabs.html" />

<div id="settings-right">

<div id="sieverules-list" class="uibox listbox" role="navigation" aria-labelledby="aria-label-pefsection">
<h2 id="aria-label-pefsection" class="boxtitle"><roundcube:object name="sieveruleslisttitle" activeicon="/this/images/tick.png" inactiveicon="/this/images/cross.png" /></h2>
<div class="scroller withfooter">
	<roundcube:object name="sieveruleslist" id="sieverules-table" class="listing sieverules-table fixedheader" noheader="true" activeicon="/this/images/tick.png" inactiveicon="/this/images/cross.png" />
	<roundcube:object name="sieverulesexamplelist" id="sieverules-examples" class="listing sieverules-examples fixedheader" />
</div>
<div class="boxfooter">
	<roundcube:button command="plugin.sieverules.add" type="link" title="sieverules.newfilter" class="listbutton add disabled" classAct="listbutton add" innerClass="inner" content="+" /><roundcube:button command="plugin.sieverules.delete" type="link" title="delete" class="listbutton delete disabled" classAct="listbutton delete" innerClass="inner" content="-" /><roundcube:if condition="config:sieverules_multiplerules == true || config:sieverules_adveditor == 1 || config:sieverules_adveditor == 2" /><roundcube:button name="sieverulesactions" id="sieverulesactionsmenulink" type="link" title="sieverules.moreactions" class="listbutton groupactions"  onclick="UI.toggle_popup('sieverulesactionsmenu', event, {id: 'sieverulesactionsmenu', obj:$('#sieverulesactionsmenu'), above:1}); return false" innerClass="inner" content="&#9881;" tabindex="0" aria-disabled="false" tabindex="0" role="button" /><roundcube:endif />
</div>
</div>

<div id="sieverules-details" class="uibox contentbox">
<div class="iframebox">
	<roundcube:object name="sieverulesframe" id="preferences-frame" style="width:100%; height:100%" frameborder="0" src="/watermark.html" title="sieverules.arialabelfiltersform" />
</div>
</div>

</div>

</div>

<roundcube:include file="/includes/footer.html" />

<div id="sieverulesactionsmenu" class="popupmenu" aria-hidden="true">
<ul class="toolbarmenu" role="menu">
<roundcube:if condition="config:sieverules_multiplerules == true" />
<li role="menuitem" class="separator_below"><roundcube:button command="plugin.sieverules.ruleset_dialog" type="link" label="sieverules.newruleset" classAct="active" /></li>
<roundcube:object name="rulelist" type="link" />
<li role="menuitem" class="separator_above"><roundcube:button command="plugin.sieverules.ruleset_dialog" prop="rename_ruleset" type="link" label="sieverules.renameruleset" classAct="active" /></li>
<li role="menuitem"><roundcube:button command="plugin.sieverules.del_ruleset" type="link" label="sieverules.delruleset" classAct="active" /></li>
<li role="menuitem"><roundcube:button command="plugin.sieverules.activate_ruleset" type="link" label="sieverules.activateruleset" classAct="active" /></li>
<roundcube:endif />
<roundcube:if condition="config:sieverules_adveditor == 1 || config:sieverules_adveditor == 2" />
<li role="menuitem" <roundcube:exp expression="config:sieverules_multiplerules == true ? ' class=separator_above' : ''" />><roundcube:button command="plugin.sieverules.sieverules_adveditor" prop="1" type="link" label="sieverules.adveditor" classAct="active" /></li>
<roundcube:endif />
</ul>
</div>

<script type="text/javascript">
/* <![CDATA[ */

$(document).ready(function(){
	new rcube_splitter({id:'sieverulesviewsplitter', p1: '#sieverules-list', p2: '#sieverules-details', orientation: 'v', relative: true, start:266, min:180, size:12}).init();

	if ($('#sieverules-list-examples').length > 0) {
		var filtersHeight = parseInt($('#sieverules-list').height() - 210);
		new rcube_splitter({id:'sievefiltersviewsplitter', p1: '#sieverules-list-filters', p2: '#sieverules-list-examples', orientation: 'h', relative: true, start: filtersHeight}).init();
	}
});

/* ]]> */
</script>

</body>
</html>