<?php
/* Author: Andi Lõhmus */

$labels = array();
$labels['filters'] = 'Filtrid';
$labels['managefilters'] = 'Halda sisenevate kirjade filtreid';
$labels['filtername'] = 'Filtri nimi';
$labels['disablerule'] = 'Keela filter';
$labels['disabled'] = 'Keelatud';
$labels['newfilter'] = 'Uus filter';
$labels['moveup'] = 'Liiguta ülesse';
$labels['movedown'] = 'Liiguta alla';
$labels['filterallof'] = 'vastab kõikidele järgnevatele reeglitele';
$labels['filteranyof'] = 'vastab mõnele järgnevatest reeglitest';
$labels['filterany'] = 'kõik kirjad';
$labels['filtercontains'] = 'sisaldab';
$labels['filternotcontains'] = 'ei sisalda';
$labels['filteris'] = 'on võrdne kui';
$labels['filterisnot'] = 'ei ole võrdne kui';
$labels['filterexists'] = 'on olemas';
$labels['filternotexists'] = 'pole olemas';
$labels['filterregex'] = 'vastab regulaaravaldisele';
$labels['filternotregex'] = 'ei vasta regulaaravaldisele';
$labels['filterunder'] = 'on vähem kui';
$labels['filterover'] = 'on rohkem kui';
$labels['filteradvoptions'] = 'rohkem valikuid';
$labels['spamtest'] = 'Spammi tõenäosus';
$labels['operator'] = 'Operaator';
$labels['comparator'] = 'Komparaator';
$labels['isgreaterthan'] = 'on suurem kui';
$labels['isgreaterthanequal'] = 'on suurem või samaväärne ';
$labels['islessthan'] = 'on vähem kui';
$labels['islessthanequal'] = 'on vähem või võrdne kui';
$labels['equals'] = 'on võrdne';
$labels['notequals'] = 'ei ole võrdne';
$labels['countisgreaterthan'] = 'arv on suurem kui';
$labels['countisgreaterthanequal'] = 'arv on suurem või võrdne kui';
$labels['countislessthan'] = 'arv on väiksem kui';
$labels['countislessthanequal'] = 'arv on väiksem või võrdne kui';
$labels['countequals'] = 'arv on võrdne';
$labels['countnotequals'] = 'arv ei ole võrdne';
$labels['valueisgreaterthan'] = 'väärtus on suurem kui';
$labels['valueisgreaterthanequal'] = 'väärtus on suurem või võrdne kui';
$labels['valueislessthan'] = 'väärtus on võiksem kui';
$labels['valueislessthanequal'] = 'väärtus on väiksem või võrdne kui';
$labels['valueequals'] = 'väärtus on võrdne';
$labels['valuenotequals'] = 'väärtus ei ole võrdne';
$labels['userpart'] = 'kasutajanimi (enne "@" või "+" märki) on võrdne';
$labels['notuserpart'] = 'kasutajanimi (enne "@" või "+" märki) ei ole võrdne';
$labels['detailpart'] = 'nime osa peale "+" märki on võrdne';
$labels['notdetailpart'] = 'nime osa peale "+" märki ei ole võrdne';
$labels['domainpart'] = 'domeeninimi (peale "@") on võrdne';
$labels['notdomainpart'] = 'domeeninimi (peale "@") ei ole võrdne';
$labels['teststring'] = 'Võrdle reaga';
$labels['messagemoveto'] = 'Liiguta kiri';
$labels['messageredirect'] = 'Suuna teisele aadressile';
$labels['messageimapflags'] = 'Märgi kiri';
$labels['messagereject'] = 'Keeldu';
$labels['messagevacation'] = 'Saada kontorist väljas teade';
$labels['messagekeep'] = 'Säilita kiri';
$labels['messagediscard'] = 'Kustuta kiri ära';
$labels['messagenotify'] = 'Saada teadaanne';
$labels['messagestop'] = 'Lõpeta filtrite töö';
$labels['messagehelp'] = 'Mis see on?';
$labels['sieveorigsubj'] = 'Lisa originaal vastusele';
$labels['sievevachandle'] = 'Käsitle';
$labels['method'] = 'Meetod';
$labels['options'] = 'Valikud';
$labels['messagesrules'] = 'Filtri reeglid';
$labels['messagesactions'] = 'Filtri toimingud';
$labels['sievefrom'] = 'Saatja';
$labels['flag'] = 'Tähtsus';
$labels['importancen'] = 'Mitte ükski';
$labels['importance1'] = 'Kõrge';
$labels['importance2'] = 'Normaalne';

$messages = array();

?>