<?php
/* Author: Kepi */

$labels = array();
$labels['filters'] = 'Filtry';
$labels['filtersname'] = 'Filtry ($name)';
$labels['managefilters'] = 'Spravovat filtry';
$labels['filtername'] = 'Název filtru';
$labels['disablerule'] = 'Vypnout filtr';
$labels['disabled'] = 'vypnuto';
$labels['newfilter'] = 'Nový filtr';
$labels['editfilter'] = 'Upravit filtr';
$labels['moveup'] = 'Posunout nahoru';
$labels['movedown'] = 'Posunout dolů';
$labels['filterallof'] = 'odpovídá všem pravidlům';
$labels['filteranyof'] = 'odpovídá alespoň jednomu pravidlu';
$labels['filterany'] = 'všechny zprávy';
$labels['filtercontains'] = 'obsahuje';
$labels['filternotcontains'] = 'neobsahuje';
$labels['filteris'] = 'je rovno';
$labels['filterisnot'] = 'není rovno';
$labels['filterexists'] = 'existuje';
$labels['filternotexists'] = 'neexistuje';
$labels['filtermatches'] = 'odpovídá';
$labels['filternotmatches'] = 'neodpovídá';
$labels['filterregex'] = 'odpovídá regulárnímu výrazu';
$labels['filternotregex'] = 'neodpovídá regulárnímu výrazu';
$labels['filterunder'] = 'je méně než';
$labels['filterover'] = 'je více než';
$labels['filterbefore'] = 'je před';
$labels['filterafter'] = 'je po';
$labels['filterbeforeequal'] = 'je před nebo rovno';
$labels['filterafterequal'] = 'je po nebo rovno';
$labels['filteradvoptions'] = 'více možností...';
$labels['spamtest'] = 'Pravděpodobnost spamu';
$labels['operator'] = 'Operátor';
$labels['comparator'] = 'Porovnávání';
$labels['isgreaterthan'] = 'je větší než';
$labels['isgreaterthanequal'] = 'je větší nebo rovno';
$labels['islessthan'] = 'je menší než';
$labels['islessthanequal'] = 'je menší nebo rovno';
$labels['equals'] = 'je rovno';
$labels['notequals'] = 'není rovno';
$labels['countisgreaterthan'] = 'počet je větší než';
$labels['countisgreaterthanequal'] = 'počet je větší nebo roven';
$labels['countislessthan'] = 'počet je menší než';
$labels['countislessthanequal'] = 'počet je menší nebo roven';
$labels['countequals'] = 'počet je roven';
$labels['countnotequals'] = 'počet není roven';
$labels['valueisgreaterthan'] = 'hodnota je větší než';
$labels['valueisgreaterthanequal'] = 'hodnota je větší nebo rovna';
$labels['valueislessthan'] = 'hodnota je menší než';
$labels['valueislessthanequal'] = 'hodnota je menší nebo rovna';
$labels['valueequals'] = 'hodnota je rovna';
$labels['valuenotequals'] = 'hodnota není rovna';
$labels['userpart'] = 'část uživatele je rovna';
$labels['notuserpart'] = 'část uživatele není rovna';
$labels['detailpart'] = 'upřesňující část je rovna';
$labels['notdetailpart'] = 'upřesňující část není rovna';
$labels['domainpart'] = 'doménová část je rovna';
$labels['notdomainpart'] = 'doménová část není rovna';
$labels['teststring'] = 'Testovací řetězec';
$labels['messagemoveto'] = 'Přesunout zprávy do';
$labels['messageredirect'] = 'Přesměrovat zprávy na';
$labels['messageimapflags'] = 'Označit zprávy jako';
$labels['messagereject'] = 'Odmítnout se zprávou';
$labels['messagevacation'] = 'Automatická odpověď';
$labels['messagekeep'] = 'Ponechat zprávu';
$labels['messagediscard'] = 'Zahodit zprávu';
$labels['messagenotify'] = 'Odeslat upozornění';
$labels['messagestop'] = 'Přerušit vykonávání filtrů';
$labels['messagehelp'] = 'Co je toto?';
$labels['sieveorigsubj'] = 'K odpovědi připojit původní předmět';
$labels['sievevachandle'] = 'Štítek';
$labels['method'] = 'Metoda';
$labels['options'] = 'Možnosti';
$labels['messagesrules'] = 'Pravidla filtru';
$labels['messagesactions'] = 'Akce filtru';
$labels['sieveto'] = 'Aliasy';
$labels['sievefrom'] = 'Od';
$labels['flag'] = 'Priorita';
$labels['importancen'] = 'Žádná';
$labels['importance1'] = 'Vysoká';
$labels['importance2'] = 'Normální';
$labels['importance3'] = 'Nízká';
$labels['flagread'] = 'Přečtené';
$labels['flagdeleted'] = 'Odstraněné';
$labels['flaganswered'] = 'Zodpovězené';
$labels['flagdraft'] = 'Koncept';
$labels['flagflagged'] = 'Označené';
$labels['addsieverule'] = 'Přidat další pravidlo (pod toto pravidlo)';
$labels['addsieveact'] = 'Přidat další akci (pod tuto akci)';
$labels['deletesieverule'] = 'Odstranit toto pravidlo';
$labels['deletesieveact'] = 'Odstranit tuto akci';
$labels['envelopefrom'] = 'Skutečný odesílatel';
$labels['envelopeto'] = 'Skutečný adresát';
$labels['otherheader'] = 'Další hlavička';
$labels['period'] = 'Prodleva';
$labels['days'] = 'dní';
$labels['sekund'] = 'seconds';
$labels['message'] = 'Zpráva';
$labels['sieveruleheaders'] = 'Zobrazit ukázky dalších hlaviček';
$labels['examplefilters'] = 'Ukázkové filtry';
$labels['importfilters'] = 'Import filtrů';
$labels['usedefaultfilter'] = 'Použít výchozí filtry';
$labels['importfilter'] = 'Importovat filtry';
$labels['moreactions'] = 'Více voleb...';
$labels['adveditor'] = 'Pokročilý editor';
$labels['stdeditor'] = 'Normální editor';
$labels['messageredirectcopy'] = 'Odeslat kopii na';
$labels['messagecopyto'] = 'Kopírovat zprávu do';
$labels['body'] = 'Tělo zprávy';
$labels['auto'] = 'Automaticky';
$labels['raw'] = 'Surové';
$labels['text'] = 'Textové';
$labels['other'] = 'Ostatní';
$labels['bodycontentpart'] = 'Obsahová část';
$labels['notchecked'] = 'Nekontrolováno';
$labels['spamlevelisgreaterthanequal'] = 'je větší nebo rovno';
$labels['spamlevelislessthanequal'] = 'je menší nebo rovno';
$labels['spamlevelequals'] = 'je rovno';
$labels['i;ascii-casemap'] = 'shoda bez ohledu na velikost písmen';
$labels['i;octet'] = 'přesná shoda';
$labels['i;ascii-numeric'] = 'číselná shoda';
$labels['selectruleset'] = 'Vyberte sadu pravidel';
$labels['activeruleset'] = '%s (aktivní)';
$labels['activateruleset'] = 'Aktivovat tuto sadu filtrů';
$labels['isactive'] = 'Aktivní sada filtrů';
$labels['isinactive'] = 'Neaktivní sada filtrů';
$labels['newruleset'] = 'Vytvořit novou sadu filtrů';
$labels['delruleset'] = 'Odstranit tuto sadu filtrů';
$labels['renameruleset'] = 'Přejmenovat tuto sadu filtrů';
$labels['copy'] = 'Kopírovat';
$labels['copyexistingfilter'] = 'Kopírovat existující filtry';
$labels['copytoruleset'] = 'Kopírovat filtr do jiné sady';
$labels['copyfromruleset'] = 'Kopířovat filtry z existující sady';
$labels['time'] = 'Čas';
$labels['weekday'] = 'Den v týdnu';
$labels['virustest'] = 'Pravděpodobnost viru';
$labels['novirus'] = 'žádný virus nenalezen';
$labels['virusremoved'] = 'virus nalezen a odstraněn';
$labels['viruscured'] = 'virus nalezen a vyléčen';
$labels['possiblevirus'] = 'zpráva pravděpodobně obsahuje virus';
$labels['definitevirus'] = 'zpráva určitě obsahuje virus';
$labels['addheader'] = 'Přidat hlavičku';
$labels['removeheader'] = 'Odebrat hlavičku';
$labels['headername'] = 'Název hlavičky';
$labels['headervalue'] = 'Hodnota hlavičky';
$labels['headerappend'] = 'Přidat k existujícím hlavičkám.';
$labels['headerindex'] = 'Index hlavičky';
$labels['headerdelall'] = 'všechny výskyty';
$labels['last'] = 'poslední';
$labels['arialabelfiltersform'] = 'Formulář pro úpravu filtrů';
$labels['createfilter'] = 'Vytvořit filtr...';
$labels['createfilterbased'] = 'Vytvořit filtr na základě této zprávy';
$labels['automaticreply'] = 'Automatická odpověď';
$labels['manageautoreply'] = 'Spravovat automatickou odpověď';
$labels['enableautoreply'] = 'Zapnout automatickou odpověď';
$labels['sendonlyperiod'] = 'Automatickou odpověď odesílat pouze v tomto období:';
$labels['datefrom'] = 'Od';
$labels['dateto'] = 'Do';

$messages = array();
$messages['nosieverules'] = 'Nenalezeny žádné filtry.';
$messages['filterdeleteconfirm'] = 'Opravdu chcete smazat tento filtr?';
$messages['ruledeleteconfirm'] = 'Opravdu chcete smazat toto pravidlo?';
$messages['actiondeleteconfirm'] = 'Opravdu chcete smazat tuto akci?';
$messages['filterunknownerror'] = 'Neznámá chyba serveru.';
$messages['filterconnerror'] = 'Nepodařilo se připojit k serveru sieve.';
$messages['filterdeleteerror'] = 'Nepodařilo se smazat filtr. Nastala chyba serveru.';
$messages['filterdeleted'] = 'Filtr úspěšně smazán.';
$messages['filtersaved'] = 'Filt úspěšně uložen.';
$messages['filtersaveerror'] = 'Nepodařilo se uložit filtr. Nastala chyba serveru.';
$messages['vacperiodexp'] = 'Prodleva je počet dní, během kterých nebude zpráva doručena stejnému uživateli, nehledě na to, kolikrát vás kontaktuje.<br /><br />Příklad: Pokud vám Honza napíše v pondělí a prodleva je nastavena na 7, Honza obdrží zprávu o vaší nedostupnosti v pondělí, ale do dalšího pondělí už žádnou další zprávu nedostane, nehledě na počet mailů, které vám během týdne pošle.';
$messages['vachandleexp'] = 'Štítek může být použit ke spojení více různých oznámení o nedostupnosti dohromady. Jakmile je jedna zpráva zaslána, žádná další se stejným štítkem už v dané době zaslána nebude.';
$messages['vactoexp'] = 'Seznam dalších emailů, které jsou v automatické odpovědi zahrnuty. Pokud není příjemcem emailu vaše hlavní adresa a není na tomto seznamu, žádná zpráva nebude odeslána.';
$messages['vactoexp_adv'] = 'Jednotlivé adresy oddělte čárkou. Například: test1@adresa.cz,test2@adresa.cz,test3@adresa.cz';
$messages['vactoexp_err'] = 'Chyba: Více aliasů musí být odděleno čárkou.';
$messages['norulename'] = 'Zadejte prosím jméno pro tento filtr.';
$messages['ruleexists'] = 'Filtr se stejným jménem již existuje. Zadejte prosím jiné.';
$messages['noheader'] = 'Zadejte prosím jméno hlavičky k otestování.';
$messages['headerbadchars'] = 'Chyba: hlavička obsahuje zakázané znaky.';
$messages['noheadervalue'] = 'Zadejte prosím hodnotu, vůči které bude hlavička testována.';
$messages['sizewrongformat'] = 'Chyba: velikost zprávy musí být číslo.';
$messages['noredirect'] = 'Zadejte prosím emailovou adresu, na kterou se má zpráva přesměrovat.';
$messages['redirectaddresserror'] = 'Chyba: zdá se, že je email chybný.';
$messages['noreject'] = 'Zadejte prosím zprávu, která se odešle spolu s odmítnutým emailem.';
$messages['vacnoperiod'] = 'Zadejte prosím počet dní pro prodlevu, během které nebude zpráva zasílána stejné osobě.';
$messages['vacperiodwrongformat'] = 'Chyba: prodleva musí být číslo větší nebo rovné 1.';
$messages['vacnomsg'] = 'Zadejte prosím nějaký text pro vaši zprávu.';
$messages['vacmsgone'] = 'Chyba: Ve filtru je povolena pouze jedna automatická odpověď';
$messages['notifynomethod'] = 'Zadejte prosím metodu, jakou má být notifikace zaslána.';
$messages['notifynomsg'] = 'Zadejte prosím nějaký text pro vaši zprávu.';
$messages['sieveruleexp'] = 'Prosím přidejte jedno nebo více pravidel vůči kterým bude každá zpráva testována. Filtry jsou vyhodnocovány v pořadí v jakém jsou uvedeny v sloupci vlevo. Pokud je nalezena shoda, žádný další filtr se již nevyhodnocuje.';
$messages['sieveruleexp_stop'] = 'Zadejte prosím jedno nebo více pravidel vůči kterým bude každá zpráva testována. Filtry jsou vyhodnocovány v pořadí v jakém jsou uvedeny v sloupci vlevo dokud není dosaženo \'Přerušení\' akce.';
$messages['sieveactexp'] = 'Prosím vyberte si z voleb níže. Akce budou vykonány pro jakoukoliv zprávu, která vyhovuje pravidlům výše.';
$messages['sieveheadershlp'] = 'Níže je několik případu hlaviček, které mohou být ve filtrech testovány. Pro přidání do pravidla vyberte hlavičku nebo zadejte vlastní v poli nahoře.';
$messages['movingfilter'] = 'Přesouvám filtr...';
$messages['noexistingfilters'] = 'Nenalezeny žádné existující filtry!';
$messages['importdefault'] = '<b>Použít výchozí filtry:</b> Je dostupná sada výchozích filtrů. Přejte si tuto sadu využít?';
$messages['importother'] = '<b>Importovat filtry:</b> Byla nalezena jiná sada filtrů z %s. Chcete tyto filtry importovat do stávající sady?';
$messages['switchtoadveditor'] = 'Přepnutí do pokročilého editoru vám umožní přímo upravovat soubor sieve filtrů. Jakékoliv provedené změny mohou být nečitelné v normálním editoru a mohou být ztraceny, pokud je v normálním editoru uložíte. Přejete si pokračovat?';
$messages['filterimported'] = 'Filtry úspěšně naimportovány.';
$messages['filterimporterror'] = 'Nelze importovat filtry. Nastala chyba serveru.';
$messages['notifyinvalidmethod'] = 'Metoda není napsána ve správném formátu, musí se jednat o URI. Například: `mailto:upozorneni@adresa.cz`.';
$messages['nobodycontentpart'] = 'Zadejte prosím obsahovou část k otestování.';
$messages['badoperator'] = 'Omlouváme se, ale operátor, který jste vybrali, nemůže být v tomto pravidle použit.';
$messages['filteractionerror'] = 'Akce, které jste si vyžádali, není podporována serverem.';
$messages['filtermissingerror'] = 'Nepodařilo se najít vyžádané pravidlo.';
$messages['contentpartexp'] = 'MIME-typ nebo konkrétní část zprávy, která má být testována. Například: `message/rfc822`, `text/html`, `audio/mp3` or `image`.';
$messages['delrulesetconf'] = 'Opravdu chcete smazat tuto sadu pravidel?';
$messages['rulesetexists'] = 'Sada pravidel s tímto jménem již existuje. Zadejte prosím jinou.';
$messages['norulesetname'] = 'Zadejte prosím jméno pro tuto sadu pravidel';
$messages['copyexisting'] = '<b>Kopírovat existující sadu pravidel:</b> Chcete zkopírovat filtry z existující sady pravidel do vybrané sady?';
$messages['filtercopied'] = 'Filtry úspěšně zkopírovány.';
$messages['nosieverulesets'] = 'Nenalezeny žádné sady pravidel.';
$messages['baddateformat'] = 'Chyba: Zadejte prosím datum ve formátu YYYY-MM-DD';
$messages['badtimeformat'] = 'Chyba: Zadejte prosím čas ve formátu HH:MM:SS';
$messages['missingfoldername'] = 'Chyba: Zadejte prosím jméno složky';
$messages['eheadernoname'] = 'Chyba: Zadejte prosím název hlavičky';
$messages['eheadernoval'] = 'Chyba: Zadejte prosím hodnotu hlavičky';
$messages['addtoexisting'] = 'Vyberte ze sloupce vlevo filtr, který chcete upravit, nebo pokračujte výběrem níže.';
$messages['autoreplysaved'] = 'Automatická odpověď úspěšně uložena';
$messages['pleaseinitialise'] = 'Před nastavením automatické odpovědi je třeba inicializovat filtry. Navštivte prosím položku \'Filtry\'.';

?>