<?php
/* Author: GràciaNet */

$labels = array();
$labels['filters'] = 'Filtres';
$labels['managefilters'] = 'Gesti&oacute;  de filtres';
$labels['filtername'] = 'Nom del filtre';
$labels['disablerule'] = 'Desactivar regla';
$labels['disabled'] = 'Desactivada';
$labels['newfilter'] = 'Nou filtre';
$labels['moveup'] = 'Moure amunt';
$labels['movedown'] = 'Moure avall';
$labels['filterallof'] = 'coincideix amb TOTES les regles seg&uuml;ents';
$labels['filteranyof'] = 'coincideix amb ALGUNA de les seg&uuml;ents regles';
$labels['filterany'] = 'tots els missatges';
$labels['filtercontains'] = 'cont&eacute;';
$labels['filternotcontains'] = 'no cont&eacute';
$labels['filteris'] = '&eacutes igual a';
$labels['filterisnot'] = 'es diferent de';
$labels['filterexists'] = 'existeix';
$labels['filternotexists'] = 'no existeix';
$labels['filterregex'] = 'coincideix amb l\'expressi&oacute;  regular';
$labels['filternotregex'] = 'no coincideix amb l\'expressi&oacute;  regular';
$labels['filterunder'] = '&eacutes menys que';
$labels['filterover'] = '&eacutes m&eacutes que';
$labels['filteradvoptions'] = 'm&eacutes opcions...';
$labels['spamtest'] = 'Probabilitat de Spam';
$labels['operator'] = 'Operador';
$labels['comparator'] = 'Comparador';
$labels['isgreaterthan'] = '&eacutes major que';
$labels['isgreaterthanequal'] = '&eacutes major o igual que';
$labels['islessthan'] = '&eacutes menor que';
$labels['islessthanequal'] = '&eacutes menor o igual que';
$labels['equals'] = '&eacutes igual a';
$labels['notequals'] = '&eacutes diferent de';
$labels['countisgreaterthan'] = 'quantitat &eacutes major que';
$labels['countisgreaterthanequal'] = 'quantitat ñes major o igual que';
$labels['countislessthan'] = 'quantitat &eacutes menor que';
$labels['countislessthanequal'] = 'quantitat &eacutes menor o igual que';
$labels['countequals'] = 'quantitat &eacutes igual a';
$labels['countnotequals'] = 'quantitat &eacutes diferent de';
$labels['valueisgreaterthan'] = 'valor &eacutes major que';
$labels['valueisgreaterthanequal'] = 'valor &eacutes major o igual que';
$labels['valueislessthan'] = 'valor &eacutes menor que';
$labels['valueislessthanequal'] = 'valor &eacutes menor o igual que';
$labels['valueequals'] = 'valor &eacutes igual a';
$labels['valuenotequals'] = 'valor &eacutes diferent de';
$labels['userpart'] = 'la part de l\'usuari &eacutes igual a';
$labels['notuserpart'] = 'la part de l\'usuari &eacutes diferent de';
$labels['detailpart'] = 'la part del detall &eacutes igual a';
$labels['notdetailpart'] = 'la part del detall &eacutes diferent de';
$labels['domainpart'] = 'la part del domini &eacutes igual a';
$labels['notdomainpart'] = 'la part del domini &eacutes diferent de';
$labels['teststring'] = 'Iniciant prova';
$labels['messagemoveto'] = 'Moure missatge a';
$labels['messageredirect'] = 'Redirigir missatge a';
$labels['messageimapflags'] = 'Marcar missatge com';
$labels['messagereject'] = 'Rebutjar amb avís';
$labels['messagevacation'] = 'Missatge de vacances';
$labels['messagekeep'] = 'Mantenir missatges';
$labels['messagediscard'] = 'Descartar missatge';
$labels['messagenotify'] = 'Enviar notificaci&oacute; ';
$labels['messagestop'] = 'Deixar de processar filtres';
$labels['messagehelp'] = 'Qu&egrave; &eacutes això?';
$labels['sieveorigsubj'] = 'Afegir assumpte original a la resposta';
$labels['sievevachandle'] = 'Manejador';
$labels['method'] = 'M&egrave;tode';
$labels['options'] = 'Opcions';
$labels['messagesrules'] = 'Regles de filtrat';
$labels['messagesactions'] = 'Accions del filtre';
$labels['sieveto'] = 'Àlies';
$labels['sievefrom'] = 'De';
$labels['flag'] = 'Marca';
$labels['importancen'] = 'Cap';
$labels['importance1'] = '1';
$labels['importance2'] = '2';
$labels['importance3'] = '3';
$labels['flagread'] = 'Llegit';
$labels['flagdeleted'] = 'Eliminat';
$labels['flaganswered'] = 'Respost';
$labels['flagdraft'] = 'Esborrany';
$labels['flagflagged'] = 'Marcat';
$labels['addsieverule'] = 'Afegir una altra regla despr&eacutes d\'aquesta';
$labels['addsieveact'] = 'Afegir una altra acci&oacute;  despr&eacutes d\'aquesta';
$labels['deletesieverule'] = 'Eliminar aquesta regla';
$labels['deletesieveact'] = 'Eliminar aquesta acci&oacute; ';
$labels['envelopefrom'] = 'Remitent a la capçalera';
$labels['envelopeto'] = 'Destinatari e la capçalera';
$labels['otherheader'] = 'Una altra capçalera';
$labels['period'] = 'Període';
$labels['message'] = 'Missatge';
$labels['sieveruleheaders'] = 'Veure exemples d\'altres capçaleres';
$labels['examplefilters'] = 'Filtres d\'exemple';
$labels['importfilters'] = 'Importar filtres';
$labels['usedefaultfilter'] = 'Utilitzar filters per defecte';
$labels['importfilter'] = 'Importar filtre';
$labels['adveditor'] = 'Editor avançat';
$labels['messageredirectcopy'] = 'Envía una còpia a ';
$labels['messagecopyto'] = 'Copiar missatge a ';
$labels['body'] = 'Cos';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Text';
$labels['other'] = 'Altre';
$labels['bodycontentpart'] = 'Contingut';
$labels['notchecked'] = 'no seleccionat';
$labels['spamlevelisgreaterthanequal'] = '&eacutes major o igual que';
$labels['spamlevelislessthanequal'] = '&eacutes menor o igual que';
$labels['spamlevelequals'] = '&eacutes igual a';
$labels['selectruleset'] = 'Escollir conjunt de regles';
$labels['activeruleset'] = '%s (actiu)';
$labels['activateruleset'] = 'Activar aquest conjunt de regles';
$labels['newruleset'] = 'Crear un nou conjunt de regles.';
$labels['delruleset'] = 'Eliminar aquest conjunt de regles';
$labels['renameruleset'] = 'Renombrar aquest conjunt de regles';
$labels['copy'] = 'Copiar';
$labels['copyexistingfilter'] = 'Copiar els filtres existentes';
$labels['copytoruleset'] = 'Copiar filtre a un altre conjunt de regles';
$labels['copyfromruleset'] = 'Copiar filtres des d\'un conjunt de regles existents';

$messages = array();
$messages['nosieverules'] = 'No s\'han trobat filtres.';
$messages['filterdeleteconfirm'] = 'Est&agrave;s segur de voler eliminar aquest filtre?';
$messages['ruledeleteconfirm'] = 'Est&agrave;s segur de voler eliminar aquesta regla?';
$messages['actiondeleteconfirm'] = 'Est&agrave;s segur de voler eliminar aquesta acci&oacute; ?';
$messages['filterunknownerror'] = 'Error desconegut en el servidor';
$messages['filterconnerror'] = 'Impossible connectar amb el servidor sieve';
$messages['filterdeleteerror'] = 'No s\'ha pogut eliminar el filtre. Error del servidor';
$messages['filterdeleted'] = 'Filtre eliminat';
$messages['filtersaved'] = 'Filtre guardat';
$messages['filtersaveerror'] = 'Incapaç de guardar el filtre. Error en el servidor';
$messages['vacperiodexp'] = 'El període &eacutes el número de dies que el missatge no ser&agrave; reenviat al mateix usuari, sense importar el nombre de vegades que intenti posar-se en contacte amb tu<br /><br />Por ejemplo, si en Jaume envia un misssatge un dilluns, i t&eacute un període fixat en 7, en Jaume rebr&agrave; un avís de vacances el dilluns però no en rebr&agrave; cap altre fins al proper dilluns, malgrat env&iuml;i m&eacutes missatges durant la setmana.';
$messages['vachandleexp'] = 'Es pot usar un manejador per a vincular diferents missatges de vacances tots junts. Un cop s\'env&iuml;i el missatge no se n\'enviar&agrave; un altre que contingut el mateix manejador durant el període definit.';
$messages['vactoexp'] = 'Llista de destinataris addicionals que seran inclosos en l\'auto-resposta. Si un usuari no &eacutes la sefa adreça personal i no est&agrave; a la llista no se li enviar&agrave;n missatges.';
$messages['norulename'] = 'Cal assignar un nom al filtre';
$messages['ruleexists'] = 'Ja existeix un filtre amb aquest nom. Escolleix-ne un altre';
$messages['noheader'] = 'Heu d\'introdu&iuml;r el nom de la capçalera a verificar';
$messages['headerbadchars'] = 'Error: La capçalera cont&eacute car&agrave;cters no permesos';
$messages['noheadervalue'] = 'Ingresseu un valor per a comparar-lo amb la capçalera';
$messages['sizewrongformat'] = 'Error: El tamany del missatge ha de ser num&egrave;ric';
$messages['noredirect'] = 'Introdu&iuml;u una adreça de correu a la qual redirigir tots els missatges';
$messages['redirectaddresserror'] = 'Error: Adreça no v&agrave;lida';
$messages['noreject'] = 'Introdu&iuml;u el text a enviar en els missatges rebutjats';
$messages['vacnoperiod'] = 'Introdu&iuml;u el número de dies per al període que el missatge no ser&agrave; reenviat a la mateixa persona';
$messages['vacperiodwrongformat'] = 'Error: El període ha de ser de m&eacutes d\'1 dia';
$messages['vacnomsg'] = 'Introdu&iuml;u un text per al missatge';
$messages['notifynomethod'] = 'Introdu&iuml;u un m&egrave;tode a trav&eacutes del qual s\'enviar&agrave; la notificaci&oacute; ';
$messages['notifynomsg'] = 'Introdu&iuml;u un text per al seu missatge';
$messages['sieveruleexp'] = 'Heu de definir una o m&eacutes regles que s\'empraran per a comprar els missatges. Els filtres s&oacute; n executats en l\'ordre que apareixen a l\'esquerra d\'aquesta pantalla. Si es troba una coincid&egrave;ncia, la resta del filtres no es comproven.';
$messages['sieveactexp'] = 'Seleccioneu una de les opcions que apareixen a continuaci&oacute; . Aquesta acci&oacute;  ser&agrave; executada per cada missatge que encaixi amb les regles definides a sobre d\'aquest text.';
$messages['sieveheadershlp'] = 'A continuaci&oacute;  hi ha alguns exemples de capçaleres que poden verificar-se amb filtres. Seleccioni\'n una per afegir a la regla o introdu&iuml;u-ne una de pròpia en el requadre de dalt.';
$messages['movingfilter'] = 'Movent filtre...';
$messages['noexistingfilters'] = 'No s\'han detectat filtres!';
$messages['importdefault'] = '<b>Emprar filtres per defecte:</b> Hi ha un joc de filtres per defecte disponibles. Voleu instalar una còpia d\'aquests filtres?';
$messages['importother'] = '<b>Importar filtres:</b> S\'ha trobat un altre joc de filtres de %s. Voleu importar-los a la llsita de filtres?';
$messages['switchtoadveditor'] = 'L\'editor avançat li permet editar les regles de sieve directament. Qualsevol canvi que faci ser&agrave; il.legible per l\'editor normal de regles i es perder&agrave; si guarda modificacions amb l\'editor normal. Voleu continuar?';
$messages['filterimported'] = 'Filtre importat correctament';
$messages['filterimporterror'] = 'No s\'ha pogut importar el filtre . Error en el servidor';
$messages['badoperator'] = 'Ho lamentem, però l\'operador seleccionat no es pot usar en aquesta regla.';
$messages['filteractionerror'] = 'L\'acci&oacute;  requerida no est&agrave; disponible en aquest servidor.';
$messages['filtermissingerror'] = 'No s\'ha pogut localitzar la regla solicitada.';
$messages['delrulesetconf'] = 'Esteu segur de voler eliminar aquest conjunt de regles?';
$messages['rulesetexists'] = 'Ja existeix un conjunt de regles amb aquest nom. Escolliu-ne un altre.';
$messages['copyexisting'] = '<b> Copia el seg&uuml;ent conjunt de regles:</b> Voleu importar els filtres d\'un conjunt de regles existents al conjunt actual?';
$messages['filtercopied'] = 'Filtre copiat correctament';
$messages['nosieverulesets'] = 'No s\'han trobat regles.';

?>