<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sieverules.css" />
<script type="text/javascript" src="/functions.js"></script>
<script type="text/javascript" src="/splitter.js"></script>

<style type="text/css">

#sieverules-list { width: <roundcube:exp expression="!empty(cookie:sieverulesviewsplitter) ? cookie:sieverulesviewsplitter-5 : 190" />px; }
<roundcube:if condition="env:examples" />
#sieverules-list-filters { bottom: <roundcube:exp expression="!empty(cookie:sievefiltersviewsplitter) ? cookie:sievefiltersviewsplitter+5 : 0" />px; }
<roundcube:else />
#sieverules-list-filters { bottom: 0; }
<roundcube:endif />
#sieverules-details { left: <roundcube:exp expression="!empty(cookie:sieverulesviewsplitter) ? cookie:sieverulesviewsplitter+5 : 200" />px; }
</style>

</head>
<body onload="rcmail_ui.popups.sieverulesmenu = {id: 'sieverulesactionsmenu', obj:$('#sieverulesactionsmenu'), above:1};">

<roundcube:include file="/includes/taskbar.html" />
<roundcube:include file="/includes/header.html" />
<roundcube:include file="/includes/settingstabs.html" />

<div id="mainscreen">

<div id="sieverules-list">
<div class="sieverules-boxcontent">
<roundcube:object name="sieveruleslist" id="sieverules-table" class="records-table sieverules-table fixedheader" activeicon="/this/images/tick.png" inactiveicon="/this/images/cross.png" />
<roundcube:object name="sieverulesexamplelist" id="sieverules-examples" class="records-table sieverules-examples fixedheader" />
</div>
<div class="boxfooter">
<roundcube:button command="plugin.sieverules.add" type="link" title="sieverules.newfilter" class="buttonPas addgroup" classAct="button addgroup" content=" " />
<roundcube:button command="plugin.sieverules.delete" type="link" title="delete" class="buttonPas delgroup" classAct="button delgroup" content=" " />
<roundcube:if condition="config:sieverules_multiplerules == true || config:sieverules_adveditor == 1 || config:sieverules_adveditor == 2" />
<roundcube:button name="sieverulesactions" id="sieverulesmenulink" type="link" title="sieverules.moreactions" class="button groupactions" onclick="rcmail_ui.show_popupmenu('sieverulesmenu'); return false" content=" " />
<roundcube:endif />
</div>
</div>

<script type="text/javascript">
	var rulesviewsplit = new rcube_splitter({id:'sieverulesviewsplitter', p1: 'sieverules-list', p2: 'sieverules-details', orientation: 'v', relative: true, start: 195});
	rcmail.add_onload('rulesviewsplit.init()');

	if ($('#sieverules-list-examples').length > 0) {
		var filtersHeight = parseInt($('#sieverules-list').height() - 210);
		var filtersviewsplit = new rcube_splitter({id:'sievefiltersviewsplitter', p1: 'sieverules-list-filters', p2: 'sieverules-list-examples', orientation: 'h', relative: true, start: filtersHeight});
		rcmail.add_onload('filtersviewsplit.init()');
	}
</script>

<div id="sieverules-details">
<roundcube:object name="sieverulesframe" id="prefs-frame" width="100%" height="100%" frameborder="0" src="/watermark.html" />
</div>

</div>

<div id="sieverulesactionsmenu" class="popupmenu">
	<ul>
	<roundcube:if condition="config:sieverules_multiplerules == true" />
	<li class="separator_below"><roundcube:button command="plugin.sieverules.ruleset_dialog" type="link" label="sieverules.newruleset" classAct="active" /></li>
	<roundcube:object name="rulelist" type="link" />
	<li class="separator_above"><roundcube:button command="plugin.sieverules.ruleset_dialog" prop="rename_ruleset" type="link" label="sieverules.renameruleset" classAct="active" /></li>
	<li><roundcube:button command="plugin.sieverules.del_ruleset" type="link" label="sieverules.delruleset" classAct="active" /></li>
	<li><roundcube:button command="plugin.sieverules.activate_ruleset" type="link" label="sieverules.activateruleset" classAct="active" /></li>
	<roundcube:endif />
	<roundcube:if condition="config:sieverules_adveditor == 1 || config:sieverules_adveditor == 2" />
	<li<roundcube:exp expression="config:sieverules_multiplerules == true ? ' class=separator_above' : ''" />><roundcube:button command="plugin.sieverules.sieverules_adveditor" prop="1" type="link" label="sieverules.adveditor" classAct="active" /></li>
	<roundcube:endif />
	</ul>
</div>

<script type="text/javascript">
rcube_init_mail_ui();
</script>

</body>
</html>