<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><roundcube:object name="pagetitle" /></title>
<roundcube:include file="/includes/links.html" />
<link rel="stylesheet" type="text/css" href="/this/sieverules.css" />
<script type="text/javascript" src="/functions.js"></script>
</head>
<body onload="rcmail_ui.popups.sieverulesmenu = {id: 'sieverulesactionsmenu', obj:$('#sieverulesactionsmenu'), above:1};">

<roundcube:include file="/includes/taskbar.html" />
<roundcube:include file="/includes/header.html" />
<roundcube:include file="/includes/settingstabs.html" />

<div id="mainscreen">

<div id="sieverules-advanced">
<div id="prefs-title" class="boxtitle"><roundcube:object name="steptitle" /></div>

<div id="sieverules-advancedbox">
<roundcube:object name="advancededitor" />
</div>

<div class="boxfooter">
<roundcube:button name="sieverulesactions" id="sieverulesmenulink" type="link" title="sieverules.moreactions" class="button groupactions" onclick="rcmail_ui.show_popupmenu('sieverulesmenu'); return false" content=" " />
</div>
</div>

<div id="sieverules-advbuttons">
<roundcube:button command="plugin.sieverules.save" type="input" label="save" class="button mainaction" />
</div>

</div>

<div id="sieverulesactionsmenu" class="popupmenu">
	<ul>
	<roundcube:if condition="config:sieverules_multiplerules == true" />
	<li class="separator_below"><roundcube:button command="plugin.sieverules.ruleset_dialog" type="link" label="sieverules.newruleset" classAct="active" /></li>
	<roundcube:object name="rulelist" type="link" />
	<li class="separator_above"><roundcube:button command="plugin.sieverules.ruleset_dialog" prop="rename_ruleset" type="link" label="sieverules.renameruleset" classAct="active" /></li>
	<li><roundcube:button command="plugin.sieverules.del_ruleset" type="link" label="sieverules.delruleset" classAct="active" /></li>
	<li><roundcube:button command="plugin.sieverules.activate_ruleset" type="link" label="sieverules.activateruleset" classAct="active" /></li>
	<roundcube:endif />
	<li<roundcube:exp expression="config:sieverules_multiplerules == true ? ' class=separator_above' : ''" />><roundcube:button command="plugin.sieverules.sieverules_adveditor" prop="0" type="link" label="sieverules.stdeditor" classAct="active" /></li>
	</ul>
</div>

<script type="text/javascript">
rcube_init_mail_ui();
</script>

</body>
</html>