<?php
/* Author: Alejandro Vargas */

$labels = array();
$labels['filters'] = 'Filtros';
$labels['filtersname'] = 'Filtros ($name)';
$labels['managefilters'] = 'Manejo de filtros';
$labels['filtername'] = 'Nombre del filtro';
$labels['disablerule'] = 'Desactivar regla';
$labels['disabled'] = 'Desactivada';
$labels['newfilter'] = 'Nuevo filtro';
$labels['editfilter'] = 'Editar filtro';
$labels['moveup'] = 'Mover arriba';
$labels['movedown'] = 'Mover abajo';
$labels['filterallof'] = 'concuerda con TODAS las reglas siguientes';
$labels['filteranyof'] = 'concuerda con ALGUNA de las reglas siguientes';
$labels['filterany'] = 'todos los mensajes';
$labels['filtercontains'] = 'contiene';
$labels['filternotcontains'] = 'no contiene';
$labels['filteris'] = 'es igual a';
$labels['filterisnot'] = 'es distinto de';
$labels['filterexists'] = 'existe';
$labels['filternotexists'] = 'no existe';
$labels['filterregex'] = 'concuerda con la expresion regular';
$labels['filternotregex'] = 'no concuerda con la expresion regular';
$labels['filterunder'] = 'es menos que';
$labels['filterover'] = 'es mas que';
$labels['filteradvoptions'] = 'mas opciones...';
$labels['operator'] = 'Operador';
$labels['comparator'] = 'Comparador';
$labels['isgreaterthan'] = 'es mayor que';
$labels['isgreaterthanequal'] = 'es mayor o igual que';
$labels['islessthan'] = 'es menor que';
$labels['islessthanequal'] = 'es menor o igual que';
$labels['equals'] = 'es igual a';
$labels['notequals'] = 'es distinto de';
$labels['countisgreaterthan'] = 'cantidad es mayor que';
$labels['countisgreaterthanequal'] = 'cantidad es mayor o igual que';
$labels['countislessthan'] = 'cantidad es menor que';
$labels['countislessthanequal'] = 'cantidad es menor o igual que';
$labels['countequals'] = 'cantidad es igual a';
$labels['countnotequals'] = 'cantidad es distinto de';
$labels['valueisgreaterthan'] = 'valor es mayor que';
$labels['valueisgreaterthanequal'] = 'valor es mayor o igual que';
$labels['valueislessthan'] = 'valor es menor que';
$labels['valueislessthanequal'] = 'valor es menor o igual que';
$labels['valueequals'] = 'valor es igual a';
$labels['valuenotequals'] = 'valor es distinto de';
$labels['userpart'] = 'la parte del usuario es igual a';
$labels['notuserpart'] = 'la parte del usuario es distinta de';
$labels['detailpart'] = 'la parte del detalle es igual a';
$labels['notdetailpart'] = 'la parte del detalle es distinta de';
$labels['domainpart'] = 'la parte del dominio es igual a';
$labels['notdomainpart'] = 'la parte del dominio es distinta de';
$labels['teststring'] = 'Iniciando prueba';
$labels['messagemoveto'] = 'Mover mensaje a';
$labels['messageredirect'] = 'Redirigir mensaje a';
$labels['messageimapflags'] = 'Marcar mensaje como';
$labels['messagereject'] = 'Rechazar con aviso';
$labels['messagevacation'] = 'Mensaje de vacaciones';
$labels['messagekeep'] = 'Mantener mensaje';
$labels['messagediscard'] = 'Descartar mensaje';
$labels['messagenotify'] = 'Enviar notificacion';
$labels['messagestop'] = 'Dejar de procesar filtros';
$labels['messagehelp'] = 'Que es esto?';
$labels['sieveorigsubj'] = 'Agregar asunto iriginal a la respuesta';
$labels['sievevachandle'] = 'Manejador';
$labels['method'] = 'Metodo';
$labels['options'] = 'Opciones';
$labels['messagesrules'] = 'Reglas de filtrado';
$labels['messagesactions'] = 'Acciones del filtro';
$labels['sieveto'] = 'Alias';
$labels['sievefrom'] = 'De';
$labels['flag'] = 'Marca';
$labels['importancen'] = 'Ninguno';
$labels['importance1'] = '1';
$labels['importance2'] = '2';
$labels['importance3'] = '3';
$labels['flagread'] = 'Leido';
$labels['flagdeleted'] = 'Borrado';
$labels['flaganswered'] = 'Respondido';
$labels['flagdraft'] = 'Borrador';
$labels['flagflagged'] = 'Marcado';
$labels['addsieverule'] = 'Agregar otra regla despues de esta';
$labels['addsieveact'] = 'Agregar otra accion despues de esta';
$labels['deletesieverule'] = 'Borrar esta regla';
$labels['deletesieveact'] = 'Borrar esta accion';
$labels['envelopefrom'] = 'Remitente en la cabecera';
$labels['envelopeto'] = 'Destinatario en la cabecera';
$labels['otherheader'] = 'Otra cabecera';
$labels['period'] = 'Periodo';
$labels['days'] = 'dias';
$labels['seconds'] = 'segundos';
$labels['message'] = 'Mensaje';
$labels['sieveruleheaders'] = 'Ver ejemplos de otras cabeceras';
$labels['examplefilters'] = 'Filtros de ejemplo';
$labels['importfilters'] = 'Importar filtros';
$labels['usedefaultfilter'] = 'Usar filtros por defecto';
$labels['importfilter'] = 'Importar filtro';
$labels['adveditor'] = 'Editor avanzado';
$labels['spamlevelisgreaterthanequal'] = 'es mayor o igual que';
$labels['spamlevelislessthanequal'] = 'es menor o igual que';
$labels['spamlevelequals'] = 'es igual a';

$messages = array();
$messages['nosieverules'] = 'No se han encontrado filtros.';
$messages['filterdeleteconfirm'] = '¿Está seguro de que quiere borrar este filtro?';
$messages['ruledeleteconfirm'] = '¿Está seguro de que quiere borrar esta regla?';
$messages['actiondeleteconfirm'] = '¿Está seguro de que quiere borrar esta acción?';
$messages['filterunknownerror'] = 'Error desconocido en el servidor';
$messages['filterconnerror'] = 'Imposible conectar con el servidor sieve';
$messages['filterdeleteerror'] = 'No se pudo borrar el filtro. Error del servidor';
$messages['filterdeleted'] = 'Filtro borrado';
$messages['filtersaved'] = 'Filtro grabado';
$messages['filtersaveerror'] = 'Incapaz de grabar filtro. Error en el servidor';
$messages['vacperiodexp'] = 'El periodo es el numero de dias que el mensaje no será reenviado al mismo usuario, sin importar cuantas veces intente contactar con usted<br /><br />Por ejemplo, si Juan le manda un mensaje, unlunes, y tiene el periodo fijado en 7, Juan recibirá un aviso de vacaciones el lunes pero no recibirá otro hasta el siguiente lunes, sin importar cuántos emails le envíe durente la semana.';
$messages['vachandleexp'] = 'Se puede usar un manejador para vincular diferentes mensajes de vacaciones todos juntos, una vez se envio un mensaje, no se enviará otro que tenga el mismo manejador durante el periodo definido.';
$messages['vactoexp'] = 'Lista de destinatarios adicionales que será incluida en la auto respuesta. Si un destinatario no es su dirección principal, y no está en esta lista, no se le enviarán mensajes.';
$messages['norulename'] = 'Debe asignar un nombre al filtro';
$messages['ruleexists'] = 'Ya hay un filtro con ese nombre. Elija otro';
$messages['noheader'] = 'Debe ingresar el nombre de la cabecera a verificar';
$messages['headerbadchars'] = 'Error: La cabecera contiene caracteres no permitidos';
$messages['noheadervalue'] = 'Ingrese un valor contra el cual comparar la cabecera';
$messages['sizewrongformat'] = 'Error: El tamaño del mensaje debe ser numérico';
$messages['noredirect'] = 'Ingrese una dirección de email a la cual redirigir los mensajes';
$messages['redirectaddresserror'] = 'Error: Dirección inválida';
$messages['noreject'] = 'Ingrese el texto a enviar con los mensajes rechazados';
$messages['vacnoperiod'] = 'Ingrese el numero de dias para el periodo que el mensaje no será reenviado a la misma persona';
$messages['vacperiodwrongformat'] = 'Error: El periodo debe ser 1 o más dias';
$messages['vacnomsg'] = 'Ingrese un texto para el mensaje';
$messages['notifynomethod'] = 'Ingrese el método por el cual se enviará la notificación';
$messages['notifynomsg'] = 'Ingrese un texto para su mensaje';
$messages['sieveruleexp'] = 'Debe definir una o más reglas contra las que se comprobarán los mensajes. Los filtros son ejecutados en el orden e nque aparecen a la izquierda de esta pantalla. Si se encuentra una coincidencia los demás filtros no se comprueban.';
$messages['sieveactexp'] = 'Seleccione una de las opciones que figuran abajo. Esta acción será ejecutada por cada mensaje que concuerden con las reglas que figuran arriba.';
$messages['sieveheadershlp'] = 'Debajo hay algunos ejemplos de cabeceras que pueden verificarse con filtros. Seleccione una cabecera para agregar a la regla o increse una propia en el cuadro de arriba.';
$messages['movingfilter'] = 'Moviendo filtro...';
$messages['noexistingfilters'] = '¡No se detectan filtros!';
$messages['importdefault'] = '<b>Usar filtros por defecto:</b> Hay un juego de filtros por defecto disponibles. ¿Quiere instalar una copia de esos filtros?';
$messages['importother'] = '<b>Importar filtros:</b> Se ha encontrado otro juego de filtros de %s. ¿Quiere importarlos a su lista de filtros?';
$messages['switchtoadveditor'] = 'El editor avanzado le permite editar las reglas de sieve directamente. Cualquier cambio que haga será ilegible para el editor normal de reglas y se parderá si graba modificaciones con el editor normal. ¿Quiere continuar?';
$messages['filterimported'] = 'Filtro importado correctamente';
$messages['filterimporterror'] = 'No se pudo importar el filtro. Error en el servidor';

?>