<?php
/* Author: Michal Michalac */

$labels = array();
$labels['filters'] = 'Pravidlá';
$labels['managefilters'] = 'Spravovať pravidlá';
$labels['filtername'] = 'Názov pravidla';
$labels['disablerule'] = 'Zakázať pravidlo';
$labels['disabled'] = 'zakázané';
$labels['newfilter'] = 'Nové pravidlo';
$labels['moveup'] = 'Posunúť vyššie';
$labels['movedown'] = 'Posunúť nižšie';
$labels['filterallof'] = 'vyhovuje všetkým nasl. podmienkam';
$labels['filteranyof'] = 'vyhovuje niektorej z nasl. podmienok';
$labels['filterany'] = 'všetky správy';
$labels['filtercontains'] = 'obsahuje';
$labels['filternotcontains'] = 'neobsahuje';
$labels['filteris'] = 'je presne';
$labels['filterisnot'] = 'nie je';
$labels['filterexists'] = 'existuje';
$labels['filternotexists'] = 'neexistuje';
$labels['filterregex'] = 'vyhovuje regulárnemu výrazu';
$labels['filternotregex'] = 'nevyhovuje regulárnemu výrazu';
$labels['filterunder'] = 'je menšie ako';
$labels['filterover'] = 'je väčšie ako';
$labels['filteradvoptions'] = 'viac volieb...';
$labels['spamtest'] = 'Pravdepodobnosť spamu';
$labels['operator'] = 'Operátor';
$labels['comparator'] = 'Porovnanie';
$labels['isgreaterthan'] = 'je väčšie ako';
$labels['isgreaterthanequal'] = 'je väčšie, alebo rovné ako';
$labels['islessthan'] = 'je menšie ako';
$labels['islessthanequal'] = 'je menšie, alebo rovné ako';
$labels['equals'] = 'je rovné';
$labels['notequals'] = 'nie je rovné';
$labels['countisgreaterthan'] = 'počet je väčší ako';
$labels['countisgreaterthanequal'] = 'počet je väčší, alebo rovný ako';
$labels['countislessthan'] = 'počet je menší ako';
$labels['countislessthanequal'] = 'počet je menší, alebo rovný ako';
$labels['countequals'] = 'počet je';
$labels['countnotequals'] = 'počet nie je ';
$labels['valueisgreaterthan'] = 'hodnota je väčšia ako';
$labels['valueisgreaterthanequal'] = 'hodnota je väčšia, alebo rovná ako';
$labels['valueislessthan'] = 'hodnota je menšia ako';
$labels['valueislessthanequal'] = 'hodnota je menšia, alebo rovná ako';
$labels['valueequals'] = 'hodnota je rovná';
$labels['valuenotequals'] = 'hodnota nie je rovná';
$labels['userpart'] = 'užívateľská časť sa zhoduje s';
$labels['notuserpart'] = 'užívateľská časť sa nezhoduje s';
$labels['detailpart'] = 'detail sa zhoduje s';
$labels['notdetailpart'] = 'detail sa nezhoduje s';
$labels['domainpart'] = 'doména sa zhoduje';
$labels['notdomainpart'] = 'doména sa nezhoduje';
$labels['teststring'] = 'Testovací text';
$labels['messagemoveto'] = 'Presunúť správu do';
$labels['messageredirect'] = 'Preposlať správu na';
$labels['messageimapflags'] = 'Označiť správu ako';
$labels['messagereject'] = 'Odmietnuť so správou';
$labels['messagevacation'] = 'Dovolenka';
$labels['messagekeep'] = 'Zachovať správu';
$labels['messagediscard'] = 'Zrušiť správu';
$labels['messagenotify'] = 'Zaslať upozornenie';
$labels['messagestop'] = 'Ukončiť spracovanie pravidiel';
$labels['messagehelp'] = 'Čo je toto?';
$labels['sieveorigsubj'] = 'Pripojiť k odpovedi pôvodný predmet';
$labels['sievevachandle'] = 'Odkaz';
$labels['method'] = 'Metóda';
$labels['options'] = 'Voľby';
$labels['messagesrules'] = 'Podmienky pravidla';
$labels['messagesactions'] = 'Akcie pravidla';
$labels['sieveto'] = 'Aliasy';
$labels['sievefrom'] = 'Od';
$labels['flag'] = 'Dôležitosť';
$labels['importancen'] = 'žiadna';
$labels['importance1'] = 'vysoká';
$labels['importance2'] = 'štandardná';
$labels['importance3'] = 'nízka';
$labels['flagread'] = 'Prečítanú';
$labels['flagdeleted'] = 'Vymazanú';
$labels['flaganswered'] = 'Zodpovedanú';
$labels['flagdraft'] = 'Koncept';
$labels['flagflagged'] = 'Označenú';
$labels['addsieverule'] = 'Pridať ďalšiu podmienku';
$labels['addsieveact'] = 'Pridať ďalšiu akciu';
$labels['deletesieverule'] = 'Vymazať túto podmienku';
$labels['deletesieveact'] = 'Vymazať túto akciu';
$labels['envelopefrom'] = 'Odosielateľ na obálke';
$labels['envelopeto'] = 'Adresát na obálke';
$labels['otherheader'] = 'Iná hlavička';
$labels['period'] = 'Obdobie';
$labels['message'] = 'Správa';
$labels['sieveruleheaders'] = 'Zobraziť príklady ďalších hlavičiek';
$labels['examplefilters'] = 'Pripravené pravidlá';
$labels['importfilters'] = 'Importovať pravidlá';
$labels['usedefaultfilter'] = 'Použiť predvolené pravidlá';
$labels['importfilter'] = 'Importovať pravidlo';
$labels['adveditor'] = 'Pokročilý editor';
$labels['messageredirectcopy'] = 'Preposlať kópiu na';
$labels['messagecopyto'] = 'Kopírovať správu do';
$labels['body'] = 'Telo';
$labels['auto'] = 'Automatické';
$labels['raw'] = 'Hrubé';
$labels['text'] = 'Text';
$labels['other'] = 'Iné';
$labels['bodycontentpart'] = 'Obsah správy';
$labels['notchecked'] = 'nekontrolovaný';
$labels['spamlevelisgreaterthanequal'] = 'je väčší, alebo rovný ako';
$labels['spamlevelislessthanequal'] = 'je menší, alebo rovný ako';
$labels['spamlevelequals'] = 'je rovný';
$labels['i;ascii-casemap'] = 'text sa zhoduje bez rozlíšenia veľkosti písmen';
$labels['i;octet'] = 'text sa zhoduje';
$labels['i;ascii-numeric'] = 'číslo sa zhoduje';

$messages = array();
$messages['nosieverules'] = 'Žiadne pravidlá neboli nájdené.';
$messages['filterdeleteconfirm'] = 'Ste si istí, že chcete toto pravidlo naozaj vymazať?';
$messages['ruledeleteconfirm'] = 'Ste si istí, že chcete túto podmienku naozaj vymazať?';
$messages['actiondeleteconfirm'] = 'Ste si istí, že chcete túto akciu naozaj vymazať?';
$messages['filterunknownerror'] = 'Neznáma chyba servera';
$messages['filterconnerror'] = 'Nie je možné pripojiť sa k sieve serveru';
$messages['filterdeleteerror'] = 'Pravidlo nie je možné vymazať. Vyskytla sa chyba serveru';
$messages['filterdeleted'] = 'Pravidlo bolo úspešne vymazané';
$messages['filtersaved'] = 'Pravidlo bolo úspešne uložené';
$messages['filtersaveerror'] = 'Pravidlo nie je možné uložiť. Vyskytla sa chyba serveru';
$messages['vacperiodexp'] = "Obdobie je počet dní, počas ktorého nebude správa posielaná rovnakému užívateľovi bez ohľadu na to, koľko krát Vás bude kontaktovať. Napr.: Ak si nastavíte obdobie na 7 (dní) a Jozef Vám pošle e-mail v pondelok, v stredu, v nedeľu a na ďalší pondelok, dostane správu o Vašej neprítomnosti vždy len v pondelok.";
$messages['vachandleexp'] = 'Odkaz sa dá použiť na pripojenie iných dovolenkových správ. Každá z nich sa v nastavenom období použije len raz.';
$messages['vactoexp'] = "Zoznam ďalších adresátov zahrnutých do automatického odpovedania. Ak e-mail nie je adresovaný na Vašu hlavnú e-mailovú adresu ani na adresu v tomto zozname, automatická odpoveď sa neposiela.";
$messages['norulename'] = 'Zadajte prosím názov pravidla';
$messages['ruleexists'] = 'Pravidlo s týmto názvom už existuje. Zadajte prosím iný názov';
$messages['noheader'] = 'Zadajte prosím názov hlavičky pre porovnanie';
$messages['headerbadchars'] = 'Chyba: Hlavička obsahuje zakázané znaky';
$messages['noheadervalue'] = 'Zadajte prosím hodnotu s ktorou sa má hlavička porovnávať';
$messages['sizewrongformat'] = 'Chyba: Veľkosť správy musí byť číslo';
$messages['noredirect'] = 'Zadajte prosím e-mailovú adresu na ktorú sa má správa preposlať';
$messages['redirectaddresserror'] = 'Chyba: Adresa vyzerá ako neplatná';
$messages['noreject'] = 'Zadajte prosím správu, ktorá sa pošle s odmietnutím';
$messages['vacnoperiod'] = 'Zadajte prosím do obdobia počet dní, počas ktorých nebude automatická odpoveď posielaná rovnakému užívateľovi';
$messages['vacperiodwrongformat'] = 'Chyba: Obdobie musí byť číslo väčšie, alebo rovné 1';
$messages['vacnomsg'] = 'Zadajte prosím nejaký text správy';
$messages['notifynomethod'] = 'Zadajte prosím spôsob, ktorým má byť upozornenie poslané';
$messages['notifynomsg'] = 'Zadajte prosím text Vašej správy';
$messages['sieveruleexp'] = "Zadefinujte prosím podmienky s ktorými bude správa porovnávaná. Pravidlá sa vyhodnocujú v poradí v akom sú zobrazené v ľavej časti tejto obrazovky. Ak sa nájde zhoda, ďalšie pravidlá sa vyhodnocovať nebudú.";
$messages['sieveactexp'] = 'Vyberte prosím zo zoznamu akciu, ktorá sa bude vykonávať pre všetky e-maily vyhovujúce podmienke/podmienkam vyššie.';
$messages['sieveheadershlp'] = 'Nižšie je uvedených niekoľko príkladov hlavičiek, ktoré môžu byť použité v podmienkach. Vyberte si tú, ktorú chcete vložiť do podmienky hore, alebo zadajte názov hlavičky do okienka ručne.';
$messages['movingfilter'] = 'Presúvam pravidlo...';
$messages['noexistingfilters'] = 'Žiadne pravidlo nebolo nájdené!';
$messages['importdefault'] = '<b>Použiť pripravené pravidlá:</b> Je dostupných niekoľko pravidiel. Chcete ich použiť?';
$messages['importother'] = '<b>Importovať pravidlá:</b> Ďalšia sada pravidiel bola nájdená v %s. Chcete ich importovať?';
$messages['switchtoadveditor'] = 'Prepnutie do pokročilého editora Vám umožní priamo editovať súbor pravidel. Úpravy, ktoré tu urobíte môžu byť pre štandardný editor pravidiel nečitateľné a môžu sa pri uložení v ňom stratiť. Chcete pokračovať?';
$messages['filterimported'] = 'Pravidlá boli úspešne importované';
$messages['filterimporterror'] = 'Pravidlá nebolo možné importovať. Vyskytla sa chyba servera';
$messages['notifyinvalidmethod'] = 'Vyzerá to, že metóda nie je zapísaná v platnom formáte. Musí to byť URI. Napr.: `mailto:adresa@domena.sk`.';
$messages['nobodycontentpart'] = 'Zadajte prosím obsahovú časť testu';
$messages['badoperator'] = 'Prepáčte, ale operátor ktorý ste vybrali nemôže byť v tejto podmienke použitý';
$messages['filteractionerror'] = 'Akcia, ktorú ste vybrali nie je podporovaná serverom';
$messages['filtermissingerror'] = 'Nepodarilo sa nájsť požadovanú podmienku';
$messages['contentpartexp'] = 'Typ MIME, alebo špecifická časť správy, ktorá má byť testovaná. Napr.: `message/rfc822`, `text/html`, `audio/mp3` či `image`.';

?>