<?php
/* Author: Michael Metz */

$labels = array();
$labels['filters'] = 'Filter';
$labels['managefilters'] = 'Filter verwalten';
$labels['filtername'] = 'Filtername';
$labels['disablerule'] = 'Filterregel abschalten';
$labels['disabled'] = 'abgeschaltet';
$labels['newfilter'] = 'Neuer Filter';
$labels['moveup'] = 'Aufwärts';
$labels['movedown'] = 'Abwärts';
$labels['filterallof'] = 'trifft alle folgenden Regeln';
$labels['filteranyof'] = 'trifft irgendeine der folgenden Regeln';
$labels['filterany'] = 'alle Nachrichten';
$labels['filtercontains'] = 'enthält';
$labels['filternotcontains'] = 'enthält nicht';
$labels['filteris'] = 'ist identisch mit';
$labels['filterisnot'] = 'ist nicht identisch mit';
$labels['filterexists'] = 'existiert';
$labels['filternotexists'] = 'existiert nicht';
$labels['filterregex'] = 'trifft auf den regulären Ausdruck zu';
$labels['filternotregex'] = 'trifft nicht auf den regulären Ausdruck zu';
$labels['filterunder'] = 'ist kleiner als';
$labels['filterover'] = 'ist größer als';
$labels['filterbefore'] = 'ist vor';
$labels['filterafter'] = 'ist nach';
$labels['filteradvoptions'] = 'weitere Optionen...';
$labels['spamtest'] = 'Spam-Wahrscheinlichkeit';
$labels['operator'] = 'Operator';
$labels['comparator'] = 'Komparator';
$labels['isgreaterthan'] = 'ist größer als';
$labels['isgreaterthanequal'] = 'ist größer als oder gleich ';
$labels['islessthan'] = 'ist kleiner als';
$labels['islessthanequal'] = 'ist kleiner als oder gleich';
$labels['equals'] = 'ist gleich';
$labels['notequals'] = 'ist nicht gleich';
$labels['countisgreaterthan'] = 'Anzahl ist größer als';
$labels['countisgreaterthanequal'] = 'Anzahl ist mindestens';
$labels['countislessthan'] = 'Anzahl ist kleiner';
$labels['countislessthanequal'] = 'Anzahl ist höchstens';
$labels['countequals'] = 'Anzahl ist gleich';
$labels['countnotequals'] = 'Anzahl ist ungleich';
$labels['valueisgreaterthan'] = 'Wert ist größer als';
$labels['valueisgreaterthanequal'] = 'Wert ist mindestens';
$labels['valueislessthan'] = 'Wert ist kleiner als';
$labels['valueislessthanequal'] = 'Wert ist höchstens';
$labels['valueequals'] = 'Wert ist gleich';
$labels['valuenotequals'] = 'Wert ist ungleich';
$labels['userpart'] = 'User-Teil gleicht';
$labels['notuserpart'] = 'User-Teil gleicht nicht';
$labels['detailpart'] = 'Detail-Teil gleicht';
$labels['notdetailpart'] = 'Detail-Teil gleicht nicht';
$labels['domainpart'] = 'Domain-Teil gleicht';
$labels['notdomainpart'] = 'Domain-Teil gleicht nicht';
$labels['teststring'] = 'Test-Zeichenkette';
$labels['messagemoveto'] = 'Verschiebe Nachricht nach';
$labels['messageredirect'] = 'Leite Nachricht weiter an';
$labels['messageimapflags'] = 'Markiere Nachricht als';
$labels['messagereject'] = 'Lehne Nachricht ab mit Begründung';
$labels['messagevacation'] = 'Abwesenheitsnachricht';
$labels['messagekeep'] = 'Behalte Nachricht';
$labels['messagediscard'] = 'Verwerfe Nachricht';
$labels['messagenotify'] = 'Sende Benachrichtigung';
$labels['messagestop'] = 'Filterverarbeitung beenden';
$labels['messagehelp'] = 'Hilfe';
$labels['sieveorigsubj'] = 'Hänge originalen Betreff an die Antwort an';
$labels['sievevachandle'] = 'Handle';
$labels['method'] = 'Methode';
$labels['options'] = 'Optionen';
$labels['messagesrules'] = 'Filterregeln';
$labels['messagesactions'] = 'Filteraktionen';
$labels['sieveto'] = 'Empfänger';
$labels['sievefrom'] = 'Absender';
$labels['flag'] = 'Markierung';
$labels['importancen'] = 'Keine';
$labels['importance1'] = '1';
$labels['importance2'] = '1';
$labels['importance3'] = '1';
$labels['flagread'] = 'Gelesen';
$labels['flagdeleted'] = 'Gelöscht';
$labels['flaganswered'] = 'Beantwortet';
$labels['flagdraft'] = 'Entwurf';
$labels['flagflagged'] = 'Markiert';
$labels['addsieverule'] = 'Weitere Regel unterhalb dieser hinzufügen';
$labels['addsieveact'] = 'Weitere Aktion unterhalb dieser hinzufügen';
$labels['deletesieverule'] = 'Diese Regel löschen';
$labels['deletesieveact'] = 'Diese Aktion löschen';
$labels['envelopefrom'] = 'Envelope From';
$labels['envelopeto'] = 'Envelope To';
$labels['otherheader'] = 'Anderer Header';
$labels['period'] = 'Zeitraum';
$labels['message'] = 'Nachricht';
$labels['sieveruleheaders'] = 'Zeige Beispiele für andere Header';
$labels['examplefilters'] = 'Beispielfilter...';
$labels['importfilters'] = 'Filter importieren';
$labels['usedefaultfilter'] = 'Verwende Standardfilter';
$labels['importfilter'] = 'Filter importieren';
$labels['moreactions'] = 'Weitere Optionen...';
$labels['adveditor'] = 'Erweiterter Editor';
$labels['stdeditor'] = 'Standard-Editor';
$labels['messageredirectcopy'] = 'Sende eine Kopie an';
$labels['messagecopyto'] = 'Kopiere Nachricht nach';
$labels['body'] = 'Body';
$labels['auto'] = 'Auto';
$labels['raw'] = 'Raw';
$labels['text'] = 'Text';
$labels['other'] = 'Anderes';
$labels['bodycontentpart'] = 'Content Part';
$labels['notchecked'] = 'nicht geprüft';
$labels['spamlevelisgreaterthanequal'] = 'ist mindestens';
$labels['spamlevelislessthanequal'] = 'ist höchstens';
$labels['spamlevelequals'] = 'ist gleich';
$labels['i;ascii-casemap'] = 'schreibungsunabhängige Zeichenfolge';
$labels['i;octet'] = 'exakte Zeichenfolge';
$labels['i;ascii-numeric'] = 'zahlenmäßige Übereinstimmung';
$labels['selectruleset'] = 'Wähle Regelsatz';
$labels['activeruleset'] = '%s (aktiv)';
$labels['activateruleset'] = 'Aktiviere Regelsatz';
$labels['newruleset'] = 'Erstelle Regelsatz';
$labels['delruleset'] = 'Lösche diesen Regelsatz';
$labels['renameruleset'] = 'Regelsatz umbenennen';
$labels['copy'] = 'Kopieren';
$labels['copyexistingfilter'] = 'Kopiere bestehende Filter';
$labels['copytoruleset'] = 'Kopiere Filter in anderen Regelsatz';
$labels['copyfromruleset'] = 'Kopiere Filter aus anderem Regelsatz';
$labels['time'] = 'Zeit';
$labels['weekday'] = 'Wochentag';
$labels['virustest'] = 'Viruswahrscheinlichkeit';
$labels['novirus'] = 'keinen Virus gefunden';
$labels['virusremoved'] = 'Virus gefunden und entfernt';
$labels['viruscured'] = 'Virus gefunden und kuriert';
$labels['possiblevirus'] = 'Nachricht enthält möglicherweise einen Virus';
$labels['definitevirus'] = 'Nachricht enthält definitiv einen Virus';
$labels['createfilter'] = 'Erstelle Filter...';
$labels['createfilterbased'] = 'Erstelle einen auf dieser Nachricht basierenden Filter';

$messages = array();
$messages['nosieverules'] = 'Keine Filter gefunden.';
$messages['filterdeleteconfirm'] = 'Bist du sicher das du diesen Filter löschen möchtest?';
$messages['ruledeleteconfirm'] = 'Bist du sicher das du diese Regel löschen möchtest?';
$messages['actiondeleteconfirm'] = 'Bist du sicher das du diese Aktion löschen möchtest?';
$messages['filterunknownerror'] = 'Unbekannter Serverfehler';
$messages['filterconnerror'] = 'Konnte keine Verbindung zum Sieve-Server aufbauen';
$messages['filterdeleteerror'] = 'Konnte Filter nicht löschen. Serverfehler';
$messages['filterdeleted'] = 'Filter erfolgreich gelöscht';
$messages['filtersaved'] = 'Filter erfolgreich gespeichert';
$messages['filtersaveerror'] = 'Konnte Filter nicht speichern. Serverfehler';
$messages['vacperiodexp'] = 'Zeitraum in Anzahl Tagen, in dem die Abwesenheitsnachricht nicht erneut an den selben Absender gesendet wird.<br /><br />Beispiel: Wenn Joe dir am Montag eine Mail schickt und der Zeitraum beträgt 7, bekommt Joe sofort eine Abwesenheitsnachricht gesendet, dann aber bis zum darauffolgenden Montag keine mehr, egal wie häufig er weitere Mails sendet.';
$messages['vachandleexp'] = 'Ein Handle kann genutzt werden um verschiedene Abwesenheitsnachrichten zu koppeln, so dass im Zeitraum keine weiteren Abwesenheitsnachrichten gesendet werden die das selbe Handle besitzen.';
$messages['vactoexp'] = 'Liste zusätzlicher Empfängeradressen, für die ebenfalls eine Abwesenheitsnachricht gesendet wird. Gehen Mails ein, deren Empfänger nicht die Hauptadresse ist und die nicht in dieser Liste stehen, wird keine Abwesenheitsnachricht gesendet.';
$messages['vactoexp_adv'] = 'Trenne mehrere Adressen mit einem Komma (,). Zum Beispiel: test1@example.com,test2@example.com,test3@example.com';
$messages['vactoexp_err'] = 'Fehler: Mehrere Adressen müssen durch ein Komma (,) getrennt werden';
$messages['norulename'] = 'Bitte gib einen Namen für diesen Filter ein';
$messages['ruleexists'] = 'Ein Filter mit diesem Namen existiert bereits. Wähle einen anderen';
$messages['noheader'] = 'Bitte gib den Namen des zu testenden Headers ein';
$messages['headerbadchars'] = 'Fehler: Header enthält unzulässige Zeichen';
$messages['noheadervalue'] = 'Bitte gib den Wert ein, gegen den der Header getestet werden soll';
$messages['sizewrongformat'] = 'Fehler: Nachrichtengröße muss numerisch sein';
$messages['noredirect'] = 'Bitte gib eine E-Mail Adresse zur Weiterleitung ein';
$messages['redirectaddresserror'] = 'Fehler: E-Mail Adresse ungültig';
$messages['noreject'] = 'Bitte gib eine Nachricht als Begründung für die Abweisung der Mail ein';
$messages['vacnoperiod'] = 'Bitte gib die Anzahl Tage ein, währendessen die Abwesenheitsnachricht nicht erneut an den selben Absender gesendet wird.';
$messages['vacperiodwrongformat'] = 'Fehler: Der Zeitraum muss numerisch größer gleich 1 sein';
$messages['vacnomsg'] = 'Bitte gib einen Text für deine Nachricht ein';
$messages['notifynomethod'] = 'Bitte gibt eine Methode an mit der Benachrichtigungen versendet werden sollen.';
$messages['notifynomsg'] = 'Bitte gebe einen Text für die Nachricht ein';
$messages['sieveruleexp'] = 'Bitte erstelle eine oder mehrere Regeln gegen die jede Nachricht getestet werden soll. Filter werden in der Reihenfolge durchlaufen, in der sie links gelistet sind. Wenn ein Filter zutrifft, werden keine weiteren Filter durchlaufen.';
$messages['sieveruleexp_stop'] = 'Bitte wähle mindestens eine Regel, die auf die Nachrichten angewandt werden soll. Filter werden in der Reihenfolge abgearbeitet, wie sie auf der linken Seite dargestellt sind bis eine \'Stop\'-Regel zutrifft.';
$messages['sieveactexp'] = 'Bitte wähle eine von den unten gelisteten Optionen. Diese Aktionen werden für jede Nachricht ausgeführt, die auf obige Filterregel(n) passt.';
$messages['sieveheadershlp'] = 'Unten werden einige Header als Beispiel für mögliche Header angezeigt. Wähle einen oder füge oben einen eigenen Header hinzu.';
$messages['movingfilter'] = 'Verschiebe Filter...';
$messages['noexistingfilters'] = 'Keine vorhandenen Filter gefunden!';
$messages['importdefault'] = '<b>Verwende Standardfilter:</b> Es sind eine Reihe von Standardfiltern verfügbar. Möchtest Du diese verwenden?';
$messages['importother'] = '<b>Filter importieren:</b> EIne Reihe von Filtern von %s wurden gefunden. Möchtest Du diese Filter Deinen Filtern hinzufügen?';
$messages['switchtoadveditor'] = 'Die verwendung des erweiterten Editors ermöglicht es, die Sieve-Filter direkt zu bearbeiten. Alle Änderungen sind für den normalen Editor unlesbar und werden verworfen wenn eine Regel mit dem normalen Editor gespeichert wird. Möchtest Du fortfahren?';
$messages['filterimported'] = 'Filterimport erfolgreich';
$messages['filterimporterror'] = 'Fehler beim Filterimport. Serverfehler.';
$messages['notifyinvalidmethod'] = 'Die Methode scheint ein ungültiges Format zu haben. Es muss eine URI sein, z. B.: `mailto:alert@example.com`.';
$messages['nobodycontentpart'] = 'Bitte gib den zu testenden Bereich des Inhalts an';
$messages['badoperator'] = 'Der gewählte Operator kann in dieser Regel nicht verwendet werden';
$messages['filteractionerror'] = 'Die gewünschte Aktion wird vom Server nicht unterstützt';
$messages['filtermissingerror'] = 'Die angeforderte Regel konnte nicht gefunden werden';
$messages['contentpartexp'] = 'Der MIME-Typ oder der Teil der Nachricht, der getestet werden soll. Zum Beispiel: `message/rfc822`, `text/html`, `audio/mp3` oder `image`.';
$messages['delrulesetconf'] = 'Soll dieser Regelsatz wirklich gelöscht werden?';
$messages['rulesetexists'] = 'Ein Regelsatz mit diesem Namen existiert bereits. Bitte wähle einen anderen Namen.';
$messages['copyexisting'] = 'Kopiere bestehenden Regelsatz: Sollen die Filter von einem bestehenden Regelsatz in den akutellen Regelsatz kopiert werden?';
$messages['filtercopied'] = 'Filter erfolgreich kopiert.';
$messages['nosieverulesets'] = 'Keine Regelsätze gefunden.';
$messages['baddateformat'] = 'Fehler: Bitte das Datum im Format JJJJ-MM-TT eingeben.';
$messages['badtimeformat'] = 'Fehler: Bitte die Uhrzeit im Format HH:MM:SS eingeben.';
$messages['missingfoldername'] = 'Fehler: Bitte ein Verzeichnisnamen eingeben.';
$messages['addtoexisting'] = 'Wähle einen bestehenden Filter von der Liste auf der linken Seite um die neuen Kriterien hinzuzufügen oder wähle aus den Optionen unten.';

?>